/*
 * This file is generated from insns.dat, regs.dat and token.dat
 * by tokhash.pl; do not edit.
 */

#include "compiler.h"
#include <string.h>
#include "nasm.h"
#include "hashtbl.h"
#include "insns.h"
#include "stdscan.h"

struct tokendata {
    const char *string;
    int16_t tokentype;
    int8_t aux;
    int8_t tokflag;
    int32_t num;
};

int nasm_token_hash(const char *token, struct tokenval *tv)
{
#define UNUSED 16383
    static const int16_t hash1[2048] = {
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        0,
        UNUSED,
        0,
        0,
        -3300,
        UNUSED,
        0,
        0,
        -1035,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        0,
        0,
        UNUSED,
        0,
        -3655,
        UNUSED,
        0,
        UNUSED,
        0,
        0,
        UNUSED,
        -121,
        -823,
        -1221,
        0,
        0,
        0,
        4704,
        UNUSED,
        0,
        -324,
        0,
        0,
        UNUSED,
        198,
        165,
        0,
        0,
        0,
        0,
        4366,
        0,
        -1461,
        UNUSED,
        0,
        0,
        0,
        0,
        0,
        0,
        UNUSED,
        0,
        0,
        2145,
        UNUSED,
        0,
        1968,
        3637,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        -470,
        0,
        1303,
        UNUSED,
        0,
        0,
        UNUSED,
        1376,
        0,
        0,
        UNUSED,
        0,
        921,
        4101,
        0,
        0,
        UNUSED,
        2016,
        0,
        2665,
        1338,
        1545,
        1989,
        UNUSED,
        572,
        0,
        UNUSED,
        -4228,
        0,
        2099,
        3605,
        1844,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        -276,
        0,
        0,
        0,
        UNUSED,
        1561,
        0,
        UNUSED,
        348,
        1849,
        -852,
        698,
        1979,
        0,
        0,
        473,
        4432,
        -8,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        422,
        446,
        272,
        UNUSED,
        4597,
        0,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        1972,
        UNUSED,
        -811,
        113,
        UNUSED,
        -1583,
        UNUSED,
        687,
        0,
        0,
        177,
        -3789,
        0,
        2664,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        440,
        -4168,
        UNUSED,
        0,
        UNUSED,
        0,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1053,
        1434,
        113,
        0,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        0,
        0,
        0,
        333,
        -525,
        UNUSED,
        0,
        0,
        UNUSED,
        -280,
        0,
        1653,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        406,
        UNUSED,
        33,
        UNUSED,
        UNUSED,
        -3901,
        0,
        0,
        0,
        UNUSED,
        -2092,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        0,
        349,
        0,
        UNUSED,
        UNUSED,
        0,
        -2053,
        0,
        1499,
        0,
        0,
        66,
        2075,
        UNUSED,
        0,
        -589,
        UNUSED,
        -2013,
        0,
        0,
        1763,
        UNUSED,
        0,
        0,
        UNUSED,
        UNUSED,
        2415,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        639,
        1961,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        719,
        833,
        -1939,
        0,
        UNUSED,
        830,
        1112,
        UNUSED,
        UNUSED,
        UNUSED,
        1376,
        UNUSED,
        0,
        UNUSED,
        -1372,
        UNUSED,
        -628,
        -2168,
        UNUSED,
        UNUSED,
        867,
        UNUSED,
        827,
        UNUSED,
        0,
        UNUSED,
        0,
        UNUSED,
        2135,
        UNUSED,
        805,
        0,
        865,
        1182,
        UNUSED,
        1578,
        2540,
        UNUSED,
        0,
        -1186,
        601,
        1254,
        UNUSED,
        1548,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        -2159,
        0,
        3386,
        -4599,
        538,
        105,
        0,
        UNUSED,
        0,
        0,
        -6390,
        0,
        -399,
        1287,
        0,
        UNUSED,
        0,
        -1184,
        0,
        UNUSED,
        0,
        458,
        2071,
        -547,
        UNUSED,
        1146,
        -3524,
        0,
        62,
        0,
        1863,
        4254,
        0,
        -1174,
        UNUSED,
        0,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        -402,
        793,
        UNUSED,
        2318,
        678,
        -4433,
        0,
        68,
        -4368,
        1271,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        1692,
        -939,
        2742,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        -1964,
        UNUSED,
        UNUSED,
        -542,
        1993,
        2561,
        UNUSED,
        2021,
        -3025,
        2403,
        1712,
        730,
        3205,
        0,
        -5708,
        1784,
        UNUSED,
        0,
        UNUSED,
        520,
        0,
        -5586,
        0,
        0,
        -3268,
        4103,
        -807,
        UNUSED,
        UNUSED,
        1089,
        347,
        367,
        305,
        UNUSED,
        798,
        -2793,
        0,
        UNUSED,
        849,
        UNUSED,
        UNUSED,
        -2096,
        0,
        UNUSED,
        0,
        3695,
        462,
        0,
        0,
        2946,
        -381,
        -182,
        UNUSED,
        UNUSED,
        -5333,
        UNUSED,
        1131,
        UNUSED,
        -3142,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        3747,
        -4290,
        UNUSED,
        UNUSED,
        202,
        599,
        UNUSED,
        1289,
        1213,
        UNUSED,
        300,
        0,
        1090,
        -695,
        1239,
        1899,
        1158,
        UNUSED,
        1514,
        UNUSED,
        -2284,
        691,
        2876,
        UNUSED,
        -5328,
        UNUSED,
        92,
        UNUSED,
        2239,
        UNUSED,
        3419,
        -2100,
        1635,
        -217,
        440,
        -108,
        0,
        UNUSED,
        UNUSED,
        -3052,
        649,
        468,
        -120,
        UNUSED,
        UNUSED,
        UNUSED,
        1561,
        21,
        -6622,
        1689,
        0,
        -914,
        838,
        450,
        UNUSED,
        2634,
        3502,
        -902,
        603,
        297,
        UNUSED,
        0,
        1159,
        -2191,
        UNUSED,
        0,
        0,
        3373,
        1759,
        UNUSED,
        3959,
        -2327,
        0,
        0,
        1298,
        UNUSED,
        0,
        1642,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        0,
        1489,
        1447,
        -1077,
        UNUSED,
        3514,
        0,
        UNUSED,
        0,
        UNUSED,
        0,
        0,
        UNUSED,
        751,
        383,
        -392,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        1313,
        UNUSED,
        -2879,
        UNUSED,
        0,
        0,
        1596,
        0,
        219,
        UNUSED,
        UNUSED,
        1872,
        -1781,
        126,
        531,
        0,
        859,
        -5161,
        886,
        UNUSED,
        UNUSED,
        UNUSED,
        -1613,
        -983,
        -606,
        0,
        856,
        UNUSED,
        910,
        UNUSED,
        UNUSED,
        2739,
        1471,
        UNUSED,
        UNUSED,
        1480,
        -1412,
        4236,
        0,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        1366,
        0,
        3670,
        0,
        1039,
        UNUSED,
        2430,
        UNUSED,
        -288,
        UNUSED,
        UNUSED,
        17,
        UNUSED,
        0,
        -1403,
        UNUSED,
        -3027,
        UNUSED,
        -416,
        UNUSED,
        639,
        UNUSED,
        -2329,
        0,
        1026,
        -545,
        -13,
        499,
        -274,
        UNUSED,
        -1531,
        -252,
        UNUSED,
        2888,
        UNUSED,
        UNUSED,
        -130,
        2046,
        2024,
        UNUSED,
        3144,
        0,
        -262,
        2081,
        911,
        1614,
        118,
        UNUSED,
        UNUSED,
        UNUSED,
        1194,
        UNUSED,
        -2494,
        UNUSED,
        -5685,
        629,
        UNUSED,
        1686,
        -1777,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1260,
        4298,
        UNUSED,
        654,
        -485,
        1803,
        -928,
        UNUSED,
        -1154,
        UNUSED,
        UNUSED,
        0,
        1255,
        2722,
        UNUSED,
        0,
        556,
        -512,
        UNUSED,
        0,
        UNUSED,
        25,
        0,
        190,
        2012,
        UNUSED,
        1570,
        1980,
        1078,
        1144,
        0,
        -619,
        2136,
        -265,
        0,
        156,
        2189,
        UNUSED,
        947,
        -427,
        -1292,
        3604,
        4216,
        UNUSED,
        -6475,
        -1194,
        -3277,
        713,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        -1773,
        UNUSED,
        -980,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        1781,
        0,
        UNUSED,
        1265,
        2956,
        1143,
        426,
        229,
        -280,
        0,
        UNUSED,
        974,
        -3669,
        -1250,
        -472,
        0,
        829,
        0,
        4,
        0,
        UNUSED,
        -94,
        -1162,
        752,
        UNUSED,
        UNUSED,
        833,
        3613,
        UNUSED,
        1007,
        UNUSED,
        1467,
        0,
        -4187,
        2405,
        0,
        1177,
        0,
        UNUSED,
        UNUSED,
        -4058,
        0,
        -1838,
        2211,
        0,
        0,
        0,
        0,
        -1040,
        890,
        922,
        2830,
        UNUSED,
        1508,
        UNUSED,
        0,
        -362,
        -3475,
        -1053,
        0,
        UNUSED,
        UNUSED,
        263,
        0,
        823,
        UNUSED,
        830,
        2967,
        2311,
        1678,
        UNUSED,
        0,
        0,
        419,
        -4620,
        -4798,
        3708,
        -4279,
        -148,
        UNUSED,
        736,
        7730,
        1895,
        269,
        3422,
        -4406,
        1196,
        -123,
        UNUSED,
        1077,
        UNUSED,
        UNUSED,
        2001,
        UNUSED,
        769,
        UNUSED,
        UNUSED,
        382,
        -3001,
        -801,
        1280,
        0,
        2072,
        0,
        890,
        1901,
        1515,
        UNUSED,
        0,
        1007,
        UNUSED,
        2226,
        91,
        UNUSED,
        325,
        UNUSED,
        UNUSED,
        182,
        0,
        2878,
        2848,
        -819,
        UNUSED,
        -642,
        UNUSED,
        UNUSED,
        20,
        0,
        UNUSED,
        203,
        0,
        -279,
        241,
        340,
        175,
        2358,
        -1192,
        1777,
        -1189,
        UNUSED,
        2258,
        -94,
        454,
        UNUSED,
        888,
        UNUSED,
        UNUSED,
        -2344,
        -1872,
        UNUSED,
        1098,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        242,
        117,
        1489,
        UNUSED,
        -253,
        1924,
        UNUSED,
        0,
        2097,
        1548,
        UNUSED,
        UNUSED,
        205,
        1697,
        -1042,
        UNUSED,
        2581,
        UNUSED,
        UNUSED,
        4166,
        -1111,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        868,
        1829,
        UNUSED,
        -665,
        UNUSED,
        518,
        1917,
        UNUSED,
        UNUSED,
        2677,
        397,
        UNUSED,
        -1672,
        1485,
        630,
        UNUSED,
        UNUSED,
        1069,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        1050,
        0,
        UNUSED,
        UNUSED,
        0,
        -835,
        501,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        -5071,
        UNUSED,
        -5002,
        UNUSED,
        996,
        UNUSED,
        1877,
        956,
        372,
        2661,
        792,
        2022,
        UNUSED,
        UNUSED,
        5333,
        1155,
        UNUSED,
        2311,
        145,
        1427,
        UNUSED,
        UNUSED,
        1609,
        UNUSED,
        -444,
        896,
        -1248,
        0,
        1673,
        3519,
        1510,
        0,
        1657,
        0,
        -813,
        UNUSED,
        -975,
        1541,
        UNUSED,
        1258,
        UNUSED,
        0,
        UNUSED,
        1858,
        2341,
        1012,
        706,
        1670,
        389,
        2648,
        2215,
        1155,
        807,
        -1059,
        1981,
        UNUSED,
        UNUSED,
        120,
        UNUSED,
        UNUSED,
        5409,
        UNUSED,
        1708,
        -1324,
        491,
        1486,
        -1672,
        65,
        -1417,
        0,
        -99,
        0,
        UNUSED,
        -6776,
        1133,
        501,
        6,
        2088,
        UNUSED,
        -893,
        0,
        2028,
        UNUSED,
        -2812,
        UNUSED,
        1484,
        258,
        1299,
        UNUSED,
        -3099,
        219,
        UNUSED,
        -958,
        UNUSED,
        1793,
        -3333,
        3593,
        UNUSED,
        0,
        -94,
        0,
        UNUSED,
        -4370,
        528,
        0,
        41,
        2538,
        UNUSED,
        UNUSED,
        374,
        4083,
        -5223,
        769,
        UNUSED,
        UNUSED,
        1864,
        1896,
        674,
        UNUSED,
        1855,
        197,
        575,
        UNUSED,
        -1659,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        1329,
        0,
        2388,
        -1303,
        0,
        UNUSED,
        380,
        -1018,
        UNUSED,
        412,
        461,
        -1879,
        UNUSED,
        0,
        UNUSED,
        3074,
        -2306,
        -446,
        375,
        1282,
        1356,
        UNUSED,
        -119,
        0,
        -409,
        -1098,
        979,
        3508,
        572,
        2334,
        0,
        623,
        UNUSED,
        859,
        2435,
        1285,
        465,
        UNUSED,
        1288,
        UNUSED,
        UNUSED,
        1308,
        0,
        1189,
        128,
        930,
        1557,
        UNUSED,
        -5809,
        UNUSED,
        0,
        1950,
        UNUSED,
        UNUSED,
        1519,
        2065,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        -3755,
        UNUSED,
        1989,
        653,
        4976,
        UNUSED,
        UNUSED,
        2160,
        -1677,
        1486,
        UNUSED,
        0,
        1147,
        UNUSED,
        -82,
        603,
        UNUSED,
        UNUSED,
        461,
        UNUSED,
        1278,
        0,
        1456,
        -1305,
        UNUSED,
        -844,
        0,
        1879,
        73,
        UNUSED,
        646,
        -857,
        -168,
        UNUSED,
        UNUSED,
        506,
        -389,
        UNUSED,
        242,
        UNUSED,
        UNUSED,
        2200,
        UNUSED,
        2142,
        UNUSED,
        1142,
        UNUSED,
        1393,
        -4513,
        991,
        3108,
        UNUSED,
        921,
        -615,
        644,
        -346,
        819,
        UNUSED,
        UNUSED,
        UNUSED,
        1947,
        -1240,
        0,
        UNUSED,
        UNUSED,
        -3271,
        159,
        UNUSED,
        1453,
        2051,
        UNUSED,
        239,
        377,
        UNUSED,
        -1008,
        0,
        1152,
        -17,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        2130,
        UNUSED,
        UNUSED,
        1585,
        2805,
        -1963,
        0,
        -232,
        420,
        -969,
        UNUSED,
        -1470,
        UNUSED,
        1235,
        UNUSED,
        1167,
        1995,
        0,
        308,
        759,
        321,
        UNUSED,
        198,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        0,
        -418,
        UNUSED,
        UNUSED,
        -5595,
        1553,
        1566,
        583,
        UNUSED,
        UNUSED,
        -21,
        UNUSED,
        -44,
        UNUSED,
        0,
        UNUSED,
        -3017,
        2695,
        2669,
        1892,
        1789,
        UNUSED,
        -1150,
        0,
        UNUSED,
        2633,
        UNUSED,
        UNUSED,
        2968,
        0,
        UNUSED,
        1263,
        674,
        UNUSED,
        1568,
        1816,
        UNUSED,
        264,
        UNUSED,
        UNUSED,
        UNUSED,
        908,
        2229,
        UNUSED,
        -41,
        UNUSED,
        95,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        -4671,
        6309,
        0,
        1618,
        3251,
        4532,
        115,
        1547,
        UNUSED,
        -652,
        2207,
        0,
        1322,
        2443,
        1033,
        0,
        0,
        -4800,
        UNUSED,
        UNUSED,
        UNUSED,
        71,
        -2982,
        0,
        1446,
        UNUSED,
        UNUSED,
        -5760,
        0,
        1009,
        2234,
        UNUSED,
        UNUSED,
        -19,
        -377,
        -28,
        -4476,
        UNUSED,
        867,
        1872,
        1378,
        UNUSED,
        1343,
        1108,
        UNUSED,
        3086,
        1686,
        UNUSED,
        UNUSED,
        UNUSED,
        3372,
        -691,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        125,
        995,
        -33,
        UNUSED,
        UNUSED,
        628,
        2207,
        674,
        1720,
        112,
        UNUSED,
        1061,
        65,
        UNUSED,
        1907,
        244,
        -196,
        0,
        893,
        1398,
        -17,
        1460,
        -367,
        0,
        672,
        886,
        5080,
        UNUSED,
        -885,
        2337,
        3028,
        UNUSED,
        2133,
        729,
        UNUSED,
        -2718,
        1854,
        1135,
        UNUSED,
        585,
        0,
        UNUSED,
        618,
        792,
        857,
        UNUSED,
        0,
        0,
        UNUSED,
        UNUSED,
        2899,
        UNUSED,
        2993,
        UNUSED,
        1341,
        944,
        UNUSED,
        UNUSED,
        2349,
        2409,
        348,
        973,
        4542,
        761,
        UNUSED,
        -836,
        -231,
        592,
        -1982,
        0,
        UNUSED,
        570,
        UNUSED,
        -6464,
        UNUSED,
        -213,
        1792,
        737,
        UNUSED,
        -1291,
        1006,
        -284,
        -5400,
        UNUSED,
        342,
        -1957,
        3399,
        -565,
        UNUSED,
        1003,
        3382,
        1391,
        2195,
        1893,
        1024,
        UNUSED,
        1556,
        673,
        2517,
        UNUSED,
        312,
        1144,
        655,
        UNUSED,
        1056,
        1115,
        UNUSED,
        -1097,
        UNUSED,
        UNUSED,
        888,
        -681,
        1600,
        469,
        UNUSED,
        UNUSED,
        868,
        UNUSED,
        UNUSED,
        UNUSED,
        -1020,
        2869,
        149,
        367,
        2059,
        UNUSED,
        2267,
        14,
        UNUSED,
        UNUSED,
        438,
        153,
        0,
        UNUSED,
        -1480,
        UNUSED,
        0,
        UNUSED,
        -5048,
        672,
        -326,
        UNUSED,
        -729,
        UNUSED,
        1382,
        UNUSED,
        -430,
        1161,
        UNUSED,
        1759,
        1723,
        1958,
        UNUSED,
        UNUSED,
        -1918,
        UNUSED,
        UNUSED,
        1384,
        -2132,
        -914,
        1177,
        711,
        219,
        UNUSED,
        UNUSED,
        -387,
        -5143,
        1584,
        257,
        0,
        -85,
        -507,
        1392,
        -3,
        -1794,
        1916,
        -662,
        106,
        UNUSED,
        UNUSED,
        1046,
        0,
        -1652,
        UNUSED,
        1474,
        -948,
        831,
        248,
        -379,
        938,
        2747,
        2407,
        UNUSED,
        UNUSED,
        781,
        UNUSED,
        UNUSED,
        UNUSED,
        -3569,
        -887,
        4080,
        UNUSED,
        651,
        1645,
        UNUSED,
        UNUSED,
        1787,
        1029,
        UNUSED,
        UNUSED,
        1894,
        UNUSED,
        -1689,
        -2712,
        4734,
        UNUSED,
        945,
        UNUSED,
        UNUSED,
        UNUSED,
        619,
        5269,
        UNUSED,
        522,
        UNUSED,
        -1574,
        360,
        UNUSED,
        0,
        -216,
        1986,
        -1068,
        658,
        700,
        785,
        -1252,
        1683,
        1991,
        -2137,
        1590,
        UNUSED,
        UNUSED,
        -4150,
        -24,
        UNUSED,
        UNUSED,
        UNUSED,
        570,
        15,
        0,
        1649,
        UNUSED,
        UNUSED,
        UNUSED,
        375,
        UNUSED,
        1327,
        2759,
        -519,
        1343,
        702,
        -332,
        1236,
        UNUSED,
        1291,
        111,
        262,
        UNUSED,
        UNUSED,
        1706,
        UNUSED,
        -540,
        UNUSED,
        -827,
        662,
        836,
        UNUSED,
        UNUSED,
        2582,
        3965,
        103,
        363,
        1026,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        -604,
        -156,
        UNUSED,
        -3308,
        623,
        -1472,
        UNUSED,
        -287,
        -1941,
        UNUSED,
        UNUSED,
        0,
        0,
        548,
        1637,
        UNUSED,
        UNUSED,
        UNUSED,
        -1569,
        2434,
        207,
        0,
        UNUSED,
        -168,
        UNUSED,
        UNUSED,
        1432,
        UNUSED,
        -1,
        UNUSED,
        -171,
        -772,
        791,
        -4416,
        4155,
        1765,
        1197,
        UNUSED,
        1342,
        699,
        UNUSED,
        UNUSED,
        3262,
        UNUSED,
        UNUSED,
        -1035,
        UNUSED,
        1639,
        185,
        657,
        1881,
        UNUSED,
        -1803,
        -3937,
        UNUSED,
        1911,
        UNUSED,
        1980,
        -3560,
        UNUSED,
        -467,
        -120,
        UNUSED,
        1715,
        -1327,
        UNUSED,
        UNUSED,
        -147,
        UNUSED,
        1992,
        2076,
        -1363,
        UNUSED,
        UNUSED,
        1681,
        1580,
        230,
        105,
        559,
        UNUSED,
        1399,
        UNUSED,
        2174,
        804,
        118,
        -1648,
        1098,
        UNUSED,
        446,
        1951,
        UNUSED,
        UNUSED,
        UNUSED,
        -5,
        1638,
        1998,
        602,
        UNUSED,
        UNUSED,
        UNUSED,
        -1671,
        UNUSED,
        4650,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        -4951,
        -5846,
        435,
        UNUSED,
        1928,
        1582,
        UNUSED,
        1795,
        -1782,
        96,
        1011,
        -4842,
        UNUSED,
        1511,
        231,
        -1559,
        UNUSED,
        UNUSED,
        21,
        2188,
        3590,
        -114,
        UNUSED,
        2173,
        181,
        1632,
        1271,
        0,
        641,
        421,
        1853,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        600,
        1933,
        UNUSED,
        1700,
        UNUSED,
        1559,
        UNUSED,
        -275,
        UNUSED,
        -4972,
        UNUSED,
        195,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        3367,
        2122,
        177,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        -62,
        374,
        20,
        800,
        1605,
        409,
        UNUSED,
        3378,
        -5495,
        1546,
        -3156,
        -115,
        51,
        957,
        UNUSED,
        495,
        0,
        1305,
        686,
        1501,
        981,
        412,
        UNUSED,
        -1463,
        UNUSED,
        148,
        0,
        UNUSED,
        288,
        1333,
        1731,
        1435,
        UNUSED,
        UNUSED,
        1642,
        970,
        353,
        4265,
        681,
        UNUSED,
        1871,
        UNUSED,
        256,
        347,
        UNUSED,
        -694,
        1097,
        UNUSED,
        UNUSED,
        2204,
        914,
        -927,
        -925,
        2158,
        1094,
        1586,
        2173,
        46,
        UNUSED,
        UNUSED,
        31,
        360,
        1354,
        992,
        -269,
        1136,
        -5131,
        2061,
        -3547,
        UNUSED,
        UNUSED,
        544,
        -5715,
        2066,
        4078,
        UNUSED,
        UNUSED,
        -1082,
        1436,
        UNUSED,
        -433,
        UNUSED,
        UNUSED,
        -568,
        631,
        1775,
        -2384,
        2717,
        -4233,
        457,
        -787,
        -140,
        UNUSED,
        960,
        1127,
        UNUSED,
        UNUSED,
        -772,
        0,
        1659,
        26,
        3601,
        2292,
        UNUSED,
        3295,
        379,
        UNUSED,
        1256,
        UNUSED,
        -446,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1882,
        UNUSED,
        UNUSED,
        1117,
        -381,
        -2769,
        832,
        505,
        1699,
        1348,
        -296,
        UNUSED,
        872,
        -1086,
        UNUSED,
        866,
        1544,
        -293,
        UNUSED,
        1034,
        UNUSED,
        UNUSED,
        950,
        1962,
        -297,
        1358,
        UNUSED,
        1099,
        -1975,
        373,
        -775,
        3037,
        352,
        1113,
        355,
        1086,
        UNUSED,
        -4755,
        -184,
        UNUSED,
        3633,
        2405,
        UNUSED,
        UNUSED,
        UNUSED,
        -2978,
        -1218,
        UNUSED,
        1983,
        UNUSED,
        1014,
        211,
        -603,
        -18,
        3731,
        UNUSED,
        -5823,
        UNUSED,
        UNUSED,
        1407,
        UNUSED,
        1248,
        331,
        UNUSED,
        UNUSED,
        1488,
        UNUSED,
        949,
        1315,
        UNUSED,
        2475,
        UNUSED,
        UNUSED,
        2971,
        -2172,
        -6339,
        -3549,
        2022,
        UNUSED,
        -11,
        UNUSED,
        1600,
        5399,
        1426,
        763,
        345,
        2842,
        1050,
        1138,
        0,
        UNUSED,
        1087,
        2279,
        -1647,
        1884,
        -706,
        UNUSED,
        UNUSED,
        UNUSED,
        1771,
        1993,
        UNUSED,
        UNUSED,
        530,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        -677,
        UNUSED,
        1098,
        UNUSED,
        261,
        UNUSED,
        UNUSED,
        1746,
        UNUSED,
        -307,
        531,
        535,
        2818,
        990,
        UNUSED,
        UNUSED,
        1680,
        UNUSED,
        UNUSED,
        1880,
        UNUSED,
        -2373,
        1499,
        572,
        UNUSED,
        -3436,
        164,
        1283,
        1751,
    };
    static const int16_t hash2[2048] = {
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        0,
        0,
        UNUSED,
        UNUSED,
        0,
        1472,
        -974,
        0,
        UNUSED,
        UNUSED,
        0,
        0,
        UNUSED,
        0,
        UNUSED,
        0,
        UNUSED,
        0,
        -2379,
        0,
        0,
        UNUSED,
        0,
        4274,
        UNUSED,
        UNUSED,
        0,
        -266,
        0,
        UNUSED,
        UNUSED,
        3978,
        UNUSED,
        0,
        UNUSED,
        0,
        0,
        4896,
        UNUSED,
        UNUSED,
        6613,
        0,
        0,
        6171,
        0,
        0,
        0,
        UNUSED,
        4569,
        -19,
        1957,
        0,
        915,
        0,
        UNUSED,
        0,
        0,
        0,
        2514,
        1287,
        UNUSED,
        UNUSED,
        1110,
        -3671,
        0,
        0,
        0,
        0,
        UNUSED,
        985,
        UNUSED,
        0,
        42,
        0,
        6667,
        496,
        0,
        6725,
        2355,
        UNUSED,
        UNUSED,
        498,
        0,
        0,
        UNUSED,
        1718,
        2152,
        651,
        2472,
        UNUSED,
        -66,
        -245,
        0,
        1542,
        0,
        0,
        UNUSED,
        552,
        UNUSED,
        UNUSED,
        UNUSED,
        1497,
        0,
        -177,
        -983,
        0,
        1339,
        5357,
        -123,
        0,
        0,
        0,
        6403,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        -1276,
        3592,
        UNUSED,
        397,
        UNUSED,
        784,
        UNUSED,
        0,
        0,
        483,
        5860,
        UNUSED,
        3681,
        0,
        UNUSED,
        UNUSED,
        -3372,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        0,
        0,
        UNUSED,
        0,
        868,
        UNUSED,
        0,
        UNUSED,
        -265,
        -4158,
        0,
        UNUSED,
        0,
        UNUSED,
        -2124,
        5901,
        -2002,
        UNUSED,
        2312,
        0,
        0,
        0,
        UNUSED,
        427,
        0,
        1535,
        0,
        0,
        1269,
        0,
        UNUSED,
        UNUSED,
        26,
        UNUSED,
        190,
        UNUSED,
        UNUSED,
        2083,
        UNUSED,
        -445,
        0,
        1318,
        0,
        0,
        UNUSED,
        UNUSED,
        2083,
        0,
        1119,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        0,
        0,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        118,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        0,
        0,
        350,
        0,
        UNUSED,
        0,
        UNUSED,
        6568,
        -1337,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        -530,
        8,
        3013,
        UNUSED,
        0,
        UNUSED,
        0,
        6549,
        UNUSED,
        0,
        UNUSED,
        736,
        0,
        -1468,
        0,
        -237,
        0,
        207,
        0,
        -225,
        -496,
        80,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        -615,
        UNUSED,
        0,
        -1745,
        960,
        6063,
        -1233,
        UNUSED,
        4543,
        1874,
        UNUSED,
        UNUSED,
        UNUSED,
        4821,
        -435,
        0,
        0,
        0,
        219,
        UNUSED,
        0,
        2451,
        UNUSED,
        UNUSED,
        0,
        5245,
        1193,
        0,
        0,
        1867,
        UNUSED,
        -1695,
        0,
        -322,
        UNUSED,
        -679,
        2550,
        87,
        UNUSED,
        UNUSED,
        -920,
        UNUSED,
        6072,
        0,
        UNUSED,
        0,
        221,
        1969,
        97,
        -4373,
        UNUSED,
        1803,
        0,
        762,
        UNUSED,
        684,
        1023,
        UNUSED,
        951,
        158,
        -1248,
        UNUSED,
        902,
        0,
        0,
        UNUSED,
        494,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        -689,
        UNUSED,
        346,
        0,
        2204,
        161,
        399,
        0,
        0,
        UNUSED,
        2875,
        313,
        UNUSED,
        0,
        6736,
        1898,
        3441,
        UNUSED,
        1395,
        UNUSED,
        879,
        1450,
        UNUSED,
        UNUSED,
        0,
        -3327,
        0,
        -199,
        UNUSED,
        0,
        820,
        1956,
        UNUSED,
        0,
        UNUSED,
        0,
        UNUSED,
        0,
        1307,
        403,
        0,
        0,
        -4193,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        0,
        0,
        142,
        0,
        UNUSED,
        3020,
        -1092,
        UNUSED,
        UNUSED,
        0,
        1978,
        6022,
        5694,
        UNUSED,
        0,
        UNUSED,
        -170,
        UNUSED,
        UNUSED,
        7,
        0,
        UNUSED,
        -1645,
        UNUSED,
        1675,
        0,
        UNUSED,
        0,
        758,
        UNUSED,
        0,
        UNUSED,
        -1578,
        UNUSED,
        1125,
        1521,
        UNUSED,
        1011,
        1492,
        0,
        2143,
        UNUSED,
        0,
        594,
        UNUSED,
        2790,
        451,
        UNUSED,
        799,
        0,
        1645,
        1039,
        -880,
        0,
        UNUSED,
        -758,
        UNUSED,
        1557,
        UNUSED,
        -2405,
        1391,
        7334,
        0,
        2580,
        -2658,
        UNUSED,
        797,
        UNUSED,
        803,
        0,
        1834,
        UNUSED,
        UNUSED,
        0,
        1567,
        0,
        1512,
        1765,
        1319,
        -742,
        311,
        779,
        -364,
        -2507,
        20,
        UNUSED,
        4446,
        1875,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        2183,
        266,
        0,
        -1476,
        UNUSED,
        1066,
        731,
        UNUSED,
        0,
        7492,
        0,
        480,
        UNUSED,
        0,
        8667,
        UNUSED,
        -767,
        2030,
        0,
        3304,
        UNUSED,
        2152,
        1065,
        0,
        UNUSED,
        5065,
        UNUSED,
        3750,
        0,
        UNUSED,
        1257,
        UNUSED,
        -1412,
        516,
        2010,
        0,
        -129,
        UNUSED,
        UNUSED,
        0,
        938,
        1980,
        UNUSED,
        UNUSED,
        -166,
        -1470,
        0,
        UNUSED,
        UNUSED,
        96,
        3085,
        UNUSED,
        UNUSED,
        1489,
        1980,
        1970,
        UNUSED,
        -4103,
        396,
        0,
        -5770,
        UNUSED,
        3827,
        UNUSED,
        3761,
        1785,
        296,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        0,
        1137,
        -1915,
        UNUSED,
        0,
        0,
        UNUSED,
        3501,
        -1376,
        520,
        UNUSED,
        UNUSED,
        2725,
        6558,
        1707,
        UNUSED,
        0,
        1186,
        -2208,
        1536,
        640,
        UNUSED,
        UNUSED,
        428,
        0,
        -7675,
        891,
        5372,
        1696,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        -494,
        3657,
        UNUSED,
        232,
        UNUSED,
        0,
        -2887,
        0,
        UNUSED,
        -640,
        UNUSED,
        6001,
        0,
        UNUSED,
        UNUSED,
        2581,
        192,
        -697,
        213,
        UNUSED,
        UNUSED,
        -1164,
        -670,
        UNUSED,
        1495,
        0,
        1207,
        0,
        -68,
        0,
        -689,
        UNUSED,
        -311,
        -85,
        UNUSED,
        -1196,
        1038,
        UNUSED,
        0,
        0,
        0,
        UNUSED,
        479,
        UNUSED,
        0,
        1762,
        UNUSED,
        0,
        0,
        1648,
        UNUSED,
        0,
        UNUSED,
        2198,
        -1313,
        856,
        UNUSED,
        472,
        UNUSED,
        -3452,
        UNUSED,
        0,
        -1644,
        -9,
        UNUSED,
        0,
        -977,
        UNUSED,
        UNUSED,
        0,
        289,
        UNUSED,
        -351,
        -835,
        UNUSED,
        2679,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        2449,
        1219,
        876,
        1853,
        0,
        UNUSED,
        909,
        UNUSED,
        UNUSED,
        678,
        UNUSED,
        UNUSED,
        UNUSED,
        -1330,
        1487,
        UNUSED,
        2014,
        UNUSED,
        UNUSED,
        6430,
        345,
        UNUSED,
        1412,
        UNUSED,
        0,
        1259,
        808,
        1726,
        UNUSED,
        UNUSED,
        UNUSED,
        -2499,
        -800,
        3121,
        0,
        UNUSED,
        0,
        -6,
        UNUSED,
        -2319,
        UNUSED,
        1239,
        1318,
        105,
        786,
        2073,
        554,
        -647,
        679,
        1707,
        1318,
        5022,
        UNUSED,
        1389,
        1812,
        3210,
        943,
        2001,
        562,
        666,
        UNUSED,
        UNUSED,
        1135,
        UNUSED,
        3263,
        3168,
        1804,
        0,
        UNUSED,
        -3933,
        0,
        493,
        1221,
        124,
        UNUSED,
        0,
        5136,
        478,
        1583,
        5188,
        UNUSED,
        1713,
        UNUSED,
        779,
        UNUSED,
        -1207,
        UNUSED,
        0,
        -1033,
        -1450,
        2075,
        UNUSED,
        -766,
        UNUSED,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        -454,
        -425,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        -1385,
        0,
        UNUSED,
        -3914,
        580,
        -1449,
        -115,
        UNUSED,
        0,
        0,
        UNUSED,
        -651,
        UNUSED,
        130,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1836,
        -638,
        5,
        UNUSED,
        374,
        0,
        UNUSED,
        0,
        868,
        UNUSED,
        2641,
        210,
        UNUSED,
        4683,
        UNUSED,
        UNUSED,
        2228,
        0,
        -949,
        440,
        0,
        867,
        -671,
        UNUSED,
        2364,
        UNUSED,
        -1137,
        UNUSED,
        0,
        -2755,
        -177,
        UNUSED,
        -380,
        2071,
        UNUSED,
        0,
        869,
        UNUSED,
        UNUSED,
        -2775,
        1560,
        UNUSED,
        -748,
        -1272,
        1869,
        1490,
        UNUSED,
        -1286,
        0,
        -61,
        0,
        UNUSED,
        UNUSED,
        -1437,
        UNUSED,
        UNUSED,
        1928,
        -1037,
        2096,
        201,
        -2813,
        6059,
        UNUSED,
        UNUSED,
        -1776,
        1633,
        3287,
        UNUSED,
        -1959,
        UNUSED,
        UNUSED,
        UNUSED,
        -790,
        0,
        1494,
        0,
        1041,
        1837,
        UNUSED,
        3820,
        UNUSED,
        -3745,
        UNUSED,
        UNUSED,
        85,
        -429,
        0,
        0,
        2138,
        1605,
        1982,
        -557,
        5437,
        517,
        0,
        -1011,
        -1802,
        UNUSED,
        UNUSED,
        4615,
        1340,
        0,
        1253,
        UNUSED,
        -1998,
        0,
        UNUSED,
        UNUSED,
        -1517,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        1470,
        UNUSED,
        796,
        UNUSED,
        -865,
        912,
        4325,
        1790,
        87,
        2197,
        UNUSED,
        304,
        1903,
        0,
        855,
        0,
        6935,
        UNUSED,
        1504,
        -1752,
        1377,
        1860,
        UNUSED,
        2038,
        376,
        -4962,
        2110,
        1480,
        UNUSED,
        UNUSED,
        UNUSED,
        -2082,
        0,
        -1019,
        418,
        6347,
        1314,
        UNUSED,
        UNUSED,
        217,
        UNUSED,
        UNUSED,
        2084,
        798,
        1085,
        58,
        UNUSED,
        UNUSED,
        0,
        1147,
        UNUSED,
        -86,
        844,
        71,
        UNUSED,
        860,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        194,
        1460,
        1654,
        0,
        845,
        UNUSED,
        UNUSED,
        UNUSED,
        6483,
        UNUSED,
        323,
        1933,
        -364,
        -2149,
        UNUSED,
        UNUSED,
        751,
        UNUSED,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        837,
        870,
        1502,
        UNUSED,
        UNUSED,
        0,
        402,
        -1813,
        1076,
        2111,
        UNUSED,
        UNUSED,
        -1718,
        8048,
        UNUSED,
        881,
        UNUSED,
        1780,
        -1787,
        0,
        -104,
        UNUSED,
        0,
        -631,
        0,
        1335,
        1624,
        UNUSED,
        UNUSED,
        410,
        UNUSED,
        3614,
        -357,
        1139,
        -1058,
        146,
        980,
        346,
        1763,
        1337,
        214,
        UNUSED,
        UNUSED,
        UNUSED,
        690,
        706,
        -2423,
        0,
        1243,
        -2211,
        2456,
        0,
        383,
        394,
        1463,
        0,
        1294,
        UNUSED,
        UNUSED,
        UNUSED,
        2426,
        -371,
        -826,
        5127,
        UNUSED,
        387,
        UNUSED,
        1161,
        UNUSED,
        -206,
        530,
        925,
        UNUSED,
        1727,
        0,
        UNUSED,
        2323,
        251,
        UNUSED,
        -1757,
        UNUSED,
        430,
        UNUSED,
        1747,
        881,
        UNUSED,
        UNUSED,
        UNUSED,
        545,
        UNUSED,
        -308,
        UNUSED,
        UNUSED,
        UNUSED,
        273,
        UNUSED,
        -738,
        -79,
        898,
        UNUSED,
        6042,
        -256,
        UNUSED,
        UNUSED,
        0,
        1055,
        0,
        UNUSED,
        -3487,
        -708,
        UNUSED,
        UNUSED,
        UNUSED,
        1855,
        UNUSED,
        328,
        5871,
        UNUSED,
        UNUSED,
        2485,
        UNUSED,
        1725,
        UNUSED,
        UNUSED,
        0,
        416,
        UNUSED,
        1848,
        2378,
        -318,
        1723,
        -313,
        0,
        1389,
        261,
        0,
        UNUSED,
        338,
        1974,
        3542,
        2118,
        UNUSED,
        -2280,
        UNUSED,
        UNUSED,
        UNUSED,
        1451,
        0,
        -922,
        -168,
        UNUSED,
        0,
        -3422,
        -2913,
        -1951,
        UNUSED,
        4760,
        1989,
        0,
        -1029,
        UNUSED,
        -567,
        UNUSED,
        848,
        UNUSED,
        0,
        1457,
        UNUSED,
        -712,
        952,
        1537,
        -738,
        1177,
        UNUSED,
        -747,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        137,
        -2317,
        -250,
        UNUSED,
        UNUSED,
        UNUSED,
        28,
        209,
        258,
        0,
        2547,
        UNUSED,
        2121,
        UNUSED,
        1761,
        599,
        UNUSED,
        50,
        UNUSED,
        -1524,
        UNUSED,
        UNUSED,
        851,
        874,
        UNUSED,
        4723,
        UNUSED,
        44,
        1887,
        UNUSED,
        0,
        4058,
        828,
        -974,
        1009,
        UNUSED,
        533,
        UNUSED,
        99,
        1162,
        0,
        UNUSED,
        0,
        -4206,
        700,
        UNUSED,
        UNUSED,
        -1552,
        1790,
        UNUSED,
        -1070,
        UNUSED,
        -4537,
        UNUSED,
        476,
        637,
        803,
        UNUSED,
        5841,
        0,
        388,
        116,
        -1046,
        -2721,
        -5062,
        UNUSED,
        1671,
        2089,
        1713,
        UNUSED,
        1732,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        -1440,
        UNUSED,
        1685,
        1885,
        UNUSED,
        -981,
        1160,
        UNUSED,
        785,
        UNUSED,
        1930,
        -66,
        UNUSED,
        -1935,
        -1829,
        -1412,
        -696,
        UNUSED,
        0,
        331,
        226,
        1709,
        0,
        1656,
        2225,
        UNUSED,
        UNUSED,
        -371,
        0,
        UNUSED,
        -2019,
        UNUSED,
        977,
        -172,
        1341,
        UNUSED,
        -68,
        -1343,
        UNUSED,
        1486,
        3064,
        0,
        297,
        502,
        -197,
        575,
        -283,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1836,
        0,
        UNUSED,
        1430,
        6220,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1598,
        641,
        0,
        482,
        UNUSED,
        -2,
        822,
        UNUSED,
        -1879,
        596,
        1145,
        UNUSED,
        0,
        3271,
        UNUSED,
        905,
        UNUSED,
        4634,
        UNUSED,
        -303,
        -2077,
        2134,
        UNUSED,
        UNUSED,
        193,
        1290,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        9,
        56,
        -7633,
        2225,
        1158,
        1492,
        -1232,
        UNUSED,
        UNUSED,
        UNUSED,
        -497,
        UNUSED,
        UNUSED,
        -1603,
        758,
        2096,
        518,
        1602,
        876,
        -1591,
        UNUSED,
        1563,
        159,
        UNUSED,
        -1331,
        1986,
        UNUSED,
        557,
        4630,
        0,
        5092,
        UNUSED,
        UNUSED,
        UNUSED,
        384,
        UNUSED,
        UNUSED,
        5112,
        UNUSED,
        UNUSED,
        5366,
        747,
        1558,
        -31,
        UNUSED,
        -21,
        0,
        UNUSED,
        UNUSED,
        1985,
        UNUSED,
        -698,
        1830,
        -2868,
        400,
        1579,
        1883,
        931,
        267,
        UNUSED,
        2164,
        7810,
        UNUSED,
        -258,
        681,
        UNUSED,
        360,
        548,
        -5370,
        695,
        1734,
        1786,
        1715,
        UNUSED,
        UNUSED,
        -365,
        5015,
        -2192,
        1885,
        UNUSED,
        UNUSED,
        2149,
        813,
        -381,
        -296,
        4580,
        825,
        961,
        UNUSED,
        1167,
        -1251,
        UNUSED,
        385,
        UNUSED,
        UNUSED,
        2181,
        1684,
        2162,
        1949,
        UNUSED,
        0,
        UNUSED,
        0,
        187,
        319,
        301,
        1513,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1485,
        365,
        UNUSED,
        1886,
        1631,
        UNUSED,
        2008,
        791,
        2710,
        3002,
        2143,
        1058,
        344,
        199,
        -3071,
        2097,
        UNUSED,
        UNUSED,
        256,
        0,
        -238,
        1634,
        1809,
        1767,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1162,
        UNUSED,
        -2122,
        1353,
        549,
        -3441,
        826,
        1530,
        978,
        UNUSED,
        7062,
        1566,
        1201,
        1119,
        1325,
        -671,
        -990,
        UNUSED,
        UNUSED,
        -597,
        434,
        1324,
        110,
        -985,
        0,
        UNUSED,
        1343,
        UNUSED,
        -643,
        UNUSED,
        -2308,
        381,
        770,
        1872,
        UNUSED,
        1527,
        0,
        UNUSED,
        1908,
        8626,
        UNUSED,
        472,
        265,
        -379,
        572,
        UNUSED,
        UNUSED,
        347,
        415,
        898,
        2141,
        -1780,
        1551,
        UNUSED,
        371,
        UNUSED,
        0,
        UNUSED,
        UNUSED,
        -769,
        UNUSED,
        0,
        -218,
        533,
        1961,
        UNUSED,
        UNUSED,
        583,
        -619,
        6993,
        2500,
        954,
        986,
        91,
        UNUSED,
        2097,
        5278,
        559,
        780,
        UNUSED,
        UNUSED,
        -545,
        UNUSED,
        941,
        1495,
        UNUSED,
        605,
        -3008,
        UNUSED,
        70,
        160,
        1760,
        UNUSED,
        UNUSED,
        48,
        -1185,
        -1029,
        -712,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        -654,
        -1655,
        47,
        543,
        UNUSED,
        UNUSED,
        1563,
        UNUSED,
        4801,
        UNUSED,
        1445,
        -1124,
        UNUSED,
        1518,
        640,
        -990,
        830,
        311,
        402,
        5093,
        1831,
        UNUSED,
        2001,
        -746,
        86,
        -555,
        1247,
        UNUSED,
        UNUSED,
        UNUSED,
        -1051,
        2136,
        6816,
        1577,
        UNUSED,
        784,
        1806,
        0,
        UNUSED,
        693,
        2943,
        2089,
        2155,
        4006,
        202,
        1673,
        UNUSED,
        UNUSED,
        543,
        UNUSED,
        569,
        845,
        UNUSED,
        602,
        UNUSED,
        UNUSED,
        2168,
        -476,
        -3014,
        979,
        123,
        UNUSED,
        445,
        2067,
        119,
        1927,
        -1208,
        -84,
        UNUSED,
        549,
        UNUSED,
        -1323,
        1082,
        700,
        2701,
        -30,
        1527,
        UNUSED,
        UNUSED,
        919,
        814,
        -8,
        162,
        -3062,
        871,
        1007,
        172,
        UNUSED,
        1986,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        5544,
        248,
        -1515,
        834,
        609,
        -363,
        -1601,
        -130,
        UNUSED,
        1229,
        UNUSED,
        43,
        UNUSED,
        -1893,
        UNUSED,
        -1192,
        -415,
        UNUSED,
        UNUSED,
        1575,
        UNUSED,
        -265,
        1267,
        -774,
        421,
        -78,
        -4444,
        778,
        UNUSED,
        -664,
        5376,
        UNUSED,
        UNUSED,
        2070,
        144,
        -5137,
        206,
        UNUSED,
        UNUSED,
        UNUSED,
        4043,
        447,
        0,
        -3008,
        UNUSED,
        UNUSED,
        2019,
        1372,
        5727,
        -2084,
        -716,
        0,
        -193,
        102,
        -276,
        0,
        UNUSED,
        -824,
        622,
        -4083,
        -105,
        2062,
        2977,
        3665,
        2600,
        550,
        -1121,
        UNUSED,
        1796,
        1814,
        93,
        UNUSED,
        -282,
        UNUSED,
        486,
        UNUSED,
        521,
        1385,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1537,
        39,
        1282,
        1399,
        0,
        UNUSED,
        760,
        692,
        -297,
        2056,
        -1524,
        395,
        UNUSED,
        1323,
        1725,
        UNUSED,
        UNUSED,
        743,
        245,
        1344,
        6561,
        UNUSED,
        1361,
        UNUSED,
        -428,
        2093,
        UNUSED,
        UNUSED,
        2000,
        5140,
        1084,
        215,
        UNUSED,
        -1044,
        UNUSED,
        0,
        UNUSED,
        1457,
        817,
        6657,
        -457,
        2070,
        UNUSED,
        -1894,
        1704,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1283,
        52,
        UNUSED,
        749,
        475,
        457,
        -3245,
        UNUSED,
        -1971,
        UNUSED,
        UNUSED,
        5915,
        3041,
        UNUSED,
        UNUSED,
        -351,
        49,
        1959,
        733,
        317,
        -199,
        UNUSED,
        240,
        1293,
        UNUSED,
        -2077,
        UNUSED,
        UNUSED,
        653,
        UNUSED,
        UNUSED,
        UNUSED,
        1841,
        2018,
        317,
        UNUSED,
        UNUSED,
        -278,
        150,
        UNUSED,
        -142,
        1637,
        UNUSED,
        UNUSED,
        165,
        432,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1766,
        -1333,
        UNUSED,
        753,
        UNUSED,
        1231,
        3803,
        1543,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        2111,
        1779,
        616,
        3802,
        -3028,
        865,
        UNUSED,
        1992,
        1035,
        UNUSED,
        2054,
        4868,
        1165,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        1350,
        7872,
        1449,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        UNUSED,
        614,
        1916,
        705,
        -671,
        UNUSED,
        887,
        1160,
        1912,
        467,
        -2344,
        930,
        0,
        UNUSED,
        UNUSED,
        UNUSED,
        1443,
        1500,
        1124,
        -380,
        1552,
        UNUSED,
        518,
        704,
        -1961,
        UNUSED,
        UNUSED,
        1679,
        2041,
        UNUSED,
        1895,
        -1609,
        2172,
        1651,
        UNUSED,
        354,
        1998,
        696,
        3046,
        6017,
        10,
        -1046,
        UNUSED,
        -1181,
        1018,
        -103,
        UNUSED,
        1423,
        542,
        349,
        1156,
        897,
        828,
        UNUSED,
        535,
        1488,
        UNUSED,
        1165,
        1257,
        1353,
        72,
        463,
        UNUSED,
        46,
        UNUSED,
        UNUSED,
        -1884,
        1469,
        2409,
        1201,
        1947,
        UNUSED,
        UNUSED,
        1337,
        UNUSED,
        UNUSED,
        1902,
        UNUSED,
        1152,
        877,
        794,
        UNUSED,
        UNUSED,
        -1670,
        5586,
        473,
        507,
        644,
        UNUSED,
        1447,
        529,
        2518,
        323,
        UNUSED,
        59,
        1008,
        404,
        34,
        2880,
        -1588,
        UNUSED,
        1006,
        UNUSED,
        762,
        1067,
        1441,
        UNUSED,
        -1414,
        -1671,
        UNUSED,
        3046,
        UNUSED,
        UNUSED,
        UNUSED,
        292,
        1124,
        -285,
        2069,
        257,
        UNUSED,
        -1162,
        658,
        UNUSED,
        790,
        1216,
        -63,
        -1246,
        UNUSED,
        1674,
        1939,
        1889,
        -1821,
        -209,
        UNUSED,
        UNUSED,
        442,
        UNUSED,
        -832,
        2165,
        1578,
        818,
        -1915,
        -3664,
        1501,
        522,
        UNUSED,
        793,
        UNUSED,
        1332,
        809,
        849,
        -49,
        UNUSED,
        UNUSED,
        -2145,
        211,
        -1164,
        396,
        UNUSED,
        1027,
        1647,
        101,
        UNUSED,
        UNUSED,
        136,
        -2613,
        UNUSED,
        UNUSED,
        -2420,
        1809,
        1048,
        921,
        UNUSED,
        2348,
        UNUSED,
    };
    static const struct tokendata tokendata[2216] = {
        { "db", TOKEN_INSN, C_none, 0, I_DB },
        { "dw", TOKEN_INSN, C_none, 0, I_DW },
        { "dd", TOKEN_INSN, C_none, 0, I_DD },
        { "dq", TOKEN_INSN, C_none, 0, I_DQ },
        { "dt", TOKEN_INSN, C_none, 0, I_DT },
        { "do", TOKEN_INSN, C_none, 0, I_DO },
        { "dy", TOKEN_INSN, C_none, 0, I_DY },
        { "dz", TOKEN_INSN, C_none, 0, I_DZ },
        { "resb", TOKEN_INSN, C_none, 0, I_RESB },
        { "resw", TOKEN_INSN, C_none, 0, I_RESW },
        { "resd", TOKEN_INSN, C_none, 0, I_RESD },
        { "resq", TOKEN_INSN, C_none, 0, I_RESQ },
        { "rest", TOKEN_INSN, C_none, 0, I_REST },
        { "reso", TOKEN_INSN, C_none, 0, I_RESO },
        { "resy", TOKEN_INSN, C_none, 0, I_RESY },
        { "resz", TOKEN_INSN, C_none, 0, I_RESZ },
        { "aaa", TOKEN_INSN, C_none, 0, I_AAA },
        { "aad", TOKEN_INSN, C_none, 0, I_AAD },
        { "aam", TOKEN_INSN, C_none, 0, I_AAM },
        { "aas", TOKEN_INSN, C_none, 0, I_AAS },
        { "adc", TOKEN_INSN, C_none, 0, I_ADC },
        { "add", TOKEN_INSN, C_none, 0, I_ADD },
        { "and", TOKEN_INSN, C_none, 0, I_AND },
        { "arpl", TOKEN_INSN, C_none, 0, I_ARPL },
        { "bb0_reset", TOKEN_INSN, C_none, 0, I_BB0_RESET },
        { "bb1_reset", TOKEN_INSN, C_none, 0, I_BB1_RESET },
        { "bound", TOKEN_INSN, C_none, 0, I_BOUND },
        { "bsf", TOKEN_INSN, C_none, 0, I_BSF },
        { "bsr", TOKEN_INSN, C_none, 0, I_BSR },
        { "bswap", TOKEN_INSN, C_none, 0, I_BSWAP },
        { "bt", TOKEN_INSN, C_none, 0, I_BT },
        { "btc", TOKEN_INSN, C_none, 0, I_BTC },
        { "btr", TOKEN_INSN, C_none, 0, I_BTR },
        { "bts", TOKEN_INSN, C_none, 0, I_BTS },
        { "call", TOKEN_INSN, C_none, 0, I_CALL },
        { "cbw", TOKEN_INSN, C_none, 0, I_CBW },
        { "cdq", TOKEN_INSN, C_none, 0, I_CDQ },
        { "cdqe", TOKEN_INSN, C_none, 0, I_CDQE },
        { "clc", TOKEN_INSN, C_none, 0, I_CLC },
        { "cld", TOKEN_INSN, C_none, 0, I_CLD },
        { "cli", TOKEN_INSN, C_none, 0, I_CLI },
        { "clts", TOKEN_INSN, C_none, 0, I_CLTS },
        { "cmc", TOKEN_INSN, C_none, 0, I_CMC },
        { "cmp", TOKEN_INSN, C_none, 0, I_CMP },
        { "cmpsb", TOKEN_INSN, C_none, 0, I_CMPSB },
        { "cmpsd", TOKEN_INSN, C_none, 0, I_CMPSD },
        { "cmpsq", TOKEN_INSN, C_none, 0, I_CMPSQ },
        { "cmpsw", TOKEN_INSN, C_none, 0, I_CMPSW },
        { "cmpxchg", TOKEN_INSN, C_none, 0, I_CMPXCHG },
        { "cmpxchg486", TOKEN_INSN, C_none, 0, I_CMPXCHG486 },
        { "cmpxchg8b", TOKEN_INSN, C_none, 0, I_CMPXCHG8B },
        { "cmpxchg16b", TOKEN_INSN, C_none, 0, I_CMPXCHG16B },
        { "cpuid", TOKEN_INSN, C_none, 0, I_CPUID },
        { "cpu_read", TOKEN_INSN, C_none, 0, I_CPU_READ },
        { "cpu_write", TOKEN_INSN, C_none, 0, I_CPU_WRITE },
        { "cqo", TOKEN_INSN, C_none, 0, I_CQO },
        { "cwd", TOKEN_INSN, C_none, 0, I_CWD },
        { "cwde", TOKEN_INSN, C_none, 0, I_CWDE },
        { "daa", TOKEN_INSN, C_none, 0, I_DAA },
        { "das", TOKEN_INSN, C_none, 0, I_DAS },
        { "dec", TOKEN_INSN, C_none, 0, I_DEC },
        { "div", TOKEN_INSN, C_none, 0, I_DIV },
        { "dmint", TOKEN_INSN, C_none, 0, I_DMINT },
        { "emms", TOKEN_INSN, C_none, 0, I_EMMS },
        { "enter", TOKEN_INSN, C_none, 0, I_ENTER },
        { "equ", TOKEN_INSN, C_none, 0, I_EQU },
        { "f2xm1", TOKEN_INSN, C_none, 0, I_F2XM1 },
        { "fabs", TOKEN_INSN, C_none, 0, I_FABS },
        { "fadd", TOKEN_INSN, C_none, 0, I_FADD },
        { "faddp", TOKEN_INSN, C_none, 0, I_FADDP },
        { "fbld", TOKEN_INSN, C_none, 0, I_FBLD },
        { "fbstp", TOKEN_INSN, C_none, 0, I_FBSTP },
        { "fchs", TOKEN_INSN, C_none, 0, I_FCHS },
        { "fclex", TOKEN_INSN, C_none, 0, I_FCLEX },
        { "fcmovb", TOKEN_INSN, C_none, 0, I_FCMOVB },
        { "fcmovbe", TOKEN_INSN, C_none, 0, I_FCMOVBE },
        { "fcmove", TOKEN_INSN, C_none, 0, I_FCMOVE },
        { "fcmovnb", TOKEN_INSN, C_none, 0, I_FCMOVNB },
        { "fcmovnbe", TOKEN_INSN, C_none, 0, I_FCMOVNBE },
        { "fcmovne", TOKEN_INSN, C_none, 0, I_FCMOVNE },
        { "fcmovnu", TOKEN_INSN, C_none, 0, I_FCMOVNU },
        { "fcmovu", TOKEN_INSN, C_none, 0, I_FCMOVU },
        { "fcom", TOKEN_INSN, C_none, 0, I_FCOM },
        { "fcomi", TOKEN_INSN, C_none, 0, I_FCOMI },
        { "fcomip", TOKEN_INSN, C_none, 0, I_FCOMIP },
        { "fcomp", TOKEN_INSN, C_none, 0, I_FCOMP },
        { "fcompp", TOKEN_INSN, C_none, 0, I_FCOMPP },
        { "fcos", TOKEN_INSN, C_none, 0, I_FCOS },
        { "fdecstp", TOKEN_INSN, C_none, 0, I_FDECSTP },
        { "fdisi", TOKEN_INSN, C_none, 0, I_FDISI },
        { "fdiv", TOKEN_INSN, C_none, 0, I_FDIV },
        { "fdivp", TOKEN_INSN, C_none, 0, I_FDIVP },
        { "fdivr", TOKEN_INSN, C_none, 0, I_FDIVR },
        { "fdivrp", TOKEN_INSN, C_none, 0, I_FDIVRP },
        { "femms", TOKEN_INSN, C_none, 0, I_FEMMS },
        { "feni", TOKEN_INSN, C_none, 0, I_FENI },
        { "ffree", TOKEN_INSN, C_none, 0, I_FFREE },
        { "ffreep", TOKEN_INSN, C_none, 0, I_FFREEP },
        { "fiadd", TOKEN_INSN, C_none, 0, I_FIADD },
        { "ficom", TOKEN_INSN, C_none, 0, I_FICOM },
        { "ficomp", TOKEN_INSN, C_none, 0, I_FICOMP },
        { "fidiv", TOKEN_INSN, C_none, 0, I_FIDIV },
        { "fidivr", TOKEN_INSN, C_none, 0, I_FIDIVR },
        { "fild", TOKEN_INSN, C_none, 0, I_FILD },
        { "fimul", TOKEN_INSN, C_none, 0, I_FIMUL },
        { "fincstp", TOKEN_INSN, C_none, 0, I_FINCSTP },
        { "finit", TOKEN_INSN, C_none, 0, I_FINIT },
        { "fist", TOKEN_INSN, C_none, 0, I_FIST },
        { "fistp", TOKEN_INSN, C_none, 0, I_FISTP },
        { "fisttp", TOKEN_INSN, C_none, 0, I_FISTTP },
        { "fisub", TOKEN_INSN, C_none, 0, I_FISUB },
        { "fisubr", TOKEN_INSN, C_none, 0, I_FISUBR },
        { "fld", TOKEN_INSN, C_none, 0, I_FLD },
        { "fld1", TOKEN_INSN, C_none, 0, I_FLD1 },
        { "fldcw", TOKEN_INSN, C_none, 0, I_FLDCW },
        { "fldenv", TOKEN_INSN, C_none, 0, I_FLDENV },
        { "fldl2e", TOKEN_INSN, C_none, 0, I_FLDL2E },
        { "fldl2t", TOKEN_INSN, C_none, 0, I_FLDL2T },
        { "fldlg2", TOKEN_INSN, C_none, 0, I_FLDLG2 },
        { "fldln2", TOKEN_INSN, C_none, 0, I_FLDLN2 },
        { "fldpi", TOKEN_INSN, C_none, 0, I_FLDPI },
        { "fldz", TOKEN_INSN, C_none, 0, I_FLDZ },
        { "fmul", TOKEN_INSN, C_none, 0, I_FMUL },
        { "fmulp", TOKEN_INSN, C_none, 0, I_FMULP },
        { "fnclex", TOKEN_INSN, C_none, 0, I_FNCLEX },
        { "fndisi", TOKEN_INSN, C_none, 0, I_FNDISI },
        { "fneni", TOKEN_INSN, C_none, 0, I_FNENI },
        { "fninit", TOKEN_INSN, C_none, 0, I_FNINIT },
        { "fnop", TOKEN_INSN, C_none, 0, I_FNOP },
        { "fnsave", TOKEN_INSN, C_none, 0, I_FNSAVE },
        { "fnstcw", TOKEN_INSN, C_none, 0, I_FNSTCW },
        { "fnstenv", TOKEN_INSN, C_none, 0, I_FNSTENV },
        { "fnstsw", TOKEN_INSN, C_none, 0, I_FNSTSW },
        { "fpatan", TOKEN_INSN, C_none, 0, I_FPATAN },
        { "fprem", TOKEN_INSN, C_none, 0, I_FPREM },
        { "fprem1", TOKEN_INSN, C_none, 0, I_FPREM1 },
        { "fptan", TOKEN_INSN, C_none, 0, I_FPTAN },
        { "frndint", TOKEN_INSN, C_none, 0, I_FRNDINT },
        { "frstor", TOKEN_INSN, C_none, 0, I_FRSTOR },
        { "fsave", TOKEN_INSN, C_none, 0, I_FSAVE },
        { "fscale", TOKEN_INSN, C_none, 0, I_FSCALE },
        { "fsetpm", TOKEN_INSN, C_none, 0, I_FSETPM },
        { "fsin", TOKEN_INSN, C_none, 0, I_FSIN },
        { "fsincos", TOKEN_INSN, C_none, 0, I_FSINCOS },
        { "fsqrt", TOKEN_INSN, C_none, 0, I_FSQRT },
        { "fst", TOKEN_INSN, C_none, 0, I_FST },
        { "fstcw", TOKEN_INSN, C_none, 0, I_FSTCW },
        { "fstenv", TOKEN_INSN, C_none, 0, I_FSTENV },
        { "fstp", TOKEN_INSN, C_none, 0, I_FSTP },
        { "fstsw", TOKEN_INSN, C_none, 0, I_FSTSW },
        { "fsub", TOKEN_INSN, C_none, 0, I_FSUB },
        { "fsubp", TOKEN_INSN, C_none, 0, I_FSUBP },
        { "fsubr", TOKEN_INSN, C_none, 0, I_FSUBR },
        { "fsubrp", TOKEN_INSN, C_none, 0, I_FSUBRP },
        { "ftst", TOKEN_INSN, C_none, 0, I_FTST },
        { "fucom", TOKEN_INSN, C_none, 0, I_FUCOM },
        { "fucomi", TOKEN_INSN, C_none, 0, I_FUCOMI },
        { "fucomip", TOKEN_INSN, C_none, 0, I_FUCOMIP },
        { "fucomp", TOKEN_INSN, C_none, 0, I_FUCOMP },
        { "fucompp", TOKEN_INSN, C_none, 0, I_FUCOMPP },
        { "fxam", TOKEN_INSN, C_none, 0, I_FXAM },
        { "fxch", TOKEN_INSN, C_none, 0, I_FXCH },
        { "fxtract", TOKEN_INSN, C_none, 0, I_FXTRACT },
        { "fyl2x", TOKEN_INSN, C_none, 0, I_FYL2X },
        { "fyl2xp1", TOKEN_INSN, C_none, 0, I_FYL2XP1 },
        { "hlt", TOKEN_INSN, C_none, 0, I_HLT },
        { "ibts", TOKEN_INSN, C_none, 0, I_IBTS },
        { "icebp", TOKEN_INSN, C_none, 0, I_ICEBP },
        { "idiv", TOKEN_INSN, C_none, 0, I_IDIV },
        { "imul", TOKEN_INSN, C_none, 0, I_IMUL },
        { "in", TOKEN_INSN, C_none, 0, I_IN },
        { "inc", TOKEN_INSN, C_none, 0, I_INC },
        { "incbin", TOKEN_INSN, C_none, 0, I_INCBIN },
        { "insb", TOKEN_INSN, C_none, 0, I_INSB },
        { "insd", TOKEN_INSN, C_none, 0, I_INSD },
        { "insw", TOKEN_INSN, C_none, 0, I_INSW },
        { "int", TOKEN_INSN, C_none, 0, I_INT },
        { "int01", TOKEN_INSN, C_none, 0, I_INT01 },
        { "int1", TOKEN_INSN, C_none, 0, I_INT1 },
        { "int03", TOKEN_INSN, C_none, 0, I_INT03 },
        { "int3", TOKEN_INSN, C_none, 0, I_INT3 },
        { "into", TOKEN_INSN, C_none, 0, I_INTO },
        { "invd", TOKEN_INSN, C_none, 0, I_INVD },
        { "invpcid", TOKEN_INSN, C_none, 0, I_INVPCID },
        { "invlpg", TOKEN_INSN, C_none, 0, I_INVLPG },
        { "invlpga", TOKEN_INSN, C_none, 0, I_INVLPGA },
        { "iret", TOKEN_INSN, C_none, 0, I_IRET },
        { "iretd", TOKEN_INSN, C_none, 0, I_IRETD },
        { "iretq", TOKEN_INSN, C_none, 0, I_IRETQ },
        { "iretw", TOKEN_INSN, C_none, 0, I_IRETW },
        { "jcxz", TOKEN_INSN, C_none, 0, I_JCXZ },
        { "jecxz", TOKEN_INSN, C_none, 0, I_JECXZ },
        { "jrcxz", TOKEN_INSN, C_none, 0, I_JRCXZ },
        { "jmp", TOKEN_INSN, C_none, 0, I_JMP },
        { "jmpe", TOKEN_INSN, C_none, 0, I_JMPE },
        { "lahf", TOKEN_INSN, C_none, 0, I_LAHF },
        { "lar", TOKEN_INSN, C_none, 0, I_LAR },
        { "lds", TOKEN_INSN, C_none, 0, I_LDS },
        { "lea", TOKEN_INSN, C_none, 0, I_LEA },
        { "leave", TOKEN_INSN, C_none, 0, I_LEAVE },
        { "les", TOKEN_INSN, C_none, 0, I_LES },
        { "lfence", TOKEN_INSN, C_none, 0, I_LFENCE },
        { "lfs", TOKEN_INSN, C_none, 0, I_LFS },
        { "lgdt", TOKEN_INSN, C_none, 0, I_LGDT },
        { "lgs", TOKEN_INSN, C_none, 0, I_LGS },
        { "lidt", TOKEN_INSN, C_none, 0, I_LIDT },
        { "lldt", TOKEN_INSN, C_none, 0, I_LLDT },
        { "lmsw", TOKEN_INSN, C_none, 0, I_LMSW },
        { "loadall", TOKEN_INSN, C_none, 0, I_LOADALL },
        { "loadall286", TOKEN_INSN, C_none, 0, I_LOADALL286 },
        { "lodsb", TOKEN_INSN, C_none, 0, I_LODSB },
        { "lodsd", TOKEN_INSN, C_none, 0, I_LODSD },
        { "lodsq", TOKEN_INSN, C_none, 0, I_LODSQ },
        { "lodsw", TOKEN_INSN, C_none, 0, I_LODSW },
        { "loop", TOKEN_INSN, C_none, 0, I_LOOP },
        { "loope", TOKEN_INSN, C_none, 0, I_LOOPE },
        { "loopne", TOKEN_INSN, C_none, 0, I_LOOPNE },
        { "loopnz", TOKEN_INSN, C_none, 0, I_LOOPNZ },
        { "loopz", TOKEN_INSN, C_none, 0, I_LOOPZ },
        { "lsl", TOKEN_INSN, C_none, 0, I_LSL },
        { "lss", TOKEN_INSN, C_none, 0, I_LSS },
        { "ltr", TOKEN_INSN, C_none, 0, I_LTR },
        { "mfence", TOKEN_INSN, C_none, 0, I_MFENCE },
        { "monitor", TOKEN_INSN, C_none, 0, I_MONITOR },
        { "mov", TOKEN_INSN, C_none, 0, I_MOV },
        { "movd", TOKEN_INSN, C_none, 0, I_MOVD },
        { "movq", TOKEN_INSN, C_none, 0, I_MOVQ },
        { "movsb", TOKEN_INSN, C_none, 0, I_MOVSB },
        { "movsd", TOKEN_INSN, C_none, 0, I_MOVSD },
        { "movsq", TOKEN_INSN, C_none, 0, I_MOVSQ },
        { "movsw", TOKEN_INSN, C_none, 0, I_MOVSW },
        { "movsx", TOKEN_INSN, C_none, 0, I_MOVSX },
        { "movsxd", TOKEN_INSN, C_none, 0, I_MOVSXD },
        { "movzx", TOKEN_INSN, C_none, 0, I_MOVZX },
        { "mul", TOKEN_INSN, C_none, 0, I_MUL },
        { "mwait", TOKEN_INSN, C_none, 0, I_MWAIT },
        { "neg", TOKEN_INSN, C_none, 0, I_NEG },
        { "nop", TOKEN_INSN, C_none, 0, I_NOP },
        { "not", TOKEN_INSN, C_none, 0, I_NOT },
        { "or", TOKEN_INSN, C_none, 0, I_OR },
        { "out", TOKEN_INSN, C_none, 0, I_OUT },
        { "outsb", TOKEN_INSN, C_none, 0, I_OUTSB },
        { "outsd", TOKEN_INSN, C_none, 0, I_OUTSD },
        { "outsw", TOKEN_INSN, C_none, 0, I_OUTSW },
        { "packssdw", TOKEN_INSN, C_none, 0, I_PACKSSDW },
        { "packsswb", TOKEN_INSN, C_none, 0, I_PACKSSWB },
        { "packuswb", TOKEN_INSN, C_none, 0, I_PACKUSWB },
        { "paddb", TOKEN_INSN, C_none, 0, I_PADDB },
        { "paddd", TOKEN_INSN, C_none, 0, I_PADDD },
        { "paddsb", TOKEN_INSN, C_none, 0, I_PADDSB },
        { "paddsiw", TOKEN_INSN, C_none, 0, I_PADDSIW },
        { "paddsw", TOKEN_INSN, C_none, 0, I_PADDSW },
        { "paddusb", TOKEN_INSN, C_none, 0, I_PADDUSB },
        { "paddusw", TOKEN_INSN, C_none, 0, I_PADDUSW },
        { "paddw", TOKEN_INSN, C_none, 0, I_PADDW },
        { "pand", TOKEN_INSN, C_none, 0, I_PAND },
        { "pandn", TOKEN_INSN, C_none, 0, I_PANDN },
        { "pause", TOKEN_INSN, C_none, 0, I_PAUSE },
        { "paveb", TOKEN_INSN, C_none, 0, I_PAVEB },
        { "pavgusb", TOKEN_INSN, C_none, 0, I_PAVGUSB },
        { "pcmpeqb", TOKEN_INSN, C_none, 0, I_PCMPEQB },
        { "pcmpeqd", TOKEN_INSN, C_none, 0, I_PCMPEQD },
        { "pcmpeqw", TOKEN_INSN, C_none, 0, I_PCMPEQW },
        { "pcmpgtb", TOKEN_INSN, C_none, 0, I_PCMPGTB },
        { "pcmpgtd", TOKEN_INSN, C_none, 0, I_PCMPGTD },
        { "pcmpgtw", TOKEN_INSN, C_none, 0, I_PCMPGTW },
        { "pdistib", TOKEN_INSN, C_none, 0, I_PDISTIB },
        { "pf2id", TOKEN_INSN, C_none, 0, I_PF2ID },
        { "pfacc", TOKEN_INSN, C_none, 0, I_PFACC },
        { "pfadd", TOKEN_INSN, C_none, 0, I_PFADD },
        { "pfcmpeq", TOKEN_INSN, C_none, 0, I_PFCMPEQ },
        { "pfcmpge", TOKEN_INSN, C_none, 0, I_PFCMPGE },
        { "pfcmpgt", TOKEN_INSN, C_none, 0, I_PFCMPGT },
        { "pfmax", TOKEN_INSN, C_none, 0, I_PFMAX },
        { "pfmin", TOKEN_INSN, C_none, 0, I_PFMIN },
        { "pfmul", TOKEN_INSN, C_none, 0, I_PFMUL },
        { "pfrcp", TOKEN_INSN, C_none, 0, I_PFRCP },
        { "pfrcpit1", TOKEN_INSN, C_none, 0, I_PFRCPIT1 },
        { "pfrcpit2", TOKEN_INSN, C_none, 0, I_PFRCPIT2 },
        { "pfrsqit1", TOKEN_INSN, C_none, 0, I_PFRSQIT1 },
        { "pfrsqrt", TOKEN_INSN, C_none, 0, I_PFRSQRT },
        { "pfsub", TOKEN_INSN, C_none, 0, I_PFSUB },
        { "pfsubr", TOKEN_INSN, C_none, 0, I_PFSUBR },
        { "pi2fd", TOKEN_INSN, C_none, 0, I_PI2FD },
        { "pmachriw", TOKEN_INSN, C_none, 0, I_PMACHRIW },
        { "pmaddwd", TOKEN_INSN, C_none, 0, I_PMADDWD },
        { "pmagw", TOKEN_INSN, C_none, 0, I_PMAGW },
        { "pmulhriw", TOKEN_INSN, C_none, 0, I_PMULHRIW },
        { "pmulhrwa", TOKEN_INSN, C_none, 0, I_PMULHRWA },
        { "pmulhrwc", TOKEN_INSN, C_none, 0, I_PMULHRWC },
        { "pmulhw", TOKEN_INSN, C_none, 0, I_PMULHW },
        { "pmullw", TOKEN_INSN, C_none, 0, I_PMULLW },
        { "pmvgezb", TOKEN_INSN, C_none, 0, I_PMVGEZB },
        { "pmvlzb", TOKEN_INSN, C_none, 0, I_PMVLZB },
        { "pmvnzb", TOKEN_INSN, C_none, 0, I_PMVNZB },
        { "pmvzb", TOKEN_INSN, C_none, 0, I_PMVZB },
        { "pop", TOKEN_INSN, C_none, 0, I_POP },
        { "popa", TOKEN_INSN, C_none, 0, I_POPA },
        { "popad", TOKEN_INSN, C_none, 0, I_POPAD },
        { "popaw", TOKEN_INSN, C_none, 0, I_POPAW },
        { "popf", TOKEN_INSN, C_none, 0, I_POPF },
        { "popfd", TOKEN_INSN, C_none, 0, I_POPFD },
        { "popfq", TOKEN_INSN, C_none, 0, I_POPFQ },
        { "popfw", TOKEN_INSN, C_none, 0, I_POPFW },
        { "por", TOKEN_INSN, C_none, 0, I_POR },
        { "prefetch", TOKEN_INSN, C_none, 0, I_PREFETCH },
        { "prefetchw", TOKEN_INSN, C_none, 0, I_PREFETCHW },
        { "pslld", TOKEN_INSN, C_none, 0, I_PSLLD },
        { "psllq", TOKEN_INSN, C_none, 0, I_PSLLQ },
        { "psllw", TOKEN_INSN, C_none, 0, I_PSLLW },
        { "psrad", TOKEN_INSN, C_none, 0, I_PSRAD },
        { "psraw", TOKEN_INSN, C_none, 0, I_PSRAW },
        { "psrld", TOKEN_INSN, C_none, 0, I_PSRLD },
        { "psrlq", TOKEN_INSN, C_none, 0, I_PSRLQ },
        { "psrlw", TOKEN_INSN, C_none, 0, I_PSRLW },
        { "psubb", TOKEN_INSN, C_none, 0, I_PSUBB },
        { "psubd", TOKEN_INSN, C_none, 0, I_PSUBD },
        { "psubsb", TOKEN_INSN, C_none, 0, I_PSUBSB },
        { "psubsiw", TOKEN_INSN, C_none, 0, I_PSUBSIW },
        { "psubsw", TOKEN_INSN, C_none, 0, I_PSUBSW },
        { "psubusb", TOKEN_INSN, C_none, 0, I_PSUBUSB },
        { "psubusw", TOKEN_INSN, C_none, 0, I_PSUBUSW },
        { "psubw", TOKEN_INSN, C_none, 0, I_PSUBW },
        { "punpckhbw", TOKEN_INSN, C_none, 0, I_PUNPCKHBW },
        { "punpckhdq", TOKEN_INSN, C_none, 0, I_PUNPCKHDQ },
        { "punpckhwd", TOKEN_INSN, C_none, 0, I_PUNPCKHWD },
        { "punpcklbw", TOKEN_INSN, C_none, 0, I_PUNPCKLBW },
        { "punpckldq", TOKEN_INSN, C_none, 0, I_PUNPCKLDQ },
        { "punpcklwd", TOKEN_INSN, C_none, 0, I_PUNPCKLWD },
        { "push", TOKEN_INSN, C_none, 0, I_PUSH },
        { "pusha", TOKEN_INSN, C_none, 0, I_PUSHA },
        { "pushad", TOKEN_INSN, C_none, 0, I_PUSHAD },
        { "pushaw", TOKEN_INSN, C_none, 0, I_PUSHAW },
        { "pushf", TOKEN_INSN, C_none, 0, I_PUSHF },
        { "pushfd", TOKEN_INSN, C_none, 0, I_PUSHFD },
        { "pushfq", TOKEN_INSN, C_none, 0, I_PUSHFQ },
        { "pushfw", TOKEN_INSN, C_none, 0, I_PUSHFW },
        { "pxor", TOKEN_INSN, C_none, 0, I_PXOR },
        { "rcl", TOKEN_INSN, C_none, 0, I_RCL },
        { "rcr", TOKEN_INSN, C_none, 0, I_RCR },
        { "rdshr", TOKEN_INSN, C_none, 0, I_RDSHR },
        { "rdmsr", TOKEN_INSN, C_none, 0, I_RDMSR },
        { "rdpmc", TOKEN_INSN, C_none, 0, I_RDPMC },
        { "rdtsc", TOKEN_INSN, C_none, 0, I_RDTSC },
        { "rdtscp", TOKEN_INSN, C_none, 0, I_RDTSCP },
        { "ret", TOKEN_INSN, C_none, 0, I_RET },
        { "retf", TOKEN_INSN, C_none, 0, I_RETF },
        { "retn", TOKEN_INSN, C_none, 0, I_RETN },
        { "rol", TOKEN_INSN, C_none, 0, I_ROL },
        { "ror", TOKEN_INSN, C_none, 0, I_ROR },
        { "rdm", TOKEN_INSN, C_none, 0, I_RDM },
        { "rsdc", TOKEN_INSN, C_none, 0, I_RSDC },
        { "rsldt", TOKEN_INSN, C_none, 0, I_RSLDT },
        { "rsm", TOKEN_INSN, C_none, 0, I_RSM },
        { "rsts", TOKEN_INSN, C_none, 0, I_RSTS },
        { "sahf", TOKEN_INSN, C_none, 0, I_SAHF },
        { "sal", TOKEN_INSN, C_none, 0, I_SAL },
        { "salc", TOKEN_INSN, C_none, 0, I_SALC },
        { "sar", TOKEN_INSN, C_none, 0, I_SAR },
        { "sbb", TOKEN_INSN, C_none, 0, I_SBB },
        { "scasb", TOKEN_INSN, C_none, 0, I_SCASB },
        { "scasd", TOKEN_INSN, C_none, 0, I_SCASD },
        { "scasq", TOKEN_INSN, C_none, 0, I_SCASQ },
        { "scasw", TOKEN_INSN, C_none, 0, I_SCASW },
        { "sfence", TOKEN_INSN, C_none, 0, I_SFENCE },
        { "sgdt", TOKEN_INSN, C_none, 0, I_SGDT },
        { "shl", TOKEN_INSN, C_none, 0, I_SHL },
        { "shld", TOKEN_INSN, C_none, 0, I_SHLD },
        { "shr", TOKEN_INSN, C_none, 0, I_SHR },
        { "shrd", TOKEN_INSN, C_none, 0, I_SHRD },
        { "sidt", TOKEN_INSN, C_none, 0, I_SIDT },
        { "sldt", TOKEN_INSN, C_none, 0, I_SLDT },
        { "skinit", TOKEN_INSN, C_none, 0, I_SKINIT },
        { "smi", TOKEN_INSN, C_none, 0, I_SMI },
        { "smint", TOKEN_INSN, C_none, 0, I_SMINT },
        { "smintold", TOKEN_INSN, C_none, 0, I_SMINTOLD },
        { "smsw", TOKEN_INSN, C_none, 0, I_SMSW },
        { "stc", TOKEN_INSN, C_none, 0, I_STC },
        { "std", TOKEN_INSN, C_none, 0, I_STD },
        { "sti", TOKEN_INSN, C_none, 0, I_STI },
        { "stosb", TOKEN_INSN, C_none, 0, I_STOSB },
        { "stosd", TOKEN_INSN, C_none, 0, I_STOSD },
        { "stosq", TOKEN_INSN, C_none, 0, I_STOSQ },
        { "stosw", TOKEN_INSN, C_none, 0, I_STOSW },
        { "str", TOKEN_INSN, C_none, 0, I_STR },
        { "sub", TOKEN_INSN, C_none, 0, I_SUB },
        { "svdc", TOKEN_INSN, C_none, 0, I_SVDC },
        { "svldt", TOKEN_INSN, C_none, 0, I_SVLDT },
        { "svts", TOKEN_INSN, C_none, 0, I_SVTS },
        { "swapgs", TOKEN_INSN, C_none, 0, I_SWAPGS },
        { "syscall", TOKEN_INSN, C_none, 0, I_SYSCALL },
        { "sysenter", TOKEN_INSN, C_none, 0, I_SYSENTER },
        { "sysexit", TOKEN_INSN, C_none, 0, I_SYSEXIT },
        { "sysret", TOKEN_INSN, C_none, 0, I_SYSRET },
        { "test", TOKEN_INSN, C_none, 0, I_TEST },
        { "ud0", TOKEN_INSN, C_none, 0, I_UD0 },
        { "ud1", TOKEN_INSN, C_none, 0, I_UD1 },
        { "ud2b", TOKEN_INSN, C_none, 0, I_UD2B },
        { "ud2", TOKEN_INSN, C_none, 0, I_UD2 },
        { "ud2a", TOKEN_INSN, C_none, 0, I_UD2A },
        { "umov", TOKEN_INSN, C_none, 0, I_UMOV },
        { "verr", TOKEN_INSN, C_none, 0, I_VERR },
        { "verw", TOKEN_INSN, C_none, 0, I_VERW },
        { "fwait", TOKEN_INSN, C_none, 0, I_FWAIT },
        { "wbinvd", TOKEN_INSN, C_none, 0, I_WBINVD },
        { "wrshr", TOKEN_INSN, C_none, 0, I_WRSHR },
        { "wrmsr", TOKEN_INSN, C_none, 0, I_WRMSR },
        { "xadd", TOKEN_INSN, C_none, 0, I_XADD },
        { "xbts", TOKEN_INSN, C_none, 0, I_XBTS },
        { "xchg", TOKEN_INSN, C_none, 0, I_XCHG },
        { "xlatb", TOKEN_INSN, C_none, 0, I_XLATB },
        { "xlat", TOKEN_INSN, C_none, 0, I_XLAT },
        { "xor", TOKEN_INSN, C_none, 0, I_XOR },
        { "cmova", TOKEN_INSN, C_A, 0, I_CMOVcc },
        { "cmovae", TOKEN_INSN, C_AE, 0, I_CMOVcc },
        { "cmovb", TOKEN_INSN, C_B, 0, I_CMOVcc },
        { "cmovbe", TOKEN_INSN, C_BE, 0, I_CMOVcc },
        { "cmovc", TOKEN_INSN, C_C, 0, I_CMOVcc },
        { "cmove", TOKEN_INSN, C_E, 0, I_CMOVcc },
        { "cmovg", TOKEN_INSN, C_G, 0, I_CMOVcc },
        { "cmovge", TOKEN_INSN, C_GE, 0, I_CMOVcc },
        { "cmovl", TOKEN_INSN, C_L, 0, I_CMOVcc },
        { "cmovle", TOKEN_INSN, C_LE, 0, I_CMOVcc },
        { "cmovna", TOKEN_INSN, C_NA, 0, I_CMOVcc },
        { "cmovnae", TOKEN_INSN, C_NAE, 0, I_CMOVcc },
        { "cmovnb", TOKEN_INSN, C_NB, 0, I_CMOVcc },
        { "cmovnbe", TOKEN_INSN, C_NBE, 0, I_CMOVcc },
        { "cmovnc", TOKEN_INSN, C_NC, 0, I_CMOVcc },
        { "cmovne", TOKEN_INSN, C_NE, 0, I_CMOVcc },
        { "cmovng", TOKEN_INSN, C_NG, 0, I_CMOVcc },
        { "cmovnge", TOKEN_INSN, C_NGE, 0, I_CMOVcc },
        { "cmovnl", TOKEN_INSN, C_NL, 0, I_CMOVcc },
        { "cmovnle", TOKEN_INSN, C_NLE, 0, I_CMOVcc },
        { "cmovno", TOKEN_INSN, C_NO, 0, I_CMOVcc },
        { "cmovnp", TOKEN_INSN, C_NP, 0, I_CMOVcc },
        { "cmovns", TOKEN_INSN, C_NS, 0, I_CMOVcc },
        { "cmovnz", TOKEN_INSN, C_NZ, 0, I_CMOVcc },
        { "cmovo", TOKEN_INSN, C_O, 0, I_CMOVcc },
        { "cmovp", TOKEN_INSN, C_P, 0, I_CMOVcc },
        { "cmovpe", TOKEN_INSN, C_PE, 0, I_CMOVcc },
        { "cmovpo", TOKEN_INSN, C_PO, 0, I_CMOVcc },
        { "cmovs", TOKEN_INSN, C_S, 0, I_CMOVcc },
        { "cmovz", TOKEN_INSN, C_Z, 0, I_CMOVcc },
        { "ja", TOKEN_INSN, C_A, 0, I_Jcc },
        { "jae", TOKEN_INSN, C_AE, 0, I_Jcc },
        { "jb", TOKEN_INSN, C_B, 0, I_Jcc },
        { "jbe", TOKEN_INSN, C_BE, 0, I_Jcc },
        { "jc", TOKEN_INSN, C_C, 0, I_Jcc },
        { "je", TOKEN_INSN, C_E, 0, I_Jcc },
        { "jg", TOKEN_INSN, C_G, 0, I_Jcc },
        { "jge", TOKEN_INSN, C_GE, 0, I_Jcc },
        { "jl", TOKEN_INSN, C_L, 0, I_Jcc },
        { "jle", TOKEN_INSN, C_LE, 0, I_Jcc },
        { "jna", TOKEN_INSN, C_NA, 0, I_Jcc },
        { "jnae", TOKEN_INSN, C_NAE, 0, I_Jcc },
        { "jnb", TOKEN_INSN, C_NB, 0, I_Jcc },
        { "jnbe", TOKEN_INSN, C_NBE, 0, I_Jcc },
        { "jnc", TOKEN_INSN, C_NC, 0, I_Jcc },
        { "jne", TOKEN_INSN, C_NE, 0, I_Jcc },
        { "jng", TOKEN_INSN, C_NG, 0, I_Jcc },
        { "jnge", TOKEN_INSN, C_NGE, 0, I_Jcc },
        { "jnl", TOKEN_INSN, C_NL, 0, I_Jcc },
        { "jnle", TOKEN_INSN, C_NLE, 0, I_Jcc },
        { "jno", TOKEN_INSN, C_NO, 0, I_Jcc },
        { "jnp", TOKEN_INSN, C_NP, 0, I_Jcc },
        { "jns", TOKEN_INSN, C_NS, 0, I_Jcc },
        { "jnz", TOKEN_INSN, C_NZ, 0, I_Jcc },
        { "jo", TOKEN_INSN, C_O, 0, I_Jcc },
        { "jp", TOKEN_INSN, C_P, 0, I_Jcc },
        { "jpe", TOKEN_INSN, C_PE, 0, I_Jcc },
        { "jpo", TOKEN_INSN, C_PO, 0, I_Jcc },
        { "js", TOKEN_INSN, C_S, 0, I_Jcc },
        { "jz", TOKEN_INSN, C_Z, 0, I_Jcc },
        { "seta", TOKEN_INSN, C_A, 0, I_SETcc },
        { "setae", TOKEN_INSN, C_AE, 0, I_SETcc },
        { "setb", TOKEN_INSN, C_B, 0, I_SETcc },
        { "setbe", TOKEN_INSN, C_BE, 0, I_SETcc },
        { "setc", TOKEN_INSN, C_C, 0, I_SETcc },
        { "sete", TOKEN_INSN, C_E, 0, I_SETcc },
        { "setg", TOKEN_INSN, C_G, 0, I_SETcc },
        { "setge", TOKEN_INSN, C_GE, 0, I_SETcc },
        { "setl", TOKEN_INSN, C_L, 0, I_SETcc },
        { "setle", TOKEN_INSN, C_LE, 0, I_SETcc },
        { "setna", TOKEN_INSN, C_NA, 0, I_SETcc },
        { "setnae", TOKEN_INSN, C_NAE, 0, I_SETcc },
        { "setnb", TOKEN_INSN, C_NB, 0, I_SETcc },
        { "setnbe", TOKEN_INSN, C_NBE, 0, I_SETcc },
        { "setnc", TOKEN_INSN, C_NC, 0, I_SETcc },
        { "setne", TOKEN_INSN, C_NE, 0, I_SETcc },
        { "setng", TOKEN_INSN, C_NG, 0, I_SETcc },
        { "setnge", TOKEN_INSN, C_NGE, 0, I_SETcc },
        { "setnl", TOKEN_INSN, C_NL, 0, I_SETcc },
        { "setnle", TOKEN_INSN, C_NLE, 0, I_SETcc },
        { "setno", TOKEN_INSN, C_NO, 0, I_SETcc },
        { "setnp", TOKEN_INSN, C_NP, 0, I_SETcc },
        { "setns", TOKEN_INSN, C_NS, 0, I_SETcc },
        { "setnz", TOKEN_INSN, C_NZ, 0, I_SETcc },
        { "seto", TOKEN_INSN, C_O, 0, I_SETcc },
        { "setp", TOKEN_INSN, C_P, 0, I_SETcc },
        { "setpe", TOKEN_INSN, C_PE, 0, I_SETcc },
        { "setpo", TOKEN_INSN, C_PO, 0, I_SETcc },
        { "sets", TOKEN_INSN, C_S, 0, I_SETcc },
        { "setz", TOKEN_INSN, C_Z, 0, I_SETcc },
        { "addps", TOKEN_INSN, C_none, 0, I_ADDPS },
        { "addss", TOKEN_INSN, C_none, 0, I_ADDSS },
        { "andnps", TOKEN_INSN, C_none, 0, I_ANDNPS },
        { "andps", TOKEN_INSN, C_none, 0, I_ANDPS },
        { "cmpeqps", TOKEN_INSN, C_none, 0, I_CMPEQPS },
        { "cmpeqss", TOKEN_INSN, C_none, 0, I_CMPEQSS },
        { "cmpleps", TOKEN_INSN, C_none, 0, I_CMPLEPS },
        { "cmpless", TOKEN_INSN, C_none, 0, I_CMPLESS },
        { "cmpltps", TOKEN_INSN, C_none, 0, I_CMPLTPS },
        { "cmpltss", TOKEN_INSN, C_none, 0, I_CMPLTSS },
        { "cmpneqps", TOKEN_INSN, C_none, 0, I_CMPNEQPS },
        { "cmpneqss", TOKEN_INSN, C_none, 0, I_CMPNEQSS },
        { "cmpnleps", TOKEN_INSN, C_none, 0, I_CMPNLEPS },
        { "cmpnless", TOKEN_INSN, C_none, 0, I_CMPNLESS },
        { "cmpnltps", TOKEN_INSN, C_none, 0, I_CMPNLTPS },
        { "cmpnltss", TOKEN_INSN, C_none, 0, I_CMPNLTSS },
        { "cmpordps", TOKEN_INSN, C_none, 0, I_CMPORDPS },
        { "cmpordss", TOKEN_INSN, C_none, 0, I_CMPORDSS },
        { "cmpunordps", TOKEN_INSN, C_none, 0, I_CMPUNORDPS },
        { "cmpunordss", TOKEN_INSN, C_none, 0, I_CMPUNORDSS },
        { "cmpps", TOKEN_INSN, C_none, 0, I_CMPPS },
        { "cmpss", TOKEN_INSN, C_none, 0, I_CMPSS },
        { "comiss", TOKEN_INSN, C_none, 0, I_COMISS },
        { "cvtpi2ps", TOKEN_INSN, C_none, 0, I_CVTPI2PS },
        { "cvtps2pi", TOKEN_INSN, C_none, 0, I_CVTPS2PI },
        { "cvtsi2ss", TOKEN_INSN, C_none, 0, I_CVTSI2SS },
        { "cvtss2si", TOKEN_INSN, C_none, 0, I_CVTSS2SI },
        { "cvttps2pi", TOKEN_INSN, C_none, 0, I_CVTTPS2PI },
        { "cvttss2si", TOKEN_INSN, C_none, 0, I_CVTTSS2SI },
        { "divps", TOKEN_INSN, C_none, 0, I_DIVPS },
        { "divss", TOKEN_INSN, C_none, 0, I_DIVSS },
        { "ldmxcsr", TOKEN_INSN, C_none, 0, I_LDMXCSR },
        { "maxps", TOKEN_INSN, C_none, 0, I_MAXPS },
        { "maxss", TOKEN_INSN, C_none, 0, I_MAXSS },
        { "minps", TOKEN_INSN, C_none, 0, I_MINPS },
        { "minss", TOKEN_INSN, C_none, 0, I_MINSS },
        { "movaps", TOKEN_INSN, C_none, 0, I_MOVAPS },
        { "movhps", TOKEN_INSN, C_none, 0, I_MOVHPS },
        { "movlhps", TOKEN_INSN, C_none, 0, I_MOVLHPS },
        { "movlps", TOKEN_INSN, C_none, 0, I_MOVLPS },
        { "movhlps", TOKEN_INSN, C_none, 0, I_MOVHLPS },
        { "movmskps", TOKEN_INSN, C_none, 0, I_MOVMSKPS },
        { "movntps", TOKEN_INSN, C_none, 0, I_MOVNTPS },
        { "movss", TOKEN_INSN, C_none, 0, I_MOVSS },
        { "movups", TOKEN_INSN, C_none, 0, I_MOVUPS },
        { "mulps", TOKEN_INSN, C_none, 0, I_MULPS },
        { "mulss", TOKEN_INSN, C_none, 0, I_MULSS },
        { "orps", TOKEN_INSN, C_none, 0, I_ORPS },
        { "rcpps", TOKEN_INSN, C_none, 0, I_RCPPS },
        { "rcpss", TOKEN_INSN, C_none, 0, I_RCPSS },
        { "rsqrtps", TOKEN_INSN, C_none, 0, I_RSQRTPS },
        { "rsqrtss", TOKEN_INSN, C_none, 0, I_RSQRTSS },
        { "shufps", TOKEN_INSN, C_none, 0, I_SHUFPS },
        { "sqrtps", TOKEN_INSN, C_none, 0, I_SQRTPS },
        { "sqrtss", TOKEN_INSN, C_none, 0, I_SQRTSS },
        { "stmxcsr", TOKEN_INSN, C_none, 0, I_STMXCSR },
        { "subps", TOKEN_INSN, C_none, 0, I_SUBPS },
        { "subss", TOKEN_INSN, C_none, 0, I_SUBSS },
        { "ucomiss", TOKEN_INSN, C_none, 0, I_UCOMISS },
        { "unpckhps", TOKEN_INSN, C_none, 0, I_UNPCKHPS },
        { "unpcklps", TOKEN_INSN, C_none, 0, I_UNPCKLPS },
        { "xorps", TOKEN_INSN, C_none, 0, I_XORPS },
        { "fxrstor", TOKEN_INSN, C_none, 0, I_FXRSTOR },
        { "fxrstor64", TOKEN_INSN, C_none, 0, I_FXRSTOR64 },
        { "fxsave", TOKEN_INSN, C_none, 0, I_FXSAVE },
        { "fxsave64", TOKEN_INSN, C_none, 0, I_FXSAVE64 },
        { "xgetbv", TOKEN_INSN, C_none, 0, I_XGETBV },
        { "xsetbv", TOKEN_INSN, C_none, 0, I_XSETBV },
        { "xsave", TOKEN_INSN, C_none, 0, I_XSAVE },
        { "xsave64", TOKEN_INSN, C_none, 0, I_XSAVE64 },
        { "xsavec", TOKEN_INSN, C_none, 0, I_XSAVEC },
        { "xsavec64", TOKEN_INSN, C_none, 0, I_XSAVEC64 },
        { "xsaveopt", TOKEN_INSN, C_none, 0, I_XSAVEOPT },
        { "xsaveopt64", TOKEN_INSN, C_none, 0, I_XSAVEOPT64 },
        { "xsaves", TOKEN_INSN, C_none, 0, I_XSAVES },
        { "xsaves64", TOKEN_INSN, C_none, 0, I_XSAVES64 },
        { "xrstor", TOKEN_INSN, C_none, 0, I_XRSTOR },
        { "xrstor64", TOKEN_INSN, C_none, 0, I_XRSTOR64 },
        { "xrstors", TOKEN_INSN, C_none, 0, I_XRSTORS },
        { "xrstors64", TOKEN_INSN, C_none, 0, I_XRSTORS64 },
        { "prefetchnta", TOKEN_INSN, C_none, 0, I_PREFETCHNTA },
        { "prefetcht0", TOKEN_INSN, C_none, 0, I_PREFETCHT0 },
        { "prefetcht1", TOKEN_INSN, C_none, 0, I_PREFETCHT1 },
        { "prefetcht2", TOKEN_INSN, C_none, 0, I_PREFETCHT2 },
        { "maskmovq", TOKEN_INSN, C_none, 0, I_MASKMOVQ },
        { "movntq", TOKEN_INSN, C_none, 0, I_MOVNTQ },
        { "pavgb", TOKEN_INSN, C_none, 0, I_PAVGB },
        { "pavgw", TOKEN_INSN, C_none, 0, I_PAVGW },
        { "pextrw", TOKEN_INSN, C_none, 0, I_PEXTRW },
        { "pinsrw", TOKEN_INSN, C_none, 0, I_PINSRW },
        { "pmaxsw", TOKEN_INSN, C_none, 0, I_PMAXSW },
        { "pmaxub", TOKEN_INSN, C_none, 0, I_PMAXUB },
        { "pminsw", TOKEN_INSN, C_none, 0, I_PMINSW },
        { "pminub", TOKEN_INSN, C_none, 0, I_PMINUB },
        { "pmovmskb", TOKEN_INSN, C_none, 0, I_PMOVMSKB },
        { "pmulhuw", TOKEN_INSN, C_none, 0, I_PMULHUW },
        { "psadbw", TOKEN_INSN, C_none, 0, I_PSADBW },
        { "pshufw", TOKEN_INSN, C_none, 0, I_PSHUFW },
        { "pf2iw", TOKEN_INSN, C_none, 0, I_PF2IW },
        { "pfnacc", TOKEN_INSN, C_none, 0, I_PFNACC },
        { "pfpnacc", TOKEN_INSN, C_none, 0, I_PFPNACC },
        { "pi2fw", TOKEN_INSN, C_none, 0, I_PI2FW },
        { "pswapd", TOKEN_INSN, C_none, 0, I_PSWAPD },
        { "maskmovdqu", TOKEN_INSN, C_none, 0, I_MASKMOVDQU },
        { "clflush", TOKEN_INSN, C_none, 0, I_CLFLUSH },
        { "movntdq", TOKEN_INSN, C_none, 0, I_MOVNTDQ },
        { "movnti", TOKEN_INSN, C_none, 0, I_MOVNTI },
        { "movntpd", TOKEN_INSN, C_none, 0, I_MOVNTPD },
        { "movdqa", TOKEN_INSN, C_none, 0, I_MOVDQA },
        { "movdqu", TOKEN_INSN, C_none, 0, I_MOVDQU },
        { "movdq2q", TOKEN_INSN, C_none, 0, I_MOVDQ2Q },
        { "movq2dq", TOKEN_INSN, C_none, 0, I_MOVQ2DQ },
        { "paddq", TOKEN_INSN, C_none, 0, I_PADDQ },
        { "pmuludq", TOKEN_INSN, C_none, 0, I_PMULUDQ },
        { "pshufd", TOKEN_INSN, C_none, 0, I_PSHUFD },
        { "pshufhw", TOKEN_INSN, C_none, 0, I_PSHUFHW },
        { "pshuflw", TOKEN_INSN, C_none, 0, I_PSHUFLW },
        { "pslldq", TOKEN_INSN, C_none, 0, I_PSLLDQ },
        { "psrldq", TOKEN_INSN, C_none, 0, I_PSRLDQ },
        { "psubq", TOKEN_INSN, C_none, 0, I_PSUBQ },
        { "punpckhqdq", TOKEN_INSN, C_none, 0, I_PUNPCKHQDQ },
        { "punpcklqdq", TOKEN_INSN, C_none, 0, I_PUNPCKLQDQ },
        { "addpd", TOKEN_INSN, C_none, 0, I_ADDPD },
        { "addsd", TOKEN_INSN, C_none, 0, I_ADDSD },
        { "andnpd", TOKEN_INSN, C_none, 0, I_ANDNPD },
        { "andpd", TOKEN_INSN, C_none, 0, I_ANDPD },
        { "cmpeqpd", TOKEN_INSN, C_none, 0, I_CMPEQPD },
        { "cmpeqsd", TOKEN_INSN, C_none, 0, I_CMPEQSD },
        { "cmplepd", TOKEN_INSN, C_none, 0, I_CMPLEPD },
        { "cmplesd", TOKEN_INSN, C_none, 0, I_CMPLESD },
        { "cmpltpd", TOKEN_INSN, C_none, 0, I_CMPLTPD },
        { "cmpltsd", TOKEN_INSN, C_none, 0, I_CMPLTSD },
        { "cmpneqpd", TOKEN_INSN, C_none, 0, I_CMPNEQPD },
        { "cmpneqsd", TOKEN_INSN, C_none, 0, I_CMPNEQSD },
        { "cmpnlepd", TOKEN_INSN, C_none, 0, I_CMPNLEPD },
        { "cmpnlesd", TOKEN_INSN, C_none, 0, I_CMPNLESD },
        { "cmpnltpd", TOKEN_INSN, C_none, 0, I_CMPNLTPD },
        { "cmpnltsd", TOKEN_INSN, C_none, 0, I_CMPNLTSD },
        { "cmpordpd", TOKEN_INSN, C_none, 0, I_CMPORDPD },
        { "cmpordsd", TOKEN_INSN, C_none, 0, I_CMPORDSD },
        { "cmpunordpd", TOKEN_INSN, C_none, 0, I_CMPUNORDPD },
        { "cmpunordsd", TOKEN_INSN, C_none, 0, I_CMPUNORDSD },
        { "cmppd", TOKEN_INSN, C_none, 0, I_CMPPD },
        { "comisd", TOKEN_INSN, C_none, 0, I_COMISD },
        { "cvtdq2pd", TOKEN_INSN, C_none, 0, I_CVTDQ2PD },
        { "cvtdq2ps", TOKEN_INSN, C_none, 0, I_CVTDQ2PS },
        { "cvtpd2dq", TOKEN_INSN, C_none, 0, I_CVTPD2DQ },
        { "cvtpd2pi", TOKEN_INSN, C_none, 0, I_CVTPD2PI },
        { "cvtpd2ps", TOKEN_INSN, C_none, 0, I_CVTPD2PS },
        { "cvtpi2pd", TOKEN_INSN, C_none, 0, I_CVTPI2PD },
        { "cvtps2dq", TOKEN_INSN, C_none, 0, I_CVTPS2DQ },
        { "cvtps2pd", TOKEN_INSN, C_none, 0, I_CVTPS2PD },
        { "cvtsd2si", TOKEN_INSN, C_none, 0, I_CVTSD2SI },
        { "cvtsd2ss", TOKEN_INSN, C_none, 0, I_CVTSD2SS },
        { "cvtsi2sd", TOKEN_INSN, C_none, 0, I_CVTSI2SD },
        { "cvtss2sd", TOKEN_INSN, C_none, 0, I_CVTSS2SD },
        { "cvttpd2pi", TOKEN_INSN, C_none, 0, I_CVTTPD2PI },
        { "cvttpd2dq", TOKEN_INSN, C_none, 0, I_CVTTPD2DQ },
        { "cvttps2dq", TOKEN_INSN, C_none, 0, I_CVTTPS2DQ },
        { "cvttsd2si", TOKEN_INSN, C_none, 0, I_CVTTSD2SI },
        { "divpd", TOKEN_INSN, C_none, 0, I_DIVPD },
        { "divsd", TOKEN_INSN, C_none, 0, I_DIVSD },
        { "maxpd", TOKEN_INSN, C_none, 0, I_MAXPD },
        { "maxsd", TOKEN_INSN, C_none, 0, I_MAXSD },
        { "minpd", TOKEN_INSN, C_none, 0, I_MINPD },
        { "minsd", TOKEN_INSN, C_none, 0, I_MINSD },
        { "movapd", TOKEN_INSN, C_none, 0, I_MOVAPD },
        { "movhpd", TOKEN_INSN, C_none, 0, I_MOVHPD },
        { "movlpd", TOKEN_INSN, C_none, 0, I_MOVLPD },
        { "movmskpd", TOKEN_INSN, C_none, 0, I_MOVMSKPD },
        { "movupd", TOKEN_INSN, C_none, 0, I_MOVUPD },
        { "mulpd", TOKEN_INSN, C_none, 0, I_MULPD },
        { "mulsd", TOKEN_INSN, C_none, 0, I_MULSD },
        { "orpd", TOKEN_INSN, C_none, 0, I_ORPD },
        { "shufpd", TOKEN_INSN, C_none, 0, I_SHUFPD },
        { "sqrtpd", TOKEN_INSN, C_none, 0, I_SQRTPD },
        { "sqrtsd", TOKEN_INSN, C_none, 0, I_SQRTSD },
        { "subpd", TOKEN_INSN, C_none, 0, I_SUBPD },
        { "subsd", TOKEN_INSN, C_none, 0, I_SUBSD },
        { "ucomisd", TOKEN_INSN, C_none, 0, I_UCOMISD },
        { "unpckhpd", TOKEN_INSN, C_none, 0, I_UNPCKHPD },
        { "unpcklpd", TOKEN_INSN, C_none, 0, I_UNPCKLPD },
        { "xorpd", TOKEN_INSN, C_none, 0, I_XORPD },
        { "addsubpd", TOKEN_INSN, C_none, 0, I_ADDSUBPD },
        { "addsubps", TOKEN_INSN, C_none, 0, I_ADDSUBPS },
        { "haddpd", TOKEN_INSN, C_none, 0, I_HADDPD },
        { "haddps", TOKEN_INSN, C_none, 0, I_HADDPS },
        { "hsubpd", TOKEN_INSN, C_none, 0, I_HSUBPD },
        { "hsubps", TOKEN_INSN, C_none, 0, I_HSUBPS },
        { "lddqu", TOKEN_INSN, C_none, 0, I_LDDQU },
        { "movddup", TOKEN_INSN, C_none, 0, I_MOVDDUP },
        { "movshdup", TOKEN_INSN, C_none, 0, I_MOVSHDUP },
        { "movsldup", TOKEN_INSN, C_none, 0, I_MOVSLDUP },
        { "clgi", TOKEN_INSN, C_none, 0, I_CLGI },
        { "stgi", TOKEN_INSN, C_none, 0, I_STGI },
        { "vmcall", TOKEN_INSN, C_none, 0, I_VMCALL },
        { "vmclear", TOKEN_INSN, C_none, 0, I_VMCLEAR },
        { "vmfunc", TOKEN_INSN, C_none, 0, I_VMFUNC },
        { "vmlaunch", TOKEN_INSN, C_none, 0, I_VMLAUNCH },
        { "vmload", TOKEN_INSN, C_none, 0, I_VMLOAD },
        { "vmmcall", TOKEN_INSN, C_none, 0, I_VMMCALL },
        { "vmptrld", TOKEN_INSN, C_none, 0, I_VMPTRLD },
        { "vmptrst", TOKEN_INSN, C_none, 0, I_VMPTRST },
        { "vmread", TOKEN_INSN, C_none, 0, I_VMREAD },
        { "vmresume", TOKEN_INSN, C_none, 0, I_VMRESUME },
        { "vmrun", TOKEN_INSN, C_none, 0, I_VMRUN },
        { "vmsave", TOKEN_INSN, C_none, 0, I_VMSAVE },
        { "vmwrite", TOKEN_INSN, C_none, 0, I_VMWRITE },
        { "vmxoff", TOKEN_INSN, C_none, 0, I_VMXOFF },
        { "vmxon", TOKEN_INSN, C_none, 0, I_VMXON },
        { "invept", TOKEN_INSN, C_none, 0, I_INVEPT },
        { "invvpid", TOKEN_INSN, C_none, 0, I_INVVPID },
        { "pabsb", TOKEN_INSN, C_none, 0, I_PABSB },
        { "pabsw", TOKEN_INSN, C_none, 0, I_PABSW },
        { "pabsd", TOKEN_INSN, C_none, 0, I_PABSD },
        { "palignr", TOKEN_INSN, C_none, 0, I_PALIGNR },
        { "phaddw", TOKEN_INSN, C_none, 0, I_PHADDW },
        { "phaddd", TOKEN_INSN, C_none, 0, I_PHADDD },
        { "phaddsw", TOKEN_INSN, C_none, 0, I_PHADDSW },
        { "phsubw", TOKEN_INSN, C_none, 0, I_PHSUBW },
        { "phsubd", TOKEN_INSN, C_none, 0, I_PHSUBD },
        { "phsubsw", TOKEN_INSN, C_none, 0, I_PHSUBSW },
        { "pmaddubsw", TOKEN_INSN, C_none, 0, I_PMADDUBSW },
        { "pmulhrsw", TOKEN_INSN, C_none, 0, I_PMULHRSW },
        { "pshufb", TOKEN_INSN, C_none, 0, I_PSHUFB },
        { "psignb", TOKEN_INSN, C_none, 0, I_PSIGNB },
        { "psignw", TOKEN_INSN, C_none, 0, I_PSIGNW },
        { "psignd", TOKEN_INSN, C_none, 0, I_PSIGND },
        { "extrq", TOKEN_INSN, C_none, 0, I_EXTRQ },
        { "insertq", TOKEN_INSN, C_none, 0, I_INSERTQ },
        { "movntsd", TOKEN_INSN, C_none, 0, I_MOVNTSD },
        { "movntss", TOKEN_INSN, C_none, 0, I_MOVNTSS },
        { "lzcnt", TOKEN_INSN, C_none, 0, I_LZCNT },
        { "blendpd", TOKEN_INSN, C_none, 0, I_BLENDPD },
        { "blendps", TOKEN_INSN, C_none, 0, I_BLENDPS },
        { "blendvpd", TOKEN_INSN, C_none, 0, I_BLENDVPD },
        { "blendvps", TOKEN_INSN, C_none, 0, I_BLENDVPS },
        { "dppd", TOKEN_INSN, C_none, 0, I_DPPD },
        { "dpps", TOKEN_INSN, C_none, 0, I_DPPS },
        { "extractps", TOKEN_INSN, C_none, 0, I_EXTRACTPS },
        { "insertps", TOKEN_INSN, C_none, 0, I_INSERTPS },
        { "movntdqa", TOKEN_INSN, C_none, 0, I_MOVNTDQA },
        { "mpsadbw", TOKEN_INSN, C_none, 0, I_MPSADBW },
        { "packusdw", TOKEN_INSN, C_none, 0, I_PACKUSDW },
        { "pblendvb", TOKEN_INSN, C_none, 0, I_PBLENDVB },
        { "pblendw", TOKEN_INSN, C_none, 0, I_PBLENDW },
        { "pcmpeqq", TOKEN_INSN, C_none, 0, I_PCMPEQQ },
        { "pextrb", TOKEN_INSN, C_none, 0, I_PEXTRB },
        { "pextrd", TOKEN_INSN, C_none, 0, I_PEXTRD },
        { "pextrq", TOKEN_INSN, C_none, 0, I_PEXTRQ },
        { "phminposuw", TOKEN_INSN, C_none, 0, I_PHMINPOSUW },
        { "pinsrb", TOKEN_INSN, C_none, 0, I_PINSRB },
        { "pinsrd", TOKEN_INSN, C_none, 0, I_PINSRD },
        { "pinsrq", TOKEN_INSN, C_none, 0, I_PINSRQ },
        { "pmaxsb", TOKEN_INSN, C_none, 0, I_PMAXSB },
        { "pmaxsd", TOKEN_INSN, C_none, 0, I_PMAXSD },
        { "pmaxud", TOKEN_INSN, C_none, 0, I_PMAXUD },
        { "pmaxuw", TOKEN_INSN, C_none, 0, I_PMAXUW },
        { "pminsb", TOKEN_INSN, C_none, 0, I_PMINSB },
        { "pminsd", TOKEN_INSN, C_none, 0, I_PMINSD },
        { "pminud", TOKEN_INSN, C_none, 0, I_PMINUD },
        { "pminuw", TOKEN_INSN, C_none, 0, I_PMINUW },
        { "pmovsxbw", TOKEN_INSN, C_none, 0, I_PMOVSXBW },
        { "pmovsxbd", TOKEN_INSN, C_none, 0, I_PMOVSXBD },
        { "pmovsxbq", TOKEN_INSN, C_none, 0, I_PMOVSXBQ },
        { "pmovsxwd", TOKEN_INSN, C_none, 0, I_PMOVSXWD },
        { "pmovsxwq", TOKEN_INSN, C_none, 0, I_PMOVSXWQ },
        { "pmovsxdq", TOKEN_INSN, C_none, 0, I_PMOVSXDQ },
        { "pmovzxbw", TOKEN_INSN, C_none, 0, I_PMOVZXBW },
        { "pmovzxbd", TOKEN_INSN, C_none, 0, I_PMOVZXBD },
        { "pmovzxbq", TOKEN_INSN, C_none, 0, I_PMOVZXBQ },
        { "pmovzxwd", TOKEN_INSN, C_none, 0, I_PMOVZXWD },
        { "pmovzxwq", TOKEN_INSN, C_none, 0, I_PMOVZXWQ },
        { "pmovzxdq", TOKEN_INSN, C_none, 0, I_PMOVZXDQ },
        { "pmuldq", TOKEN_INSN, C_none, 0, I_PMULDQ },
        { "pmulld", TOKEN_INSN, C_none, 0, I_PMULLD },
        { "ptest", TOKEN_INSN, C_none, 0, I_PTEST },
        { "roundpd", TOKEN_INSN, C_none, 0, I_ROUNDPD },
        { "roundps", TOKEN_INSN, C_none, 0, I_ROUNDPS },
        { "roundsd", TOKEN_INSN, C_none, 0, I_ROUNDSD },
        { "roundss", TOKEN_INSN, C_none, 0, I_ROUNDSS },
        { "crc32", TOKEN_INSN, C_none, 0, I_CRC32 },
        { "pcmpestri", TOKEN_INSN, C_none, 0, I_PCMPESTRI },
        { "pcmpestrm", TOKEN_INSN, C_none, 0, I_PCMPESTRM },
        { "pcmpistri", TOKEN_INSN, C_none, 0, I_PCMPISTRI },
        { "pcmpistrm", TOKEN_INSN, C_none, 0, I_PCMPISTRM },
        { "pcmpgtq", TOKEN_INSN, C_none, 0, I_PCMPGTQ },
        { "popcnt", TOKEN_INSN, C_none, 0, I_POPCNT },
        { "getsec", TOKEN_INSN, C_none, 0, I_GETSEC },
        { "pfrcpv", TOKEN_INSN, C_none, 0, I_PFRCPV },
        { "pfrsqrtv", TOKEN_INSN, C_none, 0, I_PFRSQRTV },
        { "movbe", TOKEN_INSN, C_none, 0, I_MOVBE },
        { "aesenc", TOKEN_INSN, C_none, 0, I_AESENC },
        { "aesenclast", TOKEN_INSN, C_none, 0, I_AESENCLAST },
        { "aesdec", TOKEN_INSN, C_none, 0, I_AESDEC },
        { "aesdeclast", TOKEN_INSN, C_none, 0, I_AESDECLAST },
        { "aesimc", TOKEN_INSN, C_none, 0, I_AESIMC },
        { "aeskeygenassist", TOKEN_INSN, C_none, 0, I_AESKEYGENASSIST },
        { "vaesenc", TOKEN_INSN, C_none, 0, I_VAESENC },
        { "vaesenclast", TOKEN_INSN, C_none, 0, I_VAESENCLAST },
        { "vaesdec", TOKEN_INSN, C_none, 0, I_VAESDEC },
        { "vaesdeclast", TOKEN_INSN, C_none, 0, I_VAESDECLAST },
        { "vaesimc", TOKEN_INSN, C_none, 0, I_VAESIMC },
        { "vaeskeygenassist", TOKEN_INSN, C_none, 0, I_VAESKEYGENASSIST },
        { "vaddpd", TOKEN_INSN, C_none, 0, I_VADDPD },
        { "vaddps", TOKEN_INSN, C_none, 0, I_VADDPS },
        { "vaddsd", TOKEN_INSN, C_none, 0, I_VADDSD },
        { "vaddss", TOKEN_INSN, C_none, 0, I_VADDSS },
        { "vaddsubpd", TOKEN_INSN, C_none, 0, I_VADDSUBPD },
        { "vaddsubps", TOKEN_INSN, C_none, 0, I_VADDSUBPS },
        { "vandpd", TOKEN_INSN, C_none, 0, I_VANDPD },
        { "vandps", TOKEN_INSN, C_none, 0, I_VANDPS },
        { "vandnpd", TOKEN_INSN, C_none, 0, I_VANDNPD },
        { "vandnps", TOKEN_INSN, C_none, 0, I_VANDNPS },
        { "vblendpd", TOKEN_INSN, C_none, 0, I_VBLENDPD },
        { "vblendps", TOKEN_INSN, C_none, 0, I_VBLENDPS },
        { "vblendvpd", TOKEN_INSN, C_none, 0, I_VBLENDVPD },
        { "vblendvps", TOKEN_INSN, C_none, 0, I_VBLENDVPS },
        { "vbroadcastss", TOKEN_INSN, C_none, 0, I_VBROADCASTSS },
        { "vbroadcastsd", TOKEN_INSN, C_none, 0, I_VBROADCASTSD },
        { "vbroadcastf128", TOKEN_INSN, C_none, 0, I_VBROADCASTF128 },
        { "vcmpeq_ospd", TOKEN_INSN, C_none, 0, I_VCMPEQ_OSPD },
        { "vcmpeqpd", TOKEN_INSN, C_none, 0, I_VCMPEQPD },
        { "vcmplt_ospd", TOKEN_INSN, C_none, 0, I_VCMPLT_OSPD },
        { "vcmpltpd", TOKEN_INSN, C_none, 0, I_VCMPLTPD },
        { "vcmple_ospd", TOKEN_INSN, C_none, 0, I_VCMPLE_OSPD },
        { "vcmplepd", TOKEN_INSN, C_none, 0, I_VCMPLEPD },
        { "vcmpunord_qpd", TOKEN_INSN, C_none, 0, I_VCMPUNORD_QPD },
        { "vcmpunordpd", TOKEN_INSN, C_none, 0, I_VCMPUNORDPD },
        { "vcmpneq_uqpd", TOKEN_INSN, C_none, 0, I_VCMPNEQ_UQPD },
        { "vcmpneqpd", TOKEN_INSN, C_none, 0, I_VCMPNEQPD },
        { "vcmpnlt_uspd", TOKEN_INSN, C_none, 0, I_VCMPNLT_USPD },
        { "vcmpnltpd", TOKEN_INSN, C_none, 0, I_VCMPNLTPD },
        { "vcmpnle_uspd", TOKEN_INSN, C_none, 0, I_VCMPNLE_USPD },
        { "vcmpnlepd", TOKEN_INSN, C_none, 0, I_VCMPNLEPD },
        { "vcmpord_qpd", TOKEN_INSN, C_none, 0, I_VCMPORD_QPD },
        { "vcmpordpd", TOKEN_INSN, C_none, 0, I_VCMPORDPD },
        { "vcmpeq_uqpd", TOKEN_INSN, C_none, 0, I_VCMPEQ_UQPD },
        { "vcmpnge_uspd", TOKEN_INSN, C_none, 0, I_VCMPNGE_USPD },
        { "vcmpngepd", TOKEN_INSN, C_none, 0, I_VCMPNGEPD },
        { "vcmpngt_uspd", TOKEN_INSN, C_none, 0, I_VCMPNGT_USPD },
        { "vcmpngtpd", TOKEN_INSN, C_none, 0, I_VCMPNGTPD },
        { "vcmpfalse_oqpd", TOKEN_INSN, C_none, 0, I_VCMPFALSE_OQPD },
        { "vcmpfalsepd", TOKEN_INSN, C_none, 0, I_VCMPFALSEPD },
        { "vcmpneq_oqpd", TOKEN_INSN, C_none, 0, I_VCMPNEQ_OQPD },
        { "vcmpge_ospd", TOKEN_INSN, C_none, 0, I_VCMPGE_OSPD },
        { "vcmpgepd", TOKEN_INSN, C_none, 0, I_VCMPGEPD },
        { "vcmpgt_ospd", TOKEN_INSN, C_none, 0, I_VCMPGT_OSPD },
        { "vcmpgtpd", TOKEN_INSN, C_none, 0, I_VCMPGTPD },
        { "vcmptrue_uqpd", TOKEN_INSN, C_none, 0, I_VCMPTRUE_UQPD },
        { "vcmptruepd", TOKEN_INSN, C_none, 0, I_VCMPTRUEPD },
        { "vcmplt_oqpd", TOKEN_INSN, C_none, 0, I_VCMPLT_OQPD },
        { "vcmple_oqpd", TOKEN_INSN, C_none, 0, I_VCMPLE_OQPD },
        { "vcmpunord_spd", TOKEN_INSN, C_none, 0, I_VCMPUNORD_SPD },
        { "vcmpneq_uspd", TOKEN_INSN, C_none, 0, I_VCMPNEQ_USPD },
        { "vcmpnlt_uqpd", TOKEN_INSN, C_none, 0, I_VCMPNLT_UQPD },
        { "vcmpnle_uqpd", TOKEN_INSN, C_none, 0, I_VCMPNLE_UQPD },
        { "vcmpord_spd", TOKEN_INSN, C_none, 0, I_VCMPORD_SPD },
        { "vcmpeq_uspd", TOKEN_INSN, C_none, 0, I_VCMPEQ_USPD },
        { "vcmpnge_uqpd", TOKEN_INSN, C_none, 0, I_VCMPNGE_UQPD },
        { "vcmpngt_uqpd", TOKEN_INSN, C_none, 0, I_VCMPNGT_UQPD },
        { "vcmpfalse_ospd", TOKEN_INSN, C_none, 0, I_VCMPFALSE_OSPD },
        { "vcmpneq_ospd", TOKEN_INSN, C_none, 0, I_VCMPNEQ_OSPD },
        { "vcmpge_oqpd", TOKEN_INSN, C_none, 0, I_VCMPGE_OQPD },
        { "vcmpgt_oqpd", TOKEN_INSN, C_none, 0, I_VCMPGT_OQPD },
        { "vcmptrue_uspd", TOKEN_INSN, C_none, 0, I_VCMPTRUE_USPD },
        { "vcmppd", TOKEN_INSN, C_none, 0, I_VCMPPD },
        { "vcmpeq_osps", TOKEN_INSN, C_none, 0, I_VCMPEQ_OSPS },
        { "vcmpeqps", TOKEN_INSN, C_none, 0, I_VCMPEQPS },
        { "vcmplt_osps", TOKEN_INSN, C_none, 0, I_VCMPLT_OSPS },
        { "vcmpltps", TOKEN_INSN, C_none, 0, I_VCMPLTPS },
        { "vcmple_osps", TOKEN_INSN, C_none, 0, I_VCMPLE_OSPS },
        { "vcmpleps", TOKEN_INSN, C_none, 0, I_VCMPLEPS },
        { "vcmpunord_qps", TOKEN_INSN, C_none, 0, I_VCMPUNORD_QPS },
        { "vcmpunordps", TOKEN_INSN, C_none, 0, I_VCMPUNORDPS },
        { "vcmpneq_uqps", TOKEN_INSN, C_none, 0, I_VCMPNEQ_UQPS },
        { "vcmpneqps", TOKEN_INSN, C_none, 0, I_VCMPNEQPS },
        { "vcmpnlt_usps", TOKEN_INSN, C_none, 0, I_VCMPNLT_USPS },
        { "vcmpnltps", TOKEN_INSN, C_none, 0, I_VCMPNLTPS },
        { "vcmpnle_usps", TOKEN_INSN, C_none, 0, I_VCMPNLE_USPS },
        { "vcmpnleps", TOKEN_INSN, C_none, 0, I_VCMPNLEPS },
        { "vcmpord_qps", TOKEN_INSN, C_none, 0, I_VCMPORD_QPS },
        { "vcmpordps", TOKEN_INSN, C_none, 0, I_VCMPORDPS },
        { "vcmpeq_uqps", TOKEN_INSN, C_none, 0, I_VCMPEQ_UQPS },
        { "vcmpnge_usps", TOKEN_INSN, C_none, 0, I_VCMPNGE_USPS },
        { "vcmpngeps", TOKEN_INSN, C_none, 0, I_VCMPNGEPS },
        { "vcmpngt_usps", TOKEN_INSN, C_none, 0, I_VCMPNGT_USPS },
        { "vcmpngtps", TOKEN_INSN, C_none, 0, I_VCMPNGTPS },
        { "vcmpfalse_oqps", TOKEN_INSN, C_none, 0, I_VCMPFALSE_OQPS },
        { "vcmpfalseps", TOKEN_INSN, C_none, 0, I_VCMPFALSEPS },
        { "vcmpneq_oqps", TOKEN_INSN, C_none, 0, I_VCMPNEQ_OQPS },
        { "vcmpge_osps", TOKEN_INSN, C_none, 0, I_VCMPGE_OSPS },
        { "vcmpgeps", TOKEN_INSN, C_none, 0, I_VCMPGEPS },
        { "vcmpgt_osps", TOKEN_INSN, C_none, 0, I_VCMPGT_OSPS },
        { "vcmpgtps", TOKEN_INSN, C_none, 0, I_VCMPGTPS },
        { "vcmptrue_uqps", TOKEN_INSN, C_none, 0, I_VCMPTRUE_UQPS },
        { "vcmptrueps", TOKEN_INSN, C_none, 0, I_VCMPTRUEPS },
        { "vcmplt_oqps", TOKEN_INSN, C_none, 0, I_VCMPLT_OQPS },
        { "vcmple_oqps", TOKEN_INSN, C_none, 0, I_VCMPLE_OQPS },
        { "vcmpunord_sps", TOKEN_INSN, C_none, 0, I_VCMPUNORD_SPS },
        { "vcmpneq_usps", TOKEN_INSN, C_none, 0, I_VCMPNEQ_USPS },
        { "vcmpnlt_uqps", TOKEN_INSN, C_none, 0, I_VCMPNLT_UQPS },
        { "vcmpnle_uqps", TOKEN_INSN, C_none, 0, I_VCMPNLE_UQPS },
        { "vcmpord_sps", TOKEN_INSN, C_none, 0, I_VCMPORD_SPS },
        { "vcmpeq_usps", TOKEN_INSN, C_none, 0, I_VCMPEQ_USPS },
        { "vcmpnge_uqps", TOKEN_INSN, C_none, 0, I_VCMPNGE_UQPS },
        { "vcmpngt_uqps", TOKEN_INSN, C_none, 0, I_VCMPNGT_UQPS },
        { "vcmpfalse_osps", TOKEN_INSN, C_none, 0, I_VCMPFALSE_OSPS },
        { "vcmpneq_osps", TOKEN_INSN, C_none, 0, I_VCMPNEQ_OSPS },
        { "vcmpge_oqps", TOKEN_INSN, C_none, 0, I_VCMPGE_OQPS },
        { "vcmpgt_oqps", TOKEN_INSN, C_none, 0, I_VCMPGT_OQPS },
        { "vcmptrue_usps", TOKEN_INSN, C_none, 0, I_VCMPTRUE_USPS },
        { "vcmpps", TOKEN_INSN, C_none, 0, I_VCMPPS },
        { "vcmpeq_ossd", TOKEN_INSN, C_none, 0, I_VCMPEQ_OSSD },
        { "vcmpeqsd", TOKEN_INSN, C_none, 0, I_VCMPEQSD },
        { "vcmplt_ossd", TOKEN_INSN, C_none, 0, I_VCMPLT_OSSD },
        { "vcmpltsd", TOKEN_INSN, C_none, 0, I_VCMPLTSD },
        { "vcmple_ossd", TOKEN_INSN, C_none, 0, I_VCMPLE_OSSD },
        { "vcmplesd", TOKEN_INSN, C_none, 0, I_VCMPLESD },
        { "vcmpunord_qsd", TOKEN_INSN, C_none, 0, I_VCMPUNORD_QSD },
        { "vcmpunordsd", TOKEN_INSN, C_none, 0, I_VCMPUNORDSD },
        { "vcmpneq_uqsd", TOKEN_INSN, C_none, 0, I_VCMPNEQ_UQSD },
        { "vcmpneqsd", TOKEN_INSN, C_none, 0, I_VCMPNEQSD },
        { "vcmpnlt_ussd", TOKEN_INSN, C_none, 0, I_VCMPNLT_USSD },
        { "vcmpnltsd", TOKEN_INSN, C_none, 0, I_VCMPNLTSD },
        { "vcmpnle_ussd", TOKEN_INSN, C_none, 0, I_VCMPNLE_USSD },
        { "vcmpnlesd", TOKEN_INSN, C_none, 0, I_VCMPNLESD },
        { "vcmpord_qsd", TOKEN_INSN, C_none, 0, I_VCMPORD_QSD },
        { "vcmpordsd", TOKEN_INSN, C_none, 0, I_VCMPORDSD },
        { "vcmpeq_uqsd", TOKEN_INSN, C_none, 0, I_VCMPEQ_UQSD },
        { "vcmpnge_ussd", TOKEN_INSN, C_none, 0, I_VCMPNGE_USSD },
        { "vcmpngesd", TOKEN_INSN, C_none, 0, I_VCMPNGESD },
        { "vcmpngt_ussd", TOKEN_INSN, C_none, 0, I_VCMPNGT_USSD },
        { "vcmpngtsd", TOKEN_INSN, C_none, 0, I_VCMPNGTSD },
        { "vcmpfalse_oqsd", TOKEN_INSN, C_none, 0, I_VCMPFALSE_OQSD },
        { "vcmpfalsesd", TOKEN_INSN, C_none, 0, I_VCMPFALSESD },
        { "vcmpneq_oqsd", TOKEN_INSN, C_none, 0, I_VCMPNEQ_OQSD },
        { "vcmpge_ossd", TOKEN_INSN, C_none, 0, I_VCMPGE_OSSD },
        { "vcmpgesd", TOKEN_INSN, C_none, 0, I_VCMPGESD },
        { "vcmpgt_ossd", TOKEN_INSN, C_none, 0, I_VCMPGT_OSSD },
        { "vcmpgtsd", TOKEN_INSN, C_none, 0, I_VCMPGTSD },
        { "vcmptrue_uqsd", TOKEN_INSN, C_none, 0, I_VCMPTRUE_UQSD },
        { "vcmptruesd", TOKEN_INSN, C_none, 0, I_VCMPTRUESD },
        { "vcmplt_oqsd", TOKEN_INSN, C_none, 0, I_VCMPLT_OQSD },
        { "vcmple_oqsd", TOKEN_INSN, C_none, 0, I_VCMPLE_OQSD },
        { "vcmpunord_ssd", TOKEN_INSN, C_none, 0, I_VCMPUNORD_SSD },
        { "vcmpneq_ussd", TOKEN_INSN, C_none, 0, I_VCMPNEQ_USSD },
        { "vcmpnlt_uqsd", TOKEN_INSN, C_none, 0, I_VCMPNLT_UQSD },
        { "vcmpnle_uqsd", TOKEN_INSN, C_none, 0, I_VCMPNLE_UQSD },
        { "vcmpord_ssd", TOKEN_INSN, C_none, 0, I_VCMPORD_SSD },
        { "vcmpeq_ussd", TOKEN_INSN, C_none, 0, I_VCMPEQ_USSD },
        { "vcmpnge_uqsd", TOKEN_INSN, C_none, 0, I_VCMPNGE_UQSD },
        { "vcmpngt_uqsd", TOKEN_INSN, C_none, 0, I_VCMPNGT_UQSD },
        { "vcmpfalse_ossd", TOKEN_INSN, C_none, 0, I_VCMPFALSE_OSSD },
        { "vcmpneq_ossd", TOKEN_INSN, C_none, 0, I_VCMPNEQ_OSSD },
        { "vcmpge_oqsd", TOKEN_INSN, C_none, 0, I_VCMPGE_OQSD },
        { "vcmpgt_oqsd", TOKEN_INSN, C_none, 0, I_VCMPGT_OQSD },
        { "vcmptrue_ussd", TOKEN_INSN, C_none, 0, I_VCMPTRUE_USSD },
        { "vcmpsd", TOKEN_INSN, C_none, 0, I_VCMPSD },
        { "vcmpeq_osss", TOKEN_INSN, C_none, 0, I_VCMPEQ_OSSS },
        { "vcmpeqss", TOKEN_INSN, C_none, 0, I_VCMPEQSS },
        { "vcmplt_osss", TOKEN_INSN, C_none, 0, I_VCMPLT_OSSS },
        { "vcmpltss", TOKEN_INSN, C_none, 0, I_VCMPLTSS },
        { "vcmple_osss", TOKEN_INSN, C_none, 0, I_VCMPLE_OSSS },
        { "vcmpless", TOKEN_INSN, C_none, 0, I_VCMPLESS },
        { "vcmpunord_qss", TOKEN_INSN, C_none, 0, I_VCMPUNORD_QSS },
        { "vcmpunordss", TOKEN_INSN, C_none, 0, I_VCMPUNORDSS },
        { "vcmpneq_uqss", TOKEN_INSN, C_none, 0, I_VCMPNEQ_UQSS },
        { "vcmpneqss", TOKEN_INSN, C_none, 0, I_VCMPNEQSS },
        { "vcmpnlt_usss", TOKEN_INSN, C_none, 0, I_VCMPNLT_USSS },
        { "vcmpnltss", TOKEN_INSN, C_none, 0, I_VCMPNLTSS },
        { "vcmpnle_usss", TOKEN_INSN, C_none, 0, I_VCMPNLE_USSS },
        { "vcmpnless", TOKEN_INSN, C_none, 0, I_VCMPNLESS },
        { "vcmpord_qss", TOKEN_INSN, C_none, 0, I_VCMPORD_QSS },
        { "vcmpordss", TOKEN_INSN, C_none, 0, I_VCMPORDSS },
        { "vcmpeq_uqss", TOKEN_INSN, C_none, 0, I_VCMPEQ_UQSS },
        { "vcmpnge_usss", TOKEN_INSN, C_none, 0, I_VCMPNGE_USSS },
        { "vcmpngess", TOKEN_INSN, C_none, 0, I_VCMPNGESS },
        { "vcmpngt_usss", TOKEN_INSN, C_none, 0, I_VCMPNGT_USSS },
        { "vcmpngtss", TOKEN_INSN, C_none, 0, I_VCMPNGTSS },
        { "vcmpfalse_oqss", TOKEN_INSN, C_none, 0, I_VCMPFALSE_OQSS },
        { "vcmpfalsess", TOKEN_INSN, C_none, 0, I_VCMPFALSESS },
        { "vcmpneq_oqss", TOKEN_INSN, C_none, 0, I_VCMPNEQ_OQSS },
        { "vcmpge_osss", TOKEN_INSN, C_none, 0, I_VCMPGE_OSSS },
        { "vcmpgess", TOKEN_INSN, C_none, 0, I_VCMPGESS },
        { "vcmpgt_osss", TOKEN_INSN, C_none, 0, I_VCMPGT_OSSS },
        { "vcmpgtss", TOKEN_INSN, C_none, 0, I_VCMPGTSS },
        { "vcmptrue_uqss", TOKEN_INSN, C_none, 0, I_VCMPTRUE_UQSS },
        { "vcmptruess", TOKEN_INSN, C_none, 0, I_VCMPTRUESS },
        { "vcmplt_oqss", TOKEN_INSN, C_none, 0, I_VCMPLT_OQSS },
        { "vcmple_oqss", TOKEN_INSN, C_none, 0, I_VCMPLE_OQSS },
        { "vcmpunord_sss", TOKEN_INSN, C_none, 0, I_VCMPUNORD_SSS },
        { "vcmpneq_usss", TOKEN_INSN, C_none, 0, I_VCMPNEQ_USSS },
        { "vcmpnlt_uqss", TOKEN_INSN, C_none, 0, I_VCMPNLT_UQSS },
        { "vcmpnle_uqss", TOKEN_INSN, C_none, 0, I_VCMPNLE_UQSS },
        { "vcmpord_sss", TOKEN_INSN, C_none, 0, I_VCMPORD_SSS },
        { "vcmpeq_usss", TOKEN_INSN, C_none, 0, I_VCMPEQ_USSS },
        { "vcmpnge_uqss", TOKEN_INSN, C_none, 0, I_VCMPNGE_UQSS },
        { "vcmpngt_uqss", TOKEN_INSN, C_none, 0, I_VCMPNGT_UQSS },
        { "vcmpfalse_osss", TOKEN_INSN, C_none, 0, I_VCMPFALSE_OSSS },
        { "vcmpneq_osss", TOKEN_INSN, C_none, 0, I_VCMPNEQ_OSSS },
        { "vcmpge_oqss", TOKEN_INSN, C_none, 0, I_VCMPGE_OQSS },
        { "vcmpgt_oqss", TOKEN_INSN, C_none, 0, I_VCMPGT_OQSS },
        { "vcmptrue_usss", TOKEN_INSN, C_none, 0, I_VCMPTRUE_USSS },
        { "vcmpss", TOKEN_INSN, C_none, 0, I_VCMPSS },
        { "vcomisd", TOKEN_INSN, C_none, 0, I_VCOMISD },
        { "vcomiss", TOKEN_INSN, C_none, 0, I_VCOMISS },
        { "vcvtdq2pd", TOKEN_INSN, C_none, 0, I_VCVTDQ2PD },
        { "vcvtdq2ps", TOKEN_INSN, C_none, 0, I_VCVTDQ2PS },
        { "vcvtpd2dq", TOKEN_INSN, C_none, 0, I_VCVTPD2DQ },
        { "vcvtpd2ps", TOKEN_INSN, C_none, 0, I_VCVTPD2PS },
        { "vcvtps2dq", TOKEN_INSN, C_none, 0, I_VCVTPS2DQ },
        { "vcvtps2pd", TOKEN_INSN, C_none, 0, I_VCVTPS2PD },
        { "vcvtsd2si", TOKEN_INSN, C_none, 0, I_VCVTSD2SI },
        { "vcvtsd2ss", TOKEN_INSN, C_none, 0, I_VCVTSD2SS },
        { "vcvtsi2sd", TOKEN_INSN, C_none, 0, I_VCVTSI2SD },
        { "vcvtsi2ss", TOKEN_INSN, C_none, 0, I_VCVTSI2SS },
        { "vcvtss2sd", TOKEN_INSN, C_none, 0, I_VCVTSS2SD },
        { "vcvtss2si", TOKEN_INSN, C_none, 0, I_VCVTSS2SI },
        { "vcvttpd2dq", TOKEN_INSN, C_none, 0, I_VCVTTPD2DQ },
        { "vcvttps2dq", TOKEN_INSN, C_none, 0, I_VCVTTPS2DQ },
        { "vcvttsd2si", TOKEN_INSN, C_none, 0, I_VCVTTSD2SI },
        { "vcvttss2si", TOKEN_INSN, C_none, 0, I_VCVTTSS2SI },
        { "vdivpd", TOKEN_INSN, C_none, 0, I_VDIVPD },
        { "vdivps", TOKEN_INSN, C_none, 0, I_VDIVPS },
        { "vdivsd", TOKEN_INSN, C_none, 0, I_VDIVSD },
        { "vdivss", TOKEN_INSN, C_none, 0, I_VDIVSS },
        { "vdppd", TOKEN_INSN, C_none, 0, I_VDPPD },
        { "vdpps", TOKEN_INSN, C_none, 0, I_VDPPS },
        { "vextractf128", TOKEN_INSN, C_none, 0, I_VEXTRACTF128 },
        { "vextractps", TOKEN_INSN, C_none, 0, I_VEXTRACTPS },
        { "vhaddpd", TOKEN_INSN, C_none, 0, I_VHADDPD },
        { "vhaddps", TOKEN_INSN, C_none, 0, I_VHADDPS },
        { "vhsubpd", TOKEN_INSN, C_none, 0, I_VHSUBPD },
        { "vhsubps", TOKEN_INSN, C_none, 0, I_VHSUBPS },
        { "vinsertf128", TOKEN_INSN, C_none, 0, I_VINSERTF128 },
        { "vinsertps", TOKEN_INSN, C_none, 0, I_VINSERTPS },
        { "vlddqu", TOKEN_INSN, C_none, 0, I_VLDDQU },
        { "vldqqu", TOKEN_INSN, C_none, 0, I_VLDQQU },
        { "vldmxcsr", TOKEN_INSN, C_none, 0, I_VLDMXCSR },
        { "vmaskmovdqu", TOKEN_INSN, C_none, 0, I_VMASKMOVDQU },
        { "vmaskmovps", TOKEN_INSN, C_none, 0, I_VMASKMOVPS },
        { "vmaskmovpd", TOKEN_INSN, C_none, 0, I_VMASKMOVPD },
        { "vmaxpd", TOKEN_INSN, C_none, 0, I_VMAXPD },
        { "vmaxps", TOKEN_INSN, C_none, 0, I_VMAXPS },
        { "vmaxsd", TOKEN_INSN, C_none, 0, I_VMAXSD },
        { "vmaxss", TOKEN_INSN, C_none, 0, I_VMAXSS },
        { "vminpd", TOKEN_INSN, C_none, 0, I_VMINPD },
        { "vminps", TOKEN_INSN, C_none, 0, I_VMINPS },
        { "vminsd", TOKEN_INSN, C_none, 0, I_VMINSD },
        { "vminss", TOKEN_INSN, C_none, 0, I_VMINSS },
        { "vmovapd", TOKEN_INSN, C_none, 0, I_VMOVAPD },
        { "vmovaps", TOKEN_INSN, C_none, 0, I_VMOVAPS },
        { "vmovd", TOKEN_INSN, C_none, 0, I_VMOVD },
        { "vmovq", TOKEN_INSN, C_none, 0, I_VMOVQ },
        { "vmovddup", TOKEN_INSN, C_none, 0, I_VMOVDDUP },
        { "vmovdqa", TOKEN_INSN, C_none, 0, I_VMOVDQA },
        { "vmovqqa", TOKEN_INSN, C_none, 0, I_VMOVQQA },
        { "vmovdqu", TOKEN_INSN, C_none, 0, I_VMOVDQU },
        { "vmovqqu", TOKEN_INSN, C_none, 0, I_VMOVQQU },
        { "vmovhlps", TOKEN_INSN, C_none, 0, I_VMOVHLPS },
        { "vmovhpd", TOKEN_INSN, C_none, 0, I_VMOVHPD },
        { "vmovhps", TOKEN_INSN, C_none, 0, I_VMOVHPS },
        { "vmovlhps", TOKEN_INSN, C_none, 0, I_VMOVLHPS },
        { "vmovlpd", TOKEN_INSN, C_none, 0, I_VMOVLPD },
        { "vmovlps", TOKEN_INSN, C_none, 0, I_VMOVLPS },
        { "vmovmskpd", TOKEN_INSN, C_none, 0, I_VMOVMSKPD },
        { "vmovmskps", TOKEN_INSN, C_none, 0, I_VMOVMSKPS },
        { "vmovntdq", TOKEN_INSN, C_none, 0, I_VMOVNTDQ },
        { "vmovntqq", TOKEN_INSN, C_none, 0, I_VMOVNTQQ },
        { "vmovntdqa", TOKEN_INSN, C_none, 0, I_VMOVNTDQA },
        { "vmovntpd", TOKEN_INSN, C_none, 0, I_VMOVNTPD },
        { "vmovntps", TOKEN_INSN, C_none, 0, I_VMOVNTPS },
        { "vmovsd", TOKEN_INSN, C_none, 0, I_VMOVSD },
        { "vmovshdup", TOKEN_INSN, C_none, 0, I_VMOVSHDUP },
        { "vmovsldup", TOKEN_INSN, C_none, 0, I_VMOVSLDUP },
        { "vmovss", TOKEN_INSN, C_none, 0, I_VMOVSS },
        { "vmovupd", TOKEN_INSN, C_none, 0, I_VMOVUPD },
        { "vmovups", TOKEN_INSN, C_none, 0, I_VMOVUPS },
        { "vmpsadbw", TOKEN_INSN, C_none, 0, I_VMPSADBW },
        { "vmulpd", TOKEN_INSN, C_none, 0, I_VMULPD },
        { "vmulps", TOKEN_INSN, C_none, 0, I_VMULPS },
        { "vmulsd", TOKEN_INSN, C_none, 0, I_VMULSD },
        { "vmulss", TOKEN_INSN, C_none, 0, I_VMULSS },
        { "vorpd", TOKEN_INSN, C_none, 0, I_VORPD },
        { "vorps", TOKEN_INSN, C_none, 0, I_VORPS },
        { "vpabsb", TOKEN_INSN, C_none, 0, I_VPABSB },
        { "vpabsw", TOKEN_INSN, C_none, 0, I_VPABSW },
        { "vpabsd", TOKEN_INSN, C_none, 0, I_VPABSD },
        { "vpacksswb", TOKEN_INSN, C_none, 0, I_VPACKSSWB },
        { "vpackssdw", TOKEN_INSN, C_none, 0, I_VPACKSSDW },
        { "vpackuswb", TOKEN_INSN, C_none, 0, I_VPACKUSWB },
        { "vpackusdw", TOKEN_INSN, C_none, 0, I_VPACKUSDW },
        { "vpaddb", TOKEN_INSN, C_none, 0, I_VPADDB },
        { "vpaddw", TOKEN_INSN, C_none, 0, I_VPADDW },
        { "vpaddd", TOKEN_INSN, C_none, 0, I_VPADDD },
        { "vpaddq", TOKEN_INSN, C_none, 0, I_VPADDQ },
        { "vpaddsb", TOKEN_INSN, C_none, 0, I_VPADDSB },
        { "vpaddsw", TOKEN_INSN, C_none, 0, I_VPADDSW },
        { "vpaddusb", TOKEN_INSN, C_none, 0, I_VPADDUSB },
        { "vpaddusw", TOKEN_INSN, C_none, 0, I_VPADDUSW },
        { "vpalignr", TOKEN_INSN, C_none, 0, I_VPALIGNR },
        { "vpand", TOKEN_INSN, C_none, 0, I_VPAND },
        { "vpandn", TOKEN_INSN, C_none, 0, I_VPANDN },
        { "vpavgb", TOKEN_INSN, C_none, 0, I_VPAVGB },
        { "vpavgw", TOKEN_INSN, C_none, 0, I_VPAVGW },
        { "vpblendvb", TOKEN_INSN, C_none, 0, I_VPBLENDVB },
        { "vpblendw", TOKEN_INSN, C_none, 0, I_VPBLENDW },
        { "vpcmpestri", TOKEN_INSN, C_none, 0, I_VPCMPESTRI },
        { "vpcmpestrm", TOKEN_INSN, C_none, 0, I_VPCMPESTRM },
        { "vpcmpistri", TOKEN_INSN, C_none, 0, I_VPCMPISTRI },
        { "vpcmpistrm", TOKEN_INSN, C_none, 0, I_VPCMPISTRM },
        { "vpcmpeqb", TOKEN_INSN, C_none, 0, I_VPCMPEQB },
        { "vpcmpeqw", TOKEN_INSN, C_none, 0, I_VPCMPEQW },
        { "vpcmpeqd", TOKEN_INSN, C_none, 0, I_VPCMPEQD },
        { "vpcmpeqq", TOKEN_INSN, C_none, 0, I_VPCMPEQQ },
        { "vpcmpgtb", TOKEN_INSN, C_none, 0, I_VPCMPGTB },
        { "vpcmpgtw", TOKEN_INSN, C_none, 0, I_VPCMPGTW },
        { "vpcmpgtd", TOKEN_INSN, C_none, 0, I_VPCMPGTD },
        { "vpcmpgtq", TOKEN_INSN, C_none, 0, I_VPCMPGTQ },
        { "vpermilpd", TOKEN_INSN, C_none, 0, I_VPERMILPD },
        { "vpermilps", TOKEN_INSN, C_none, 0, I_VPERMILPS },
        { "vperm2f128", TOKEN_INSN, C_none, 0, I_VPERM2F128 },
        { "vpextrb", TOKEN_INSN, C_none, 0, I_VPEXTRB },
        { "vpextrw", TOKEN_INSN, C_none, 0, I_VPEXTRW },
        { "vpextrd", TOKEN_INSN, C_none, 0, I_VPEXTRD },
        { "vpextrq", TOKEN_INSN, C_none, 0, I_VPEXTRQ },
        { "vphaddw", TOKEN_INSN, C_none, 0, I_VPHADDW },
        { "vphaddd", TOKEN_INSN, C_none, 0, I_VPHADDD },
        { "vphaddsw", TOKEN_INSN, C_none, 0, I_VPHADDSW },
        { "vphminposuw", TOKEN_INSN, C_none, 0, I_VPHMINPOSUW },
        { "vphsubw", TOKEN_INSN, C_none, 0, I_VPHSUBW },
        { "vphsubd", TOKEN_INSN, C_none, 0, I_VPHSUBD },
        { "vphsubsw", TOKEN_INSN, C_none, 0, I_VPHSUBSW },
        { "vpinsrb", TOKEN_INSN, C_none, 0, I_VPINSRB },
        { "vpinsrw", TOKEN_INSN, C_none, 0, I_VPINSRW },
        { "vpinsrd", TOKEN_INSN, C_none, 0, I_VPINSRD },
        { "vpinsrq", TOKEN_INSN, C_none, 0, I_VPINSRQ },
        { "vpmaddwd", TOKEN_INSN, C_none, 0, I_VPMADDWD },
        { "vpmaddubsw", TOKEN_INSN, C_none, 0, I_VPMADDUBSW },
        { "vpmaxsb", TOKEN_INSN, C_none, 0, I_VPMAXSB },
        { "vpmaxsw", TOKEN_INSN, C_none, 0, I_VPMAXSW },
        { "vpmaxsd", TOKEN_INSN, C_none, 0, I_VPMAXSD },
        { "vpmaxub", TOKEN_INSN, C_none, 0, I_VPMAXUB },
        { "vpmaxuw", TOKEN_INSN, C_none, 0, I_VPMAXUW },
        { "vpmaxud", TOKEN_INSN, C_none, 0, I_VPMAXUD },
        { "vpminsb", TOKEN_INSN, C_none, 0, I_VPMINSB },
        { "vpminsw", TOKEN_INSN, C_none, 0, I_VPMINSW },
        { "vpminsd", TOKEN_INSN, C_none, 0, I_VPMINSD },
        { "vpminub", TOKEN_INSN, C_none, 0, I_VPMINUB },
        { "vpminuw", TOKEN_INSN, C_none, 0, I_VPMINUW },
        { "vpminud", TOKEN_INSN, C_none, 0, I_VPMINUD },
        { "vpmovmskb", TOKEN_INSN, C_none, 0, I_VPMOVMSKB },
        { "vpmovsxbw", TOKEN_INSN, C_none, 0, I_VPMOVSXBW },
        { "vpmovsxbd", TOKEN_INSN, C_none, 0, I_VPMOVSXBD },
        { "vpmovsxbq", TOKEN_INSN, C_none, 0, I_VPMOVSXBQ },
        { "vpmovsxwd", TOKEN_INSN, C_none, 0, I_VPMOVSXWD },
        { "vpmovsxwq", TOKEN_INSN, C_none, 0, I_VPMOVSXWQ },
        { "vpmovsxdq", TOKEN_INSN, C_none, 0, I_VPMOVSXDQ },
        { "vpmovzxbw", TOKEN_INSN, C_none, 0, I_VPMOVZXBW },
        { "vpmovzxbd", TOKEN_INSN, C_none, 0, I_VPMOVZXBD },
        { "vpmovzxbq", TOKEN_INSN, C_none, 0, I_VPMOVZXBQ },
        { "vpmovzxwd", TOKEN_INSN, C_none, 0, I_VPMOVZXWD },
        { "vpmovzxwq", TOKEN_INSN, C_none, 0, I_VPMOVZXWQ },
        { "vpmovzxdq", TOKEN_INSN, C_none, 0, I_VPMOVZXDQ },
        { "vpmulhuw", TOKEN_INSN, C_none, 0, I_VPMULHUW },
        { "vpmulhrsw", TOKEN_INSN, C_none, 0, I_VPMULHRSW },
        { "vpmulhw", TOKEN_INSN, C_none, 0, I_VPMULHW },
        { "vpmullw", TOKEN_INSN, C_none, 0, I_VPMULLW },
        { "vpmulld", TOKEN_INSN, C_none, 0, I_VPMULLD },
        { "vpmuludq", TOKEN_INSN, C_none, 0, I_VPMULUDQ },
        { "vpmuldq", TOKEN_INSN, C_none, 0, I_VPMULDQ },
        { "vpor", TOKEN_INSN, C_none, 0, I_VPOR },
        { "vpsadbw", TOKEN_INSN, C_none, 0, I_VPSADBW },
        { "vpshufb", TOKEN_INSN, C_none, 0, I_VPSHUFB },
        { "vpshufd", TOKEN_INSN, C_none, 0, I_VPSHUFD },
        { "vpshufhw", TOKEN_INSN, C_none, 0, I_VPSHUFHW },
        { "vpshuflw", TOKEN_INSN, C_none, 0, I_VPSHUFLW },
        { "vpsignb", TOKEN_INSN, C_none, 0, I_VPSIGNB },
        { "vpsignw", TOKEN_INSN, C_none, 0, I_VPSIGNW },
        { "vpsignd", TOKEN_INSN, C_none, 0, I_VPSIGND },
        { "vpslldq", TOKEN_INSN, C_none, 0, I_VPSLLDQ },
        { "vpsrldq", TOKEN_INSN, C_none, 0, I_VPSRLDQ },
        { "vpsllw", TOKEN_INSN, C_none, 0, I_VPSLLW },
        { "vpslld", TOKEN_INSN, C_none, 0, I_VPSLLD },
        { "vpsllq", TOKEN_INSN, C_none, 0, I_VPSLLQ },
        { "vpsraw", TOKEN_INSN, C_none, 0, I_VPSRAW },
        { "vpsrad", TOKEN_INSN, C_none, 0, I_VPSRAD },
        { "vpsrlw", TOKEN_INSN, C_none, 0, I_VPSRLW },
        { "vpsrld", TOKEN_INSN, C_none, 0, I_VPSRLD },
        { "vpsrlq", TOKEN_INSN, C_none, 0, I_VPSRLQ },
        { "vptest", TOKEN_INSN, C_none, 0, I_VPTEST },
        { "vpsubb", TOKEN_INSN, C_none, 0, I_VPSUBB },
        { "vpsubw", TOKEN_INSN, C_none, 0, I_VPSUBW },
        { "vpsubd", TOKEN_INSN, C_none, 0, I_VPSUBD },
        { "vpsubq", TOKEN_INSN, C_none, 0, I_VPSUBQ },
        { "vpsubsb", TOKEN_INSN, C_none, 0, I_VPSUBSB },
        { "vpsubsw", TOKEN_INSN, C_none, 0, I_VPSUBSW },
        { "vpsubusb", TOKEN_INSN, C_none, 0, I_VPSUBUSB },
        { "vpsubusw", TOKEN_INSN, C_none, 0, I_VPSUBUSW },
        { "vpunpckhbw", TOKEN_INSN, C_none, 0, I_VPUNPCKHBW },
        { "vpunpckhwd", TOKEN_INSN, C_none, 0, I_VPUNPCKHWD },
        { "vpunpckhdq", TOKEN_INSN, C_none, 0, I_VPUNPCKHDQ },
        { "vpunpckhqdq", TOKEN_INSN, C_none, 0, I_VPUNPCKHQDQ },
        { "vpunpcklbw", TOKEN_INSN, C_none, 0, I_VPUNPCKLBW },
        { "vpunpcklwd", TOKEN_INSN, C_none, 0, I_VPUNPCKLWD },
        { "vpunpckldq", TOKEN_INSN, C_none, 0, I_VPUNPCKLDQ },
        { "vpunpcklqdq", TOKEN_INSN, C_none, 0, I_VPUNPCKLQDQ },
        { "vpxor", TOKEN_INSN, C_none, 0, I_VPXOR },
        { "vrcpps", TOKEN_INSN, C_none, 0, I_VRCPPS },
        { "vrcpss", TOKEN_INSN, C_none, 0, I_VRCPSS },
        { "vrsqrtps", TOKEN_INSN, C_none, 0, I_VRSQRTPS },
        { "vrsqrtss", TOKEN_INSN, C_none, 0, I_VRSQRTSS },
        { "vroundpd", TOKEN_INSN, C_none, 0, I_VROUNDPD },
        { "vroundps", TOKEN_INSN, C_none, 0, I_VROUNDPS },
        { "vroundsd", TOKEN_INSN, C_none, 0, I_VROUNDSD },
        { "vroundss", TOKEN_INSN, C_none, 0, I_VROUNDSS },
        { "vshufpd", TOKEN_INSN, C_none, 0, I_VSHUFPD },
        { "vshufps", TOKEN_INSN, C_none, 0, I_VSHUFPS },
        { "vsqrtpd", TOKEN_INSN, C_none, 0, I_VSQRTPD },
        { "vsqrtps", TOKEN_INSN, C_none, 0, I_VSQRTPS },
        { "vsqrtsd", TOKEN_INSN, C_none, 0, I_VSQRTSD },
        { "vsqrtss", TOKEN_INSN, C_none, 0, I_VSQRTSS },
        { "vstmxcsr", TOKEN_INSN, C_none, 0, I_VSTMXCSR },
        { "vsubpd", TOKEN_INSN, C_none, 0, I_VSUBPD },
        { "vsubps", TOKEN_INSN, C_none, 0, I_VSUBPS },
        { "vsubsd", TOKEN_INSN, C_none, 0, I_VSUBSD },
        { "vsubss", TOKEN_INSN, C_none, 0, I_VSUBSS },
        { "vtestps", TOKEN_INSN, C_none, 0, I_VTESTPS },
        { "vtestpd", TOKEN_INSN, C_none, 0, I_VTESTPD },
        { "vucomisd", TOKEN_INSN, C_none, 0, I_VUCOMISD },
        { "vucomiss", TOKEN_INSN, C_none, 0, I_VUCOMISS },
        { "vunpckhpd", TOKEN_INSN, C_none, 0, I_VUNPCKHPD },
        { "vunpckhps", TOKEN_INSN, C_none, 0, I_VUNPCKHPS },
        { "vunpcklpd", TOKEN_INSN, C_none, 0, I_VUNPCKLPD },
        { "vunpcklps", TOKEN_INSN, C_none, 0, I_VUNPCKLPS },
        { "vxorpd", TOKEN_INSN, C_none, 0, I_VXORPD },
        { "vxorps", TOKEN_INSN, C_none, 0, I_VXORPS },
        { "vzeroall", TOKEN_INSN, C_none, 0, I_VZEROALL },
        { "vzeroupper", TOKEN_INSN, C_none, 0, I_VZEROUPPER },
        { "pclmullqlqdq", TOKEN_INSN, C_none, 0, I_PCLMULLQLQDQ },
        { "pclmulhqlqdq", TOKEN_INSN, C_none, 0, I_PCLMULHQLQDQ },
        { "pclmullqhqdq", TOKEN_INSN, C_none, 0, I_PCLMULLQHQDQ },
        { "pclmulhqhqdq", TOKEN_INSN, C_none, 0, I_PCLMULHQHQDQ },
        { "pclmulqdq", TOKEN_INSN, C_none, 0, I_PCLMULQDQ },
        { "vpclmullqlqdq", TOKEN_INSN, C_none, 0, I_VPCLMULLQLQDQ },
        { "vpclmulhqlqdq", TOKEN_INSN, C_none, 0, I_VPCLMULHQLQDQ },
        { "vpclmullqhqdq", TOKEN_INSN, C_none, 0, I_VPCLMULLQHQDQ },
        { "vpclmulhqhqdq", TOKEN_INSN, C_none, 0, I_VPCLMULHQHQDQ },
        { "vpclmulqdq", TOKEN_INSN, C_none, 0, I_VPCLMULQDQ },
        { "vfmadd132ps", TOKEN_INSN, C_none, 0, I_VFMADD132PS },
        { "vfmadd132pd", TOKEN_INSN, C_none, 0, I_VFMADD132PD },
        { "vfmadd312ps", TOKEN_INSN, C_none, 0, I_VFMADD312PS },
        { "vfmadd312pd", TOKEN_INSN, C_none, 0, I_VFMADD312PD },
        { "vfmadd213ps", TOKEN_INSN, C_none, 0, I_VFMADD213PS },
        { "vfmadd213pd", TOKEN_INSN, C_none, 0, I_VFMADD213PD },
        { "vfmadd123ps", TOKEN_INSN, C_none, 0, I_VFMADD123PS },
        { "vfmadd123pd", TOKEN_INSN, C_none, 0, I_VFMADD123PD },
        { "vfmadd231ps", TOKEN_INSN, C_none, 0, I_VFMADD231PS },
        { "vfmadd231pd", TOKEN_INSN, C_none, 0, I_VFMADD231PD },
        { "vfmadd321ps", TOKEN_INSN, C_none, 0, I_VFMADD321PS },
        { "vfmadd321pd", TOKEN_INSN, C_none, 0, I_VFMADD321PD },
        { "vfmaddsub132ps", TOKEN_INSN, C_none, 0, I_VFMADDSUB132PS },
        { "vfmaddsub132pd", TOKEN_INSN, C_none, 0, I_VFMADDSUB132PD },
        { "vfmaddsub312ps", TOKEN_INSN, C_none, 0, I_VFMADDSUB312PS },
        { "vfmaddsub312pd", TOKEN_INSN, C_none, 0, I_VFMADDSUB312PD },
        { "vfmaddsub213ps", TOKEN_INSN, C_none, 0, I_VFMADDSUB213PS },
        { "vfmaddsub213pd", TOKEN_INSN, C_none, 0, I_VFMADDSUB213PD },
        { "vfmaddsub123ps", TOKEN_INSN, C_none, 0, I_VFMADDSUB123PS },
        { "vfmaddsub123pd", TOKEN_INSN, C_none, 0, I_VFMADDSUB123PD },
        { "vfmaddsub231ps", TOKEN_INSN, C_none, 0, I_VFMADDSUB231PS },
        { "vfmaddsub231pd", TOKEN_INSN, C_none, 0, I_VFMADDSUB231PD },
        { "vfmaddsub321ps", TOKEN_INSN, C_none, 0, I_VFMADDSUB321PS },
        { "vfmaddsub321pd", TOKEN_INSN, C_none, 0, I_VFMADDSUB321PD },
        { "vfmsub132ps", TOKEN_INSN, C_none, 0, I_VFMSUB132PS },
        { "vfmsub132pd", TOKEN_INSN, C_none, 0, I_VFMSUB132PD },
        { "vfmsub312ps", TOKEN_INSN, C_none, 0, I_VFMSUB312PS },
        { "vfmsub312pd", TOKEN_INSN, C_none, 0, I_VFMSUB312PD },
        { "vfmsub213ps", TOKEN_INSN, C_none, 0, I_VFMSUB213PS },
        { "vfmsub213pd", TOKEN_INSN, C_none, 0, I_VFMSUB213PD },
        { "vfmsub123ps", TOKEN_INSN, C_none, 0, I_VFMSUB123PS },
        { "vfmsub123pd", TOKEN_INSN, C_none, 0, I_VFMSUB123PD },
        { "vfmsub231ps", TOKEN_INSN, C_none, 0, I_VFMSUB231PS },
        { "vfmsub231pd", TOKEN_INSN, C_none, 0, I_VFMSUB231PD },
        { "vfmsub321ps", TOKEN_INSN, C_none, 0, I_VFMSUB321PS },
        { "vfmsub321pd", TOKEN_INSN, C_none, 0, I_VFMSUB321PD },
        { "vfmsubadd132ps", TOKEN_INSN, C_none, 0, I_VFMSUBADD132PS },
        { "vfmsubadd132pd", TOKEN_INSN, C_none, 0, I_VFMSUBADD132PD },
        { "vfmsubadd312ps", TOKEN_INSN, C_none, 0, I_VFMSUBADD312PS },
        { "vfmsubadd312pd", TOKEN_INSN, C_none, 0, I_VFMSUBADD312PD },
        { "vfmsubadd213ps", TOKEN_INSN, C_none, 0, I_VFMSUBADD213PS },
        { "vfmsubadd213pd", TOKEN_INSN, C_none, 0, I_VFMSUBADD213PD },
        { "vfmsubadd123ps", TOKEN_INSN, C_none, 0, I_VFMSUBADD123PS },
        { "vfmsubadd123pd", TOKEN_INSN, C_none, 0, I_VFMSUBADD123PD },
        { "vfmsubadd231ps", TOKEN_INSN, C_none, 0, I_VFMSUBADD231PS },
        { "vfmsubadd231pd", TOKEN_INSN, C_none, 0, I_VFMSUBADD231PD },
        { "vfmsubadd321ps", TOKEN_INSN, C_none, 0, I_VFMSUBADD321PS },
        { "vfmsubadd321pd", TOKEN_INSN, C_none, 0, I_VFMSUBADD321PD },
        { "vfnmadd132ps", TOKEN_INSN, C_none, 0, I_VFNMADD132PS },
        { "vfnmadd132pd", TOKEN_INSN, C_none, 0, I_VFNMADD132PD },
        { "vfnmadd312ps", TOKEN_INSN, C_none, 0, I_VFNMADD312PS },
        { "vfnmadd312pd", TOKEN_INSN, C_none, 0, I_VFNMADD312PD },
        { "vfnmadd213ps", TOKEN_INSN, C_none, 0, I_VFNMADD213PS },
        { "vfnmadd213pd", TOKEN_INSN, C_none, 0, I_VFNMADD213PD },
        { "vfnmadd123ps", TOKEN_INSN, C_none, 0, I_VFNMADD123PS },
        { "vfnmadd123pd", TOKEN_INSN, C_none, 0, I_VFNMADD123PD },
        { "vfnmadd231ps", TOKEN_INSN, C_none, 0, I_VFNMADD231PS },
        { "vfnmadd231pd", TOKEN_INSN, C_none, 0, I_VFNMADD231PD },
        { "vfnmadd321ps", TOKEN_INSN, C_none, 0, I_VFNMADD321PS },
        { "vfnmadd321pd", TOKEN_INSN, C_none, 0, I_VFNMADD321PD },
        { "vfnmsub132ps", TOKEN_INSN, C_none, 0, I_VFNMSUB132PS },
        { "vfnmsub132pd", TOKEN_INSN, C_none, 0, I_VFNMSUB132PD },
        { "vfnmsub312ps", TOKEN_INSN, C_none, 0, I_VFNMSUB312PS },
        { "vfnmsub312pd", TOKEN_INSN, C_none, 0, I_VFNMSUB312PD },
        { "vfnmsub213ps", TOKEN_INSN, C_none, 0, I_VFNMSUB213PS },
        { "vfnmsub213pd", TOKEN_INSN, C_none, 0, I_VFNMSUB213PD },
        { "vfnmsub123ps", TOKEN_INSN, C_none, 0, I_VFNMSUB123PS },
        { "vfnmsub123pd", TOKEN_INSN, C_none, 0, I_VFNMSUB123PD },
        { "vfnmsub231ps", TOKEN_INSN, C_none, 0, I_VFNMSUB231PS },
        { "vfnmsub231pd", TOKEN_INSN, C_none, 0, I_VFNMSUB231PD },
        { "vfnmsub321ps", TOKEN_INSN, C_none, 0, I_VFNMSUB321PS },
        { "vfnmsub321pd", TOKEN_INSN, C_none, 0, I_VFNMSUB321PD },
        { "vfmadd132ss", TOKEN_INSN, C_none, 0, I_VFMADD132SS },
        { "vfmadd132sd", TOKEN_INSN, C_none, 0, I_VFMADD132SD },
        { "vfmadd312ss", TOKEN_INSN, C_none, 0, I_VFMADD312SS },
        { "vfmadd312sd", TOKEN_INSN, C_none, 0, I_VFMADD312SD },
        { "vfmadd213ss", TOKEN_INSN, C_none, 0, I_VFMADD213SS },
        { "vfmadd213sd", TOKEN_INSN, C_none, 0, I_VFMADD213SD },
        { "vfmadd123ss", TOKEN_INSN, C_none, 0, I_VFMADD123SS },
        { "vfmadd123sd", TOKEN_INSN, C_none, 0, I_VFMADD123SD },
        { "vfmadd231ss", TOKEN_INSN, C_none, 0, I_VFMADD231SS },
        { "vfmadd231sd", TOKEN_INSN, C_none, 0, I_VFMADD231SD },
        { "vfmadd321ss", TOKEN_INSN, C_none, 0, I_VFMADD321SS },
        { "vfmadd321sd", TOKEN_INSN, C_none, 0, I_VFMADD321SD },
        { "vfmsub132ss", TOKEN_INSN, C_none, 0, I_VFMSUB132SS },
        { "vfmsub132sd", TOKEN_INSN, C_none, 0, I_VFMSUB132SD },
        { "vfmsub312ss", TOKEN_INSN, C_none, 0, I_VFMSUB312SS },
        { "vfmsub312sd", TOKEN_INSN, C_none, 0, I_VFMSUB312SD },
        { "vfmsub213ss", TOKEN_INSN, C_none, 0, I_VFMSUB213SS },
        { "vfmsub213sd", TOKEN_INSN, C_none, 0, I_VFMSUB213SD },
        { "vfmsub123ss", TOKEN_INSN, C_none, 0, I_VFMSUB123SS },
        { "vfmsub123sd", TOKEN_INSN, C_none, 0, I_VFMSUB123SD },
        { "vfmsub231ss", TOKEN_INSN, C_none, 0, I_VFMSUB231SS },
        { "vfmsub231sd", TOKEN_INSN, C_none, 0, I_VFMSUB231SD },
        { "vfmsub321ss", TOKEN_INSN, C_none, 0, I_VFMSUB321SS },
        { "vfmsub321sd", TOKEN_INSN, C_none, 0, I_VFMSUB321SD },
        { "vfnmadd132ss", TOKEN_INSN, C_none, 0, I_VFNMADD132SS },
        { "vfnmadd132sd", TOKEN_INSN, C_none, 0, I_VFNMADD132SD },
        { "vfnmadd312ss", TOKEN_INSN, C_none, 0, I_VFNMADD312SS },
        { "vfnmadd312sd", TOKEN_INSN, C_none, 0, I_VFNMADD312SD },
        { "vfnmadd213ss", TOKEN_INSN, C_none, 0, I_VFNMADD213SS },
        { "vfnmadd213sd", TOKEN_INSN, C_none, 0, I_VFNMADD213SD },
        { "vfnmadd123ss", TOKEN_INSN, C_none, 0, I_VFNMADD123SS },
        { "vfnmadd123sd", TOKEN_INSN, C_none, 0, I_VFNMADD123SD },
        { "vfnmadd231ss", TOKEN_INSN, C_none, 0, I_VFNMADD231SS },
        { "vfnmadd231sd", TOKEN_INSN, C_none, 0, I_VFNMADD231SD },
        { "vfnmadd321ss", TOKEN_INSN, C_none, 0, I_VFNMADD321SS },
        { "vfnmadd321sd", TOKEN_INSN, C_none, 0, I_VFNMADD321SD },
        { "vfnmsub132ss", TOKEN_INSN, C_none, 0, I_VFNMSUB132SS },
        { "vfnmsub132sd", TOKEN_INSN, C_none, 0, I_VFNMSUB132SD },
        { "vfnmsub312ss", TOKEN_INSN, C_none, 0, I_VFNMSUB312SS },
        { "vfnmsub312sd", TOKEN_INSN, C_none, 0, I_VFNMSUB312SD },
        { "vfnmsub213ss", TOKEN_INSN, C_none, 0, I_VFNMSUB213SS },
        { "vfnmsub213sd", TOKEN_INSN, C_none, 0, I_VFNMSUB213SD },
        { "vfnmsub123ss", TOKEN_INSN, C_none, 0, I_VFNMSUB123SS },
        { "vfnmsub123sd", TOKEN_INSN, C_none, 0, I_VFNMSUB123SD },
        { "vfnmsub231ss", TOKEN_INSN, C_none, 0, I_VFNMSUB231SS },
        { "vfnmsub231sd", TOKEN_INSN, C_none, 0, I_VFNMSUB231SD },
        { "vfnmsub321ss", TOKEN_INSN, C_none, 0, I_VFNMSUB321SS },
        { "vfnmsub321sd", TOKEN_INSN, C_none, 0, I_VFNMSUB321SD },
        { "rdfsbase", TOKEN_INSN, C_none, 0, I_RDFSBASE },
        { "rdgsbase", TOKEN_INSN, C_none, 0, I_RDGSBASE },
        { "rdrand", TOKEN_INSN, C_none, 0, I_RDRAND },
        { "wrfsbase", TOKEN_INSN, C_none, 0, I_WRFSBASE },
        { "wrgsbase", TOKEN_INSN, C_none, 0, I_WRGSBASE },
        { "vcvtph2ps", TOKEN_INSN, C_none, 0, I_VCVTPH2PS },
        { "vcvtps2ph", TOKEN_INSN, C_none, 0, I_VCVTPS2PH },
        { "adcx", TOKEN_INSN, C_none, 0, I_ADCX },
        { "adox", TOKEN_INSN, C_none, 0, I_ADOX },
        { "rdseed", TOKEN_INSN, C_none, 0, I_RDSEED },
        { "clac", TOKEN_INSN, C_none, 0, I_CLAC },
        { "stac", TOKEN_INSN, C_none, 0, I_STAC },
        { "xstore", TOKEN_INSN, C_none, 0, I_XSTORE },
        { "xcryptecb", TOKEN_INSN, C_none, 0, I_XCRYPTECB },
        { "xcryptcbc", TOKEN_INSN, C_none, 0, I_XCRYPTCBC },
        { "xcryptctr", TOKEN_INSN, C_none, 0, I_XCRYPTCTR },
        { "xcryptcfb", TOKEN_INSN, C_none, 0, I_XCRYPTCFB },
        { "xcryptofb", TOKEN_INSN, C_none, 0, I_XCRYPTOFB },
        { "montmul", TOKEN_INSN, C_none, 0, I_MONTMUL },
        { "xsha1", TOKEN_INSN, C_none, 0, I_XSHA1 },
        { "xsha256", TOKEN_INSN, C_none, 0, I_XSHA256 },
        { "llwpcb", TOKEN_INSN, C_none, 0, I_LLWPCB },
        { "slwpcb", TOKEN_INSN, C_none, 0, I_SLWPCB },
        { "lwpval", TOKEN_INSN, C_none, 0, I_LWPVAL },
        { "lwpins", TOKEN_INSN, C_none, 0, I_LWPINS },
        { "vfmaddpd", TOKEN_INSN, C_none, 0, I_VFMADDPD },
        { "vfmaddps", TOKEN_INSN, C_none, 0, I_VFMADDPS },
        { "vfmaddsd", TOKEN_INSN, C_none, 0, I_VFMADDSD },
        { "vfmaddss", TOKEN_INSN, C_none, 0, I_VFMADDSS },
        { "vfmaddsubpd", TOKEN_INSN, C_none, 0, I_VFMADDSUBPD },
        { "vfmaddsubps", TOKEN_INSN, C_none, 0, I_VFMADDSUBPS },
        { "vfmsubaddpd", TOKEN_INSN, C_none, 0, I_VFMSUBADDPD },
        { "vfmsubaddps", TOKEN_INSN, C_none, 0, I_VFMSUBADDPS },
        { "vfmsubpd", TOKEN_INSN, C_none, 0, I_VFMSUBPD },
        { "vfmsubps", TOKEN_INSN, C_none, 0, I_VFMSUBPS },
        { "vfmsubsd", TOKEN_INSN, C_none, 0, I_VFMSUBSD },
        { "vfmsubss", TOKEN_INSN, C_none, 0, I_VFMSUBSS },
        { "vfnmaddpd", TOKEN_INSN, C_none, 0, I_VFNMADDPD },
        { "vfnmaddps", TOKEN_INSN, C_none, 0, I_VFNMADDPS },
        { "vfnmaddsd", TOKEN_INSN, C_none, 0, I_VFNMADDSD },
        { "vfnmaddss", TOKEN_INSN, C_none, 0, I_VFNMADDSS },
        { "vfnmsubpd", TOKEN_INSN, C_none, 0, I_VFNMSUBPD },
        { "vfnmsubps", TOKEN_INSN, C_none, 0, I_VFNMSUBPS },
        { "vfnmsubsd", TOKEN_INSN, C_none, 0, I_VFNMSUBSD },
        { "vfnmsubss", TOKEN_INSN, C_none, 0, I_VFNMSUBSS },
        { "vfrczpd", TOKEN_INSN, C_none, 0, I_VFRCZPD },
        { "vfrczps", TOKEN_INSN, C_none, 0, I_VFRCZPS },
        { "vfrczsd", TOKEN_INSN, C_none, 0, I_VFRCZSD },
        { "vfrczss", TOKEN_INSN, C_none, 0, I_VFRCZSS },
        { "vpcmov", TOKEN_INSN, C_none, 0, I_VPCMOV },
        { "vpcomb", TOKEN_INSN, C_none, 0, I_VPCOMB },
        { "vpcomd", TOKEN_INSN, C_none, 0, I_VPCOMD },
        { "vpcomq", TOKEN_INSN, C_none, 0, I_VPCOMQ },
        { "vpcomub", TOKEN_INSN, C_none, 0, I_VPCOMUB },
        { "vpcomud", TOKEN_INSN, C_none, 0, I_VPCOMUD },
        { "vpcomuq", TOKEN_INSN, C_none, 0, I_VPCOMUQ },
        { "vpcomuw", TOKEN_INSN, C_none, 0, I_VPCOMUW },
        { "vpcomw", TOKEN_INSN, C_none, 0, I_VPCOMW },
        { "vphaddbd", TOKEN_INSN, C_none, 0, I_VPHADDBD },
        { "vphaddbq", TOKEN_INSN, C_none, 0, I_VPHADDBQ },
        { "vphaddbw", TOKEN_INSN, C_none, 0, I_VPHADDBW },
        { "vphadddq", TOKEN_INSN, C_none, 0, I_VPHADDDQ },
        { "vphaddubd", TOKEN_INSN, C_none, 0, I_VPHADDUBD },
        { "vphaddubq", TOKEN_INSN, C_none, 0, I_VPHADDUBQ },
        { "vphaddubw", TOKEN_INSN, C_none, 0, I_VPHADDUBW },
        { "vphaddudq", TOKEN_INSN, C_none, 0, I_VPHADDUDQ },
        { "vphadduwd", TOKEN_INSN, C_none, 0, I_VPHADDUWD },
        { "vphadduwq", TOKEN_INSN, C_none, 0, I_VPHADDUWQ },
        { "vphaddwd", TOKEN_INSN, C_none, 0, I_VPHADDWD },
        { "vphaddwq", TOKEN_INSN, C_none, 0, I_VPHADDWQ },
        { "vphsubbw", TOKEN_INSN, C_none, 0, I_VPHSUBBW },
        { "vphsubdq", TOKEN_INSN, C_none, 0, I_VPHSUBDQ },
        { "vphsubwd", TOKEN_INSN, C_none, 0, I_VPHSUBWD },
        { "vpmacsdd", TOKEN_INSN, C_none, 0, I_VPMACSDD },
        { "vpmacsdqh", TOKEN_INSN, C_none, 0, I_VPMACSDQH },
        { "vpmacsdql", TOKEN_INSN, C_none, 0, I_VPMACSDQL },
        { "vpmacssdd", TOKEN_INSN, C_none, 0, I_VPMACSSDD },
        { "vpmacssdqh", TOKEN_INSN, C_none, 0, I_VPMACSSDQH },
        { "vpmacssdql", TOKEN_INSN, C_none, 0, I_VPMACSSDQL },
        { "vpmacsswd", TOKEN_INSN, C_none, 0, I_VPMACSSWD },
        { "vpmacssww", TOKEN_INSN, C_none, 0, I_VPMACSSWW },
        { "vpmacswd", TOKEN_INSN, C_none, 0, I_VPMACSWD },
        { "vpmacsww", TOKEN_INSN, C_none, 0, I_VPMACSWW },
        { "vpmadcsswd", TOKEN_INSN, C_none, 0, I_VPMADCSSWD },
        { "vpmadcswd", TOKEN_INSN, C_none, 0, I_VPMADCSWD },
        { "vpperm", TOKEN_INSN, C_none, 0, I_VPPERM },
        { "vprotb", TOKEN_INSN, C_none, 0, I_VPROTB },
        { "vprotd", TOKEN_INSN, C_none, 0, I_VPROTD },
        { "vprotq", TOKEN_INSN, C_none, 0, I_VPROTQ },
        { "vprotw", TOKEN_INSN, C_none, 0, I_VPROTW },
        { "vpshab", TOKEN_INSN, C_none, 0, I_VPSHAB },
        { "vpshad", TOKEN_INSN, C_none, 0, I_VPSHAD },
        { "vpshaq", TOKEN_INSN, C_none, 0, I_VPSHAQ },
        { "vpshaw", TOKEN_INSN, C_none, 0, I_VPSHAW },
        { "vpshlb", TOKEN_INSN, C_none, 0, I_VPSHLB },
        { "vpshld", TOKEN_INSN, C_none, 0, I_VPSHLD },
        { "vpshlq", TOKEN_INSN, C_none, 0, I_VPSHLQ },
        { "vpshlw", TOKEN_INSN, C_none, 0, I_VPSHLW },
        { "vbroadcasti128", TOKEN_INSN, C_none, 0, I_VBROADCASTI128 },
        { "vpblendd", TOKEN_INSN, C_none, 0, I_VPBLENDD },
        { "vpbroadcastb", TOKEN_INSN, C_none, 0, I_VPBROADCASTB },
        { "vpbroadcastw", TOKEN_INSN, C_none, 0, I_VPBROADCASTW },
        { "vpbroadcastd", TOKEN_INSN, C_none, 0, I_VPBROADCASTD },
        { "vpbroadcastq", TOKEN_INSN, C_none, 0, I_VPBROADCASTQ },
        { "vpermd", TOKEN_INSN, C_none, 0, I_VPERMD },
        { "vpermpd", TOKEN_INSN, C_none, 0, I_VPERMPD },
        { "vpermps", TOKEN_INSN, C_none, 0, I_VPERMPS },
        { "vpermq", TOKEN_INSN, C_none, 0, I_VPERMQ },
        { "vperm2i128", TOKEN_INSN, C_none, 0, I_VPERM2I128 },
        { "vextracti128", TOKEN_INSN, C_none, 0, I_VEXTRACTI128 },
        { "vinserti128", TOKEN_INSN, C_none, 0, I_VINSERTI128 },
        { "vpmaskmovd", TOKEN_INSN, C_none, 0, I_VPMASKMOVD },
        { "vpmaskmovq", TOKEN_INSN, C_none, 0, I_VPMASKMOVQ },
        { "vpsllvd", TOKEN_INSN, C_none, 0, I_VPSLLVD },
        { "vpsllvq", TOKEN_INSN, C_none, 0, I_VPSLLVQ },
        { "vpsravd", TOKEN_INSN, C_none, 0, I_VPSRAVD },
        { "vpsrlvd", TOKEN_INSN, C_none, 0, I_VPSRLVD },
        { "vpsrlvq", TOKEN_INSN, C_none, 0, I_VPSRLVQ },
        { "vgatherdpd", TOKEN_INSN, C_none, 0, I_VGATHERDPD },
        { "vgatherqpd", TOKEN_INSN, C_none, 0, I_VGATHERQPD },
        { "vgatherdps", TOKEN_INSN, C_none, 0, I_VGATHERDPS },
        { "vgatherqps", TOKEN_INSN, C_none, 0, I_VGATHERQPS },
        { "vpgatherdd", TOKEN_INSN, C_none, 0, I_VPGATHERDD },
        { "vpgatherqd", TOKEN_INSN, C_none, 0, I_VPGATHERQD },
        { "vpgatherdq", TOKEN_INSN, C_none, 0, I_VPGATHERDQ },
        { "vpgatherqq", TOKEN_INSN, C_none, 0, I_VPGATHERQQ },
        { "xabort", TOKEN_INSN, C_none, 0, I_XABORT },
        { "xbegin", TOKEN_INSN, C_none, 0, I_XBEGIN },
        { "xend", TOKEN_INSN, C_none, 0, I_XEND },
        { "xtest", TOKEN_INSN, C_none, 0, I_XTEST },
        { "andn", TOKEN_INSN, C_none, 0, I_ANDN },
        { "bextr", TOKEN_INSN, C_none, 0, I_BEXTR },
        { "blci", TOKEN_INSN, C_none, 0, I_BLCI },
        { "blcic", TOKEN_INSN, C_none, 0, I_BLCIC },
        { "blsi", TOKEN_INSN, C_none, 0, I_BLSI },
        { "blsic", TOKEN_INSN, C_none, 0, I_BLSIC },
        { "blcfill", TOKEN_INSN, C_none, 0, I_BLCFILL },
        { "blsfill", TOKEN_INSN, C_none, 0, I_BLSFILL },
        { "blcmsk", TOKEN_INSN, C_none, 0, I_BLCMSK },
        { "blsmsk", TOKEN_INSN, C_none, 0, I_BLSMSK },
        { "blsr", TOKEN_INSN, C_none, 0, I_BLSR },
        { "blcs", TOKEN_INSN, C_none, 0, I_BLCS },
        { "bzhi", TOKEN_INSN, C_none, 0, I_BZHI },
        { "mulx", TOKEN_INSN, C_none, 0, I_MULX },
        { "pdep", TOKEN_INSN, C_none, 0, I_PDEP },
        { "pext", TOKEN_INSN, C_none, 0, I_PEXT },
        { "rorx", TOKEN_INSN, C_none, 0, I_RORX },
        { "sarx", TOKEN_INSN, C_none, 0, I_SARX },
        { "shlx", TOKEN_INSN, C_none, 0, I_SHLX },
        { "shrx", TOKEN_INSN, C_none, 0, I_SHRX },
        { "tzcnt", TOKEN_INSN, C_none, 0, I_TZCNT },
        { "tzmsk", TOKEN_INSN, C_none, 0, I_TZMSK },
        { "t1mskc", TOKEN_INSN, C_none, 0, I_T1MSKC },
        { "prefetchwt1", TOKEN_INSN, C_none, 0, I_PREFETCHWT1 },
        { "bndmk", TOKEN_INSN, C_none, 0, I_BNDMK },
        { "bndcl", TOKEN_INSN, C_none, 0, I_BNDCL },
        { "bndcu", TOKEN_INSN, C_none, 0, I_BNDCU },
        { "bndcn", TOKEN_INSN, C_none, 0, I_BNDCN },
        { "bndmov", TOKEN_INSN, C_none, 0, I_BNDMOV },
        { "bndldx", TOKEN_INSN, C_none, 0, I_BNDLDX },
        { "bndstx", TOKEN_INSN, C_none, 0, I_BNDSTX },
        { "kaddb", TOKEN_INSN, C_none, 0, I_KADDB },
        { "kaddd", TOKEN_INSN, C_none, 0, I_KADDD },
        { "kaddq", TOKEN_INSN, C_none, 0, I_KADDQ },
        { "kaddw", TOKEN_INSN, C_none, 0, I_KADDW },
        { "kandb", TOKEN_INSN, C_none, 0, I_KANDB },
        { "kandd", TOKEN_INSN, C_none, 0, I_KANDD },
        { "kandnb", TOKEN_INSN, C_none, 0, I_KANDNB },
        { "kandnd", TOKEN_INSN, C_none, 0, I_KANDND },
        { "kandnq", TOKEN_INSN, C_none, 0, I_KANDNQ },
        { "kandnw", TOKEN_INSN, C_none, 0, I_KANDNW },
        { "kandq", TOKEN_INSN, C_none, 0, I_KANDQ },
        { "kandw", TOKEN_INSN, C_none, 0, I_KANDW },
        { "kmovb", TOKEN_INSN, C_none, 0, I_KMOVB },
        { "kmovd", TOKEN_INSN, C_none, 0, I_KMOVD },
        { "kmovq", TOKEN_INSN, C_none, 0, I_KMOVQ },
        { "kmovw", TOKEN_INSN, C_none, 0, I_KMOVW },
        { "knotb", TOKEN_INSN, C_none, 0, I_KNOTB },
        { "knotd", TOKEN_INSN, C_none, 0, I_KNOTD },
        { "knotq", TOKEN_INSN, C_none, 0, I_KNOTQ },
        { "knotw", TOKEN_INSN, C_none, 0, I_KNOTW },
        { "korb", TOKEN_INSN, C_none, 0, I_KORB },
        { "kord", TOKEN_INSN, C_none, 0, I_KORD },
        { "korq", TOKEN_INSN, C_none, 0, I_KORQ },
        { "kortestb", TOKEN_INSN, C_none, 0, I_KORTESTB },
        { "kortestd", TOKEN_INSN, C_none, 0, I_KORTESTD },
        { "kortestq", TOKEN_INSN, C_none, 0, I_KORTESTQ },
        { "kortestw", TOKEN_INSN, C_none, 0, I_KORTESTW },
        { "korw", TOKEN_INSN, C_none, 0, I_KORW },
        { "kshiftlb", TOKEN_INSN, C_none, 0, I_KSHIFTLB },
        { "kshiftld", TOKEN_INSN, C_none, 0, I_KSHIFTLD },
        { "kshiftlq", TOKEN_INSN, C_none, 0, I_KSHIFTLQ },
        { "kshiftlw", TOKEN_INSN, C_none, 0, I_KSHIFTLW },
        { "kshiftrb", TOKEN_INSN, C_none, 0, I_KSHIFTRB },
        { "kshiftrd", TOKEN_INSN, C_none, 0, I_KSHIFTRD },
        { "kshiftrq", TOKEN_INSN, C_none, 0, I_KSHIFTRQ },
        { "kshiftrw", TOKEN_INSN, C_none, 0, I_KSHIFTRW },
        { "ktestb", TOKEN_INSN, C_none, 0, I_KTESTB },
        { "ktestd", TOKEN_INSN, C_none, 0, I_KTESTD },
        { "ktestq", TOKEN_INSN, C_none, 0, I_KTESTQ },
        { "ktestw", TOKEN_INSN, C_none, 0, I_KTESTW },
        { "kunpckbw", TOKEN_INSN, C_none, 0, I_KUNPCKBW },
        { "kunpckdq", TOKEN_INSN, C_none, 0, I_KUNPCKDQ },
        { "kunpckwd", TOKEN_INSN, C_none, 0, I_KUNPCKWD },
        { "kxnorb", TOKEN_INSN, C_none, 0, I_KXNORB },
        { "kxnord", TOKEN_INSN, C_none, 0, I_KXNORD },
        { "kxnorq", TOKEN_INSN, C_none, 0, I_KXNORQ },
        { "kxnorw", TOKEN_INSN, C_none, 0, I_KXNORW },
        { "kxorb", TOKEN_INSN, C_none, 0, I_KXORB },
        { "kxord", TOKEN_INSN, C_none, 0, I_KXORD },
        { "kxorq", TOKEN_INSN, C_none, 0, I_KXORQ },
        { "kxorw", TOKEN_INSN, C_none, 0, I_KXORW },
        { "sha1msg1", TOKEN_INSN, C_none, 0, I_SHA1MSG1 },
        { "sha1msg2", TOKEN_INSN, C_none, 0, I_SHA1MSG2 },
        { "sha1nexte", TOKEN_INSN, C_none, 0, I_SHA1NEXTE },
        { "sha1rnds4", TOKEN_INSN, C_none, 0, I_SHA1RNDS4 },
        { "sha256msg1", TOKEN_INSN, C_none, 0, I_SHA256MSG1 },
        { "sha256msg2", TOKEN_INSN, C_none, 0, I_SHA256MSG2 },
        { "sha256rnds2", TOKEN_INSN, C_none, 0, I_SHA256RNDS2 },
        { "valignd", TOKEN_INSN, C_none, 0, I_VALIGND },
        { "valignq", TOKEN_INSN, C_none, 0, I_VALIGNQ },
        { "vblendmpd", TOKEN_INSN, C_none, 0, I_VBLENDMPD },
        { "vblendmps", TOKEN_INSN, C_none, 0, I_VBLENDMPS },
        { "vbroadcastf32x2", TOKEN_INSN, C_none, 0, I_VBROADCASTF32X2 },
        { "vbroadcastf32x4", TOKEN_INSN, C_none, 0, I_VBROADCASTF32X4 },
        { "vbroadcastf32x8", TOKEN_INSN, C_none, 0, I_VBROADCASTF32X8 },
        { "vbroadcastf64x2", TOKEN_INSN, C_none, 0, I_VBROADCASTF64X2 },
        { "vbroadcastf64x4", TOKEN_INSN, C_none, 0, I_VBROADCASTF64X4 },
        { "vbroadcasti32x2", TOKEN_INSN, C_none, 0, I_VBROADCASTI32X2 },
        { "vbroadcasti32x4", TOKEN_INSN, C_none, 0, I_VBROADCASTI32X4 },
        { "vbroadcasti32x8", TOKEN_INSN, C_none, 0, I_VBROADCASTI32X8 },
        { "vbroadcasti64x2", TOKEN_INSN, C_none, 0, I_VBROADCASTI64X2 },
        { "vbroadcasti64x4", TOKEN_INSN, C_none, 0, I_VBROADCASTI64X4 },
        { "vcompresspd", TOKEN_INSN, C_none, 0, I_VCOMPRESSPD },
        { "vcompressps", TOKEN_INSN, C_none, 0, I_VCOMPRESSPS },
        { "vcvtpd2qq", TOKEN_INSN, C_none, 0, I_VCVTPD2QQ },
        { "vcvtpd2udq", TOKEN_INSN, C_none, 0, I_VCVTPD2UDQ },
        { "vcvtpd2uqq", TOKEN_INSN, C_none, 0, I_VCVTPD2UQQ },
        { "vcvtps2qq", TOKEN_INSN, C_none, 0, I_VCVTPS2QQ },
        { "vcvtps2udq", TOKEN_INSN, C_none, 0, I_VCVTPS2UDQ },
        { "vcvtps2uqq", TOKEN_INSN, C_none, 0, I_VCVTPS2UQQ },
        { "vcvtqq2pd", TOKEN_INSN, C_none, 0, I_VCVTQQ2PD },
        { "vcvtqq2ps", TOKEN_INSN, C_none, 0, I_VCVTQQ2PS },
        { "vcvtsd2usi", TOKEN_INSN, C_none, 0, I_VCVTSD2USI },
        { "vcvtss2usi", TOKEN_INSN, C_none, 0, I_VCVTSS2USI },
        { "vcvttpd2qq", TOKEN_INSN, C_none, 0, I_VCVTTPD2QQ },
        { "vcvttpd2udq", TOKEN_INSN, C_none, 0, I_VCVTTPD2UDQ },
        { "vcvttpd2uqq", TOKEN_INSN, C_none, 0, I_VCVTTPD2UQQ },
        { "vcvttps2qq", TOKEN_INSN, C_none, 0, I_VCVTTPS2QQ },
        { "vcvttps2udq", TOKEN_INSN, C_none, 0, I_VCVTTPS2UDQ },
        { "vcvttps2uqq", TOKEN_INSN, C_none, 0, I_VCVTTPS2UQQ },
        { "vcvttsd2usi", TOKEN_INSN, C_none, 0, I_VCVTTSD2USI },
        { "vcvttss2usi", TOKEN_INSN, C_none, 0, I_VCVTTSS2USI },
        { "vcvtudq2pd", TOKEN_INSN, C_none, 0, I_VCVTUDQ2PD },
        { "vcvtudq2ps", TOKEN_INSN, C_none, 0, I_VCVTUDQ2PS },
        { "vcvtuqq2pd", TOKEN_INSN, C_none, 0, I_VCVTUQQ2PD },
        { "vcvtuqq2ps", TOKEN_INSN, C_none, 0, I_VCVTUQQ2PS },
        { "vcvtusi2sd", TOKEN_INSN, C_none, 0, I_VCVTUSI2SD },
        { "vcvtusi2ss", TOKEN_INSN, C_none, 0, I_VCVTUSI2SS },
        { "vdbpsadbw", TOKEN_INSN, C_none, 0, I_VDBPSADBW },
        { "vexp2pd", TOKEN_INSN, C_none, 0, I_VEXP2PD },
        { "vexp2ps", TOKEN_INSN, C_none, 0, I_VEXP2PS },
        { "vexpandpd", TOKEN_INSN, C_none, 0, I_VEXPANDPD },
        { "vexpandps", TOKEN_INSN, C_none, 0, I_VEXPANDPS },
        { "vextractf32x4", TOKEN_INSN, C_none, 0, I_VEXTRACTF32X4 },
        { "vextractf32x8", TOKEN_INSN, C_none, 0, I_VEXTRACTF32X8 },
        { "vextractf64x2", TOKEN_INSN, C_none, 0, I_VEXTRACTF64X2 },
        { "vextractf64x4", TOKEN_INSN, C_none, 0, I_VEXTRACTF64X4 },
        { "vextracti32x4", TOKEN_INSN, C_none, 0, I_VEXTRACTI32X4 },
        { "vextracti32x8", TOKEN_INSN, C_none, 0, I_VEXTRACTI32X8 },
        { "vextracti64x2", TOKEN_INSN, C_none, 0, I_VEXTRACTI64X2 },
        { "vextracti64x4", TOKEN_INSN, C_none, 0, I_VEXTRACTI64X4 },
        { "vfixupimmpd", TOKEN_INSN, C_none, 0, I_VFIXUPIMMPD },
        { "vfixupimmps", TOKEN_INSN, C_none, 0, I_VFIXUPIMMPS },
        { "vfixupimmsd", TOKEN_INSN, C_none, 0, I_VFIXUPIMMSD },
        { "vfixupimmss", TOKEN_INSN, C_none, 0, I_VFIXUPIMMSS },
        { "vfpclasspd", TOKEN_INSN, C_none, 0, I_VFPCLASSPD },
        { "vfpclassps", TOKEN_INSN, C_none, 0, I_VFPCLASSPS },
        { "vfpclasssd", TOKEN_INSN, C_none, 0, I_VFPCLASSSD },
        { "vfpclassss", TOKEN_INSN, C_none, 0, I_VFPCLASSSS },
        { "vgatherpf0dpd", TOKEN_INSN, C_none, 0, I_VGATHERPF0DPD },
        { "vgatherpf0dps", TOKEN_INSN, C_none, 0, I_VGATHERPF0DPS },
        { "vgatherpf0qpd", TOKEN_INSN, C_none, 0, I_VGATHERPF0QPD },
        { "vgatherpf0qps", TOKEN_INSN, C_none, 0, I_VGATHERPF0QPS },
        { "vgatherpf1dpd", TOKEN_INSN, C_none, 0, I_VGATHERPF1DPD },
        { "vgatherpf1dps", TOKEN_INSN, C_none, 0, I_VGATHERPF1DPS },
        { "vgatherpf1qpd", TOKEN_INSN, C_none, 0, I_VGATHERPF1QPD },
        { "vgatherpf1qps", TOKEN_INSN, C_none, 0, I_VGATHERPF1QPS },
        { "vgetexppd", TOKEN_INSN, C_none, 0, I_VGETEXPPD },
        { "vgetexpps", TOKEN_INSN, C_none, 0, I_VGETEXPPS },
        { "vgetexpsd", TOKEN_INSN, C_none, 0, I_VGETEXPSD },
        { "vgetexpss", TOKEN_INSN, C_none, 0, I_VGETEXPSS },
        { "vgetmantpd", TOKEN_INSN, C_none, 0, I_VGETMANTPD },
        { "vgetmantps", TOKEN_INSN, C_none, 0, I_VGETMANTPS },
        { "vgetmantsd", TOKEN_INSN, C_none, 0, I_VGETMANTSD },
        { "vgetmantss", TOKEN_INSN, C_none, 0, I_VGETMANTSS },
        { "vinsertf32x4", TOKEN_INSN, C_none, 0, I_VINSERTF32X4 },
        { "vinsertf32x8", TOKEN_INSN, C_none, 0, I_VINSERTF32X8 },
        { "vinsertf64x2", TOKEN_INSN, C_none, 0, I_VINSERTF64X2 },
        { "vinsertf64x4", TOKEN_INSN, C_none, 0, I_VINSERTF64X4 },
        { "vinserti32x4", TOKEN_INSN, C_none, 0, I_VINSERTI32X4 },
        { "vinserti32x8", TOKEN_INSN, C_none, 0, I_VINSERTI32X8 },
        { "vinserti64x2", TOKEN_INSN, C_none, 0, I_VINSERTI64X2 },
        { "vinserti64x4", TOKEN_INSN, C_none, 0, I_VINSERTI64X4 },
        { "vmovdqa32", TOKEN_INSN, C_none, 0, I_VMOVDQA32 },
        { "vmovdqa64", TOKEN_INSN, C_none, 0, I_VMOVDQA64 },
        { "vmovdqu16", TOKEN_INSN, C_none, 0, I_VMOVDQU16 },
        { "vmovdqu32", TOKEN_INSN, C_none, 0, I_VMOVDQU32 },
        { "vmovdqu64", TOKEN_INSN, C_none, 0, I_VMOVDQU64 },
        { "vmovdqu8", TOKEN_INSN, C_none, 0, I_VMOVDQU8 },
        { "vpabsq", TOKEN_INSN, C_none, 0, I_VPABSQ },
        { "vpandd", TOKEN_INSN, C_none, 0, I_VPANDD },
        { "vpandnd", TOKEN_INSN, C_none, 0, I_VPANDND },
        { "vpandnq", TOKEN_INSN, C_none, 0, I_VPANDNQ },
        { "vpandq", TOKEN_INSN, C_none, 0, I_VPANDQ },
        { "vpblendmb", TOKEN_INSN, C_none, 0, I_VPBLENDMB },
        { "vpblendmd", TOKEN_INSN, C_none, 0, I_VPBLENDMD },
        { "vpblendmq", TOKEN_INSN, C_none, 0, I_VPBLENDMQ },
        { "vpblendmw", TOKEN_INSN, C_none, 0, I_VPBLENDMW },
        { "vpbroadcastmb2q", TOKEN_INSN, C_none, 0, I_VPBROADCASTMB2Q },
        { "vpbroadcastmw2d", TOKEN_INSN, C_none, 0, I_VPBROADCASTMW2D },
        { "vpcmpb", TOKEN_INSN, C_none, 0, I_VPCMPB },
        { "vpcmpd", TOKEN_INSN, C_none, 0, I_VPCMPD },
        { "vpcmpq", TOKEN_INSN, C_none, 0, I_VPCMPQ },
        { "vpcmpub", TOKEN_INSN, C_none, 0, I_VPCMPUB },
        { "vpcmpud", TOKEN_INSN, C_none, 0, I_VPCMPUD },
        { "vpcmpuq", TOKEN_INSN, C_none, 0, I_VPCMPUQ },
        { "vpcmpuw", TOKEN_INSN, C_none, 0, I_VPCMPUW },
        { "vpcmpw", TOKEN_INSN, C_none, 0, I_VPCMPW },
        { "vpcompressd", TOKEN_INSN, C_none, 0, I_VPCOMPRESSD },
        { "vpcompressq", TOKEN_INSN, C_none, 0, I_VPCOMPRESSQ },
        { "vpconflictd", TOKEN_INSN, C_none, 0, I_VPCONFLICTD },
        { "vpconflictq", TOKEN_INSN, C_none, 0, I_VPCONFLICTQ },
        { "vpermb", TOKEN_INSN, C_none, 0, I_VPERMB },
        { "vpermi2b", TOKEN_INSN, C_none, 0, I_VPERMI2B },
        { "vpermi2d", TOKEN_INSN, C_none, 0, I_VPERMI2D },
        { "vpermi2pd", TOKEN_INSN, C_none, 0, I_VPERMI2PD },
        { "vpermi2ps", TOKEN_INSN, C_none, 0, I_VPERMI2PS },
        { "vpermi2q", TOKEN_INSN, C_none, 0, I_VPERMI2Q },
        { "vpermi2w", TOKEN_INSN, C_none, 0, I_VPERMI2W },
        { "vpermt2b", TOKEN_INSN, C_none, 0, I_VPERMT2B },
        { "vpermt2d", TOKEN_INSN, C_none, 0, I_VPERMT2D },
        { "vpermt2pd", TOKEN_INSN, C_none, 0, I_VPERMT2PD },
        { "vpermt2ps", TOKEN_INSN, C_none, 0, I_VPERMT2PS },
        { "vpermt2q", TOKEN_INSN, C_none, 0, I_VPERMT2Q },
        { "vpermt2w", TOKEN_INSN, C_none, 0, I_VPERMT2W },
        { "vpermw", TOKEN_INSN, C_none, 0, I_VPERMW },
        { "vpexpandd", TOKEN_INSN, C_none, 0, I_VPEXPANDD },
        { "vpexpandq", TOKEN_INSN, C_none, 0, I_VPEXPANDQ },
        { "vplzcntd", TOKEN_INSN, C_none, 0, I_VPLZCNTD },
        { "vplzcntq", TOKEN_INSN, C_none, 0, I_VPLZCNTQ },
        { "vpmadd52huq", TOKEN_INSN, C_none, 0, I_VPMADD52HUQ },
        { "vpmadd52luq", TOKEN_INSN, C_none, 0, I_VPMADD52LUQ },
        { "vpmaxsq", TOKEN_INSN, C_none, 0, I_VPMAXSQ },
        { "vpmaxuq", TOKEN_INSN, C_none, 0, I_VPMAXUQ },
        { "vpminsq", TOKEN_INSN, C_none, 0, I_VPMINSQ },
        { "vpminuq", TOKEN_INSN, C_none, 0, I_VPMINUQ },
        { "vpmovb2m", TOKEN_INSN, C_none, 0, I_VPMOVB2M },
        { "vpmovd2m", TOKEN_INSN, C_none, 0, I_VPMOVD2M },
        { "vpmovdb", TOKEN_INSN, C_none, 0, I_VPMOVDB },
        { "vpmovdw", TOKEN_INSN, C_none, 0, I_VPMOVDW },
        { "vpmovm2b", TOKEN_INSN, C_none, 0, I_VPMOVM2B },
        { "vpmovm2d", TOKEN_INSN, C_none, 0, I_VPMOVM2D },
        { "vpmovm2q", TOKEN_INSN, C_none, 0, I_VPMOVM2Q },
        { "vpmovm2w", TOKEN_INSN, C_none, 0, I_VPMOVM2W },
        { "vpmovq2m", TOKEN_INSN, C_none, 0, I_VPMOVQ2M },
        { "vpmovqb", TOKEN_INSN, C_none, 0, I_VPMOVQB },
        { "vpmovqd", TOKEN_INSN, C_none, 0, I_VPMOVQD },
        { "vpmovqw", TOKEN_INSN, C_none, 0, I_VPMOVQW },
        { "vpmovsdb", TOKEN_INSN, C_none, 0, I_VPMOVSDB },
        { "vpmovsdw", TOKEN_INSN, C_none, 0, I_VPMOVSDW },
        { "vpmovsqb", TOKEN_INSN, C_none, 0, I_VPMOVSQB },
        { "vpmovsqd", TOKEN_INSN, C_none, 0, I_VPMOVSQD },
        { "vpmovsqw", TOKEN_INSN, C_none, 0, I_VPMOVSQW },
        { "vpmovswb", TOKEN_INSN, C_none, 0, I_VPMOVSWB },
        { "vpmovusdb", TOKEN_INSN, C_none, 0, I_VPMOVUSDB },
        { "vpmovusdw", TOKEN_INSN, C_none, 0, I_VPMOVUSDW },
        { "vpmovusqb", TOKEN_INSN, C_none, 0, I_VPMOVUSQB },
        { "vpmovusqd", TOKEN_INSN, C_none, 0, I_VPMOVUSQD },
        { "vpmovusqw", TOKEN_INSN, C_none, 0, I_VPMOVUSQW },
        { "vpmovuswb", TOKEN_INSN, C_none, 0, I_VPMOVUSWB },
        { "vpmovw2m", TOKEN_INSN, C_none, 0, I_VPMOVW2M },
        { "vpmovwb", TOKEN_INSN, C_none, 0, I_VPMOVWB },
        { "vpmullq", TOKEN_INSN, C_none, 0, I_VPMULLQ },
        { "vpmultishiftqb", TOKEN_INSN, C_none, 0, I_VPMULTISHIFTQB },
        { "vpord", TOKEN_INSN, C_none, 0, I_VPORD },
        { "vporq", TOKEN_INSN, C_none, 0, I_VPORQ },
        { "vprold", TOKEN_INSN, C_none, 0, I_VPROLD },
        { "vprolq", TOKEN_INSN, C_none, 0, I_VPROLQ },
        { "vprolvd", TOKEN_INSN, C_none, 0, I_VPROLVD },
        { "vprolvq", TOKEN_INSN, C_none, 0, I_VPROLVQ },
        { "vprord", TOKEN_INSN, C_none, 0, I_VPRORD },
        { "vprorq", TOKEN_INSN, C_none, 0, I_VPRORQ },
        { "vprorvd", TOKEN_INSN, C_none, 0, I_VPRORVD },
        { "vprorvq", TOKEN_INSN, C_none, 0, I_VPRORVQ },
        { "vpscatterdd", TOKEN_INSN, C_none, 0, I_VPSCATTERDD },
        { "vpscatterdq", TOKEN_INSN, C_none, 0, I_VPSCATTERDQ },
        { "vpscatterqd", TOKEN_INSN, C_none, 0, I_VPSCATTERQD },
        { "vpscatterqq", TOKEN_INSN, C_none, 0, I_VPSCATTERQQ },
        { "vpsllvw", TOKEN_INSN, C_none, 0, I_VPSLLVW },
        { "vpsraq", TOKEN_INSN, C_none, 0, I_VPSRAQ },
        { "vpsravq", TOKEN_INSN, C_none, 0, I_VPSRAVQ },
        { "vpsravw", TOKEN_INSN, C_none, 0, I_VPSRAVW },
        { "vpsrlvw", TOKEN_INSN, C_none, 0, I_VPSRLVW },
        { "vpternlogd", TOKEN_INSN, C_none, 0, I_VPTERNLOGD },
        { "vpternlogq", TOKEN_INSN, C_none, 0, I_VPTERNLOGQ },
        { "vptestmb", TOKEN_INSN, C_none, 0, I_VPTESTMB },
        { "vptestmd", TOKEN_INSN, C_none, 0, I_VPTESTMD },
        { "vptestmq", TOKEN_INSN, C_none, 0, I_VPTESTMQ },
        { "vptestmw", TOKEN_INSN, C_none, 0, I_VPTESTMW },
        { "vptestnmb", TOKEN_INSN, C_none, 0, I_VPTESTNMB },
        { "vptestnmd", TOKEN_INSN, C_none, 0, I_VPTESTNMD },
        { "vptestnmq", TOKEN_INSN, C_none, 0, I_VPTESTNMQ },
        { "vptestnmw", TOKEN_INSN, C_none, 0, I_VPTESTNMW },
        { "vpxord", TOKEN_INSN, C_none, 0, I_VPXORD },
        { "vpxorq", TOKEN_INSN, C_none, 0, I_VPXORQ },
        { "vrangepd", TOKEN_INSN, C_none, 0, I_VRANGEPD },
        { "vrangeps", TOKEN_INSN, C_none, 0, I_VRANGEPS },
        { "vrangesd", TOKEN_INSN, C_none, 0, I_VRANGESD },
        { "vrangess", TOKEN_INSN, C_none, 0, I_VRANGESS },
        { "vrcp14pd", TOKEN_INSN, C_none, 0, I_VRCP14PD },
        { "vrcp14ps", TOKEN_INSN, C_none, 0, I_VRCP14PS },
        { "vrcp14sd", TOKEN_INSN, C_none, 0, I_VRCP14SD },
        { "vrcp14ss", TOKEN_INSN, C_none, 0, I_VRCP14SS },
        { "vrcp28pd", TOKEN_INSN, C_none, 0, I_VRCP28PD },
        { "vrcp28ps", TOKEN_INSN, C_none, 0, I_VRCP28PS },
        { "vrcp28sd", TOKEN_INSN, C_none, 0, I_VRCP28SD },
        { "vrcp28ss", TOKEN_INSN, C_none, 0, I_VRCP28SS },
        { "vreducepd", TOKEN_INSN, C_none, 0, I_VREDUCEPD },
        { "vreduceps", TOKEN_INSN, C_none, 0, I_VREDUCEPS },
        { "vreducesd", TOKEN_INSN, C_none, 0, I_VREDUCESD },
        { "vreducess", TOKEN_INSN, C_none, 0, I_VREDUCESS },
        { "vrndscalepd", TOKEN_INSN, C_none, 0, I_VRNDSCALEPD },
        { "vrndscaleps", TOKEN_INSN, C_none, 0, I_VRNDSCALEPS },
        { "vrndscalesd", TOKEN_INSN, C_none, 0, I_VRNDSCALESD },
        { "vrndscaless", TOKEN_INSN, C_none, 0, I_VRNDSCALESS },
        { "vrsqrt14pd", TOKEN_INSN, C_none, 0, I_VRSQRT14PD },
        { "vrsqrt14ps", TOKEN_INSN, C_none, 0, I_VRSQRT14PS },
        { "vrsqrt14sd", TOKEN_INSN, C_none, 0, I_VRSQRT14SD },
        { "vrsqrt14ss", TOKEN_INSN, C_none, 0, I_VRSQRT14SS },
        { "vrsqrt28pd", TOKEN_INSN, C_none, 0, I_VRSQRT28PD },
        { "vrsqrt28ps", TOKEN_INSN, C_none, 0, I_VRSQRT28PS },
        { "vrsqrt28sd", TOKEN_INSN, C_none, 0, I_VRSQRT28SD },
        { "vrsqrt28ss", TOKEN_INSN, C_none, 0, I_VRSQRT28SS },
        { "vscalefpd", TOKEN_INSN, C_none, 0, I_VSCALEFPD },
        { "vscalefps", TOKEN_INSN, C_none, 0, I_VSCALEFPS },
        { "vscalefsd", TOKEN_INSN, C_none, 0, I_VSCALEFSD },
        { "vscalefss", TOKEN_INSN, C_none, 0, I_VSCALEFSS },
        { "vscatterdpd", TOKEN_INSN, C_none, 0, I_VSCATTERDPD },
        { "vscatterdps", TOKEN_INSN, C_none, 0, I_VSCATTERDPS },
        { "vscatterpf0dpd", TOKEN_INSN, C_none, 0, I_VSCATTERPF0DPD },
        { "vscatterpf0dps", TOKEN_INSN, C_none, 0, I_VSCATTERPF0DPS },
        { "vscatterpf0qpd", TOKEN_INSN, C_none, 0, I_VSCATTERPF0QPD },
        { "vscatterpf0qps", TOKEN_INSN, C_none, 0, I_VSCATTERPF0QPS },
        { "vscatterpf1dpd", TOKEN_INSN, C_none, 0, I_VSCATTERPF1DPD },
        { "vscatterpf1dps", TOKEN_INSN, C_none, 0, I_VSCATTERPF1DPS },
        { "vscatterpf1qpd", TOKEN_INSN, C_none, 0, I_VSCATTERPF1QPD },
        { "vscatterpf1qps", TOKEN_INSN, C_none, 0, I_VSCATTERPF1QPS },
        { "vscatterqpd", TOKEN_INSN, C_none, 0, I_VSCATTERQPD },
        { "vscatterqps", TOKEN_INSN, C_none, 0, I_VSCATTERQPS },
        { "vshuff32x4", TOKEN_INSN, C_none, 0, I_VSHUFF32X4 },
        { "vshuff64x2", TOKEN_INSN, C_none, 0, I_VSHUFF64X2 },
        { "vshufi32x4", TOKEN_INSN, C_none, 0, I_VSHUFI32X4 },
        { "vshufi64x2", TOKEN_INSN, C_none, 0, I_VSHUFI64X2 },
        { "clflushopt", TOKEN_INSN, C_none, 0, I_CLFLUSHOPT },
        { "hint_nop0", TOKEN_INSN, C_none, 0, I_HINT_NOP0 },
        { "hint_nop1", TOKEN_INSN, C_none, 0, I_HINT_NOP1 },
        { "hint_nop2", TOKEN_INSN, C_none, 0, I_HINT_NOP2 },
        { "hint_nop3", TOKEN_INSN, C_none, 0, I_HINT_NOP3 },
        { "hint_nop4", TOKEN_INSN, C_none, 0, I_HINT_NOP4 },
        { "hint_nop5", TOKEN_INSN, C_none, 0, I_HINT_NOP5 },
        { "hint_nop6", TOKEN_INSN, C_none, 0, I_HINT_NOP6 },
        { "hint_nop7", TOKEN_INSN, C_none, 0, I_HINT_NOP7 },
        { "hint_nop8", TOKEN_INSN, C_none, 0, I_HINT_NOP8 },
        { "hint_nop9", TOKEN_INSN, C_none, 0, I_HINT_NOP9 },
        { "hint_nop10", TOKEN_INSN, C_none, 0, I_HINT_NOP10 },
        { "hint_nop11", TOKEN_INSN, C_none, 0, I_HINT_NOP11 },
        { "hint_nop12", TOKEN_INSN, C_none, 0, I_HINT_NOP12 },
        { "hint_nop13", TOKEN_INSN, C_none, 0, I_HINT_NOP13 },
        { "hint_nop14", TOKEN_INSN, C_none, 0, I_HINT_NOP14 },
        { "hint_nop15", TOKEN_INSN, C_none, 0, I_HINT_NOP15 },
        { "hint_nop16", TOKEN_INSN, C_none, 0, I_HINT_NOP16 },
        { "hint_nop17", TOKEN_INSN, C_none, 0, I_HINT_NOP17 },
        { "hint_nop18", TOKEN_INSN, C_none, 0, I_HINT_NOP18 },
        { "hint_nop19", TOKEN_INSN, C_none, 0, I_HINT_NOP19 },
        { "hint_nop20", TOKEN_INSN, C_none, 0, I_HINT_NOP20 },
        { "hint_nop21", TOKEN_INSN, C_none, 0, I_HINT_NOP21 },
        { "hint_nop22", TOKEN_INSN, C_none, 0, I_HINT_NOP22 },
        { "hint_nop23", TOKEN_INSN, C_none, 0, I_HINT_NOP23 },
        { "hint_nop24", TOKEN_INSN, C_none, 0, I_HINT_NOP24 },
        { "hint_nop25", TOKEN_INSN, C_none, 0, I_HINT_NOP25 },
        { "hint_nop26", TOKEN_INSN, C_none, 0, I_HINT_NOP26 },
        { "hint_nop27", TOKEN_INSN, C_none, 0, I_HINT_NOP27 },
        { "hint_nop28", TOKEN_INSN, C_none, 0, I_HINT_NOP28 },
        { "hint_nop29", TOKEN_INSN, C_none, 0, I_HINT_NOP29 },
        { "hint_nop30", TOKEN_INSN, C_none, 0, I_HINT_NOP30 },
        { "hint_nop31", TOKEN_INSN, C_none, 0, I_HINT_NOP31 },
        { "hint_nop32", TOKEN_INSN, C_none, 0, I_HINT_NOP32 },
        { "hint_nop33", TOKEN_INSN, C_none, 0, I_HINT_NOP33 },
        { "hint_nop34", TOKEN_INSN, C_none, 0, I_HINT_NOP34 },
        { "hint_nop35", TOKEN_INSN, C_none, 0, I_HINT_NOP35 },
        { "hint_nop36", TOKEN_INSN, C_none, 0, I_HINT_NOP36 },
        { "hint_nop37", TOKEN_INSN, C_none, 0, I_HINT_NOP37 },
        { "hint_nop38", TOKEN_INSN, C_none, 0, I_HINT_NOP38 },
        { "hint_nop39", TOKEN_INSN, C_none, 0, I_HINT_NOP39 },
        { "hint_nop40", TOKEN_INSN, C_none, 0, I_HINT_NOP40 },
        { "hint_nop41", TOKEN_INSN, C_none, 0, I_HINT_NOP41 },
        { "hint_nop42", TOKEN_INSN, C_none, 0, I_HINT_NOP42 },
        { "hint_nop43", TOKEN_INSN, C_none, 0, I_HINT_NOP43 },
        { "hint_nop44", TOKEN_INSN, C_none, 0, I_HINT_NOP44 },
        { "hint_nop45", TOKEN_INSN, C_none, 0, I_HINT_NOP45 },
        { "hint_nop46", TOKEN_INSN, C_none, 0, I_HINT_NOP46 },
        { "hint_nop47", TOKEN_INSN, C_none, 0, I_HINT_NOP47 },
        { "hint_nop48", TOKEN_INSN, C_none, 0, I_HINT_NOP48 },
        { "hint_nop49", TOKEN_INSN, C_none, 0, I_HINT_NOP49 },
        { "hint_nop50", TOKEN_INSN, C_none, 0, I_HINT_NOP50 },
        { "hint_nop51", TOKEN_INSN, C_none, 0, I_HINT_NOP51 },
        { "hint_nop52", TOKEN_INSN, C_none, 0, I_HINT_NOP52 },
        { "hint_nop53", TOKEN_INSN, C_none, 0, I_HINT_NOP53 },
        { "hint_nop54", TOKEN_INSN, C_none, 0, I_HINT_NOP54 },
        { "hint_nop55", TOKEN_INSN, C_none, 0, I_HINT_NOP55 },
        { "hint_nop56", TOKEN_INSN, C_none, 0, I_HINT_NOP56 },
        { "hint_nop57", TOKEN_INSN, C_none, 0, I_HINT_NOP57 },
        { "hint_nop58", TOKEN_INSN, C_none, 0, I_HINT_NOP58 },
        { "hint_nop59", TOKEN_INSN, C_none, 0, I_HINT_NOP59 },
        { "hint_nop60", TOKEN_INSN, C_none, 0, I_HINT_NOP60 },
        { "hint_nop61", TOKEN_INSN, C_none, 0, I_HINT_NOP61 },
        { "hint_nop62", TOKEN_INSN, C_none, 0, I_HINT_NOP62 },
        { "hint_nop63", TOKEN_INSN, C_none, 0, I_HINT_NOP63 },
        { "al", TOKEN_REG, 0, 0, R_AL },
        { "ah", TOKEN_REG, 0, 0, R_AH },
        { "ax", TOKEN_REG, 0, 0, R_AX },
        { "eax", TOKEN_REG, 0, 0, R_EAX },
        { "rax", TOKEN_REG, 0, 0, R_RAX },
        { "bl", TOKEN_REG, 0, 0, R_BL },
        { "bh", TOKEN_REG, 0, 0, R_BH },
        { "bx", TOKEN_REG, 0, 0, R_BX },
        { "ebx", TOKEN_REG, 0, 0, R_EBX },
        { "rbx", TOKEN_REG, 0, 0, R_RBX },
        { "cl", TOKEN_REG, 0, 0, R_CL },
        { "ch", TOKEN_REG, 0, 0, R_CH },
        { "cx", TOKEN_REG, 0, 0, R_CX },
        { "ecx", TOKEN_REG, 0, 0, R_ECX },
        { "rcx", TOKEN_REG, 0, 0, R_RCX },
        { "dl", TOKEN_REG, 0, 0, R_DL },
        { "dh", TOKEN_REG, 0, 0, R_DH },
        { "dx", TOKEN_REG, 0, 0, R_DX },
        { "edx", TOKEN_REG, 0, 0, R_EDX },
        { "rdx", TOKEN_REG, 0, 0, R_RDX },
        { "spl", TOKEN_REG, 0, 0, R_SPL },
        { "sp", TOKEN_REG, 0, 0, R_SP },
        { "esp", TOKEN_REG, 0, 0, R_ESP },
        { "rsp", TOKEN_REG, 0, 0, R_RSP },
        { "bpl", TOKEN_REG, 0, 0, R_BPL },
        { "bp", TOKEN_REG, 0, 0, R_BP },
        { "ebp", TOKEN_REG, 0, 0, R_EBP },
        { "rbp", TOKEN_REG, 0, 0, R_RBP },
        { "sil", TOKEN_REG, 0, 0, R_SIL },
        { "si", TOKEN_REG, 0, 0, R_SI },
        { "esi", TOKEN_REG, 0, 0, R_ESI },
        { "rsi", TOKEN_REG, 0, 0, R_RSI },
        { "dil", TOKEN_REG, 0, 0, R_DIL },
        { "di", TOKEN_REG, 0, 0, R_DI },
        { "edi", TOKEN_REG, 0, 0, R_EDI },
        { "rdi", TOKEN_REG, 0, 0, R_RDI },
        { "r8b", TOKEN_REG, 0, 0, R_R8B },
        { "r9b", TOKEN_REG, 0, 0, R_R9B },
        { "r10b", TOKEN_REG, 0, 0, R_R10B },
        { "r11b", TOKEN_REG, 0, 0, R_R11B },
        { "r12b", TOKEN_REG, 0, 0, R_R12B },
        { "r13b", TOKEN_REG, 0, 0, R_R13B },
        { "r14b", TOKEN_REG, 0, 0, R_R14B },
        { "r15b", TOKEN_REG, 0, 0, R_R15B },
        { "r8w", TOKEN_REG, 0, 0, R_R8W },
        { "r9w", TOKEN_REG, 0, 0, R_R9W },
        { "r10w", TOKEN_REG, 0, 0, R_R10W },
        { "r11w", TOKEN_REG, 0, 0, R_R11W },
        { "r12w", TOKEN_REG, 0, 0, R_R12W },
        { "r13w", TOKEN_REG, 0, 0, R_R13W },
        { "r14w", TOKEN_REG, 0, 0, R_R14W },
        { "r15w", TOKEN_REG, 0, 0, R_R15W },
        { "r8d", TOKEN_REG, 0, 0, R_R8D },
        { "r9d", TOKEN_REG, 0, 0, R_R9D },
        { "r10d", TOKEN_REG, 0, 0, R_R10D },
        { "r11d", TOKEN_REG, 0, 0, R_R11D },
        { "r12d", TOKEN_REG, 0, 0, R_R12D },
        { "r13d", TOKEN_REG, 0, 0, R_R13D },
        { "r14d", TOKEN_REG, 0, 0, R_R14D },
        { "r15d", TOKEN_REG, 0, 0, R_R15D },
        { "r8", TOKEN_REG, 0, 0, R_R8 },
        { "r9", TOKEN_REG, 0, 0, R_R9 },
        { "r10", TOKEN_REG, 0, 0, R_R10 },
        { "r11", TOKEN_REG, 0, 0, R_R11 },
        { "r12", TOKEN_REG, 0, 0, R_R12 },
        { "r13", TOKEN_REG, 0, 0, R_R13 },
        { "r14", TOKEN_REG, 0, 0, R_R14 },
        { "r15", TOKEN_REG, 0, 0, R_R15 },
        { "es", TOKEN_REG, 0, 0, R_ES },
        { "cs", TOKEN_REG, 0, 0, R_CS },
        { "ss", TOKEN_REG, 0, 0, R_SS },
        { "ds", TOKEN_REG, 0, 0, R_DS },
        { "fs", TOKEN_REG, 0, 0, R_FS },
        { "gs", TOKEN_REG, 0, 0, R_GS },
        { "segr6", TOKEN_REG, 0, 0, R_SEGR6 },
        { "segr7", TOKEN_REG, 0, 0, R_SEGR7 },
        { "cr0", TOKEN_REG, 0, 0, R_CR0 },
        { "cr1", TOKEN_REG, 0, 0, R_CR1 },
        { "cr2", TOKEN_REG, 0, 0, R_CR2 },
        { "cr3", TOKEN_REG, 0, 0, R_CR3 },
        { "cr4", TOKEN_REG, 0, 0, R_CR4 },
        { "cr5", TOKEN_REG, 0, 0, R_CR5 },
        { "cr6", TOKEN_REG, 0, 0, R_CR6 },
        { "cr7", TOKEN_REG, 0, 0, R_CR7 },
        { "cr8", TOKEN_REG, 0, 0, R_CR8 },
        { "cr9", TOKEN_REG, 0, 0, R_CR9 },
        { "cr10", TOKEN_REG, 0, 0, R_CR10 },
        { "cr11", TOKEN_REG, 0, 0, R_CR11 },
        { "cr12", TOKEN_REG, 0, 0, R_CR12 },
        { "cr13", TOKEN_REG, 0, 0, R_CR13 },
        { "cr14", TOKEN_REG, 0, 0, R_CR14 },
        { "cr15", TOKEN_REG, 0, 0, R_CR15 },
        { "dr0", TOKEN_REG, 0, 0, R_DR0 },
        { "dr1", TOKEN_REG, 0, 0, R_DR1 },
        { "dr2", TOKEN_REG, 0, 0, R_DR2 },
        { "dr3", TOKEN_REG, 0, 0, R_DR3 },
        { "dr4", TOKEN_REG, 0, 0, R_DR4 },
        { "dr5", TOKEN_REG, 0, 0, R_DR5 },
        { "dr6", TOKEN_REG, 0, 0, R_DR6 },
        { "dr7", TOKEN_REG, 0, 0, R_DR7 },
        { "dr8", TOKEN_REG, 0, 0, R_DR8 },
        { "dr9", TOKEN_REG, 0, 0, R_DR9 },
        { "dr10", TOKEN_REG, 0, 0, R_DR10 },
        { "dr11", TOKEN_REG, 0, 0, R_DR11 },
        { "dr12", TOKEN_REG, 0, 0, R_DR12 },
        { "dr13", TOKEN_REG, 0, 0, R_DR13 },
        { "dr14", TOKEN_REG, 0, 0, R_DR14 },
        { "dr15", TOKEN_REG, 0, 0, R_DR15 },
        { "tr0", TOKEN_REG, 0, 0, R_TR0 },
        { "tr1", TOKEN_REG, 0, 0, R_TR1 },
        { "tr2", TOKEN_REG, 0, 0, R_TR2 },
        { "tr3", TOKEN_REG, 0, 0, R_TR3 },
        { "tr4", TOKEN_REG, 0, 0, R_TR4 },
        { "tr5", TOKEN_REG, 0, 0, R_TR5 },
        { "tr6", TOKEN_REG, 0, 0, R_TR6 },
        { "tr7", TOKEN_REG, 0, 0, R_TR7 },
        { "st0", TOKEN_REG, 0, 0, R_ST0 },
        { "st1", TOKEN_REG, 0, 0, R_ST1 },
        { "st2", TOKEN_REG, 0, 0, R_ST2 },
        { "st3", TOKEN_REG, 0, 0, R_ST3 },
        { "st4", TOKEN_REG, 0, 0, R_ST4 },
        { "st5", TOKEN_REG, 0, 0, R_ST5 },
        { "st6", TOKEN_REG, 0, 0, R_ST6 },
        { "st7", TOKEN_REG, 0, 0, R_ST7 },
        { "mm0", TOKEN_REG, 0, 0, R_MM0 },
        { "mm1", TOKEN_REG, 0, 0, R_MM1 },
        { "mm2", TOKEN_REG, 0, 0, R_MM2 },
        { "mm3", TOKEN_REG, 0, 0, R_MM3 },
        { "mm4", TOKEN_REG, 0, 0, R_MM4 },
        { "mm5", TOKEN_REG, 0, 0, R_MM5 },
        { "mm6", TOKEN_REG, 0, 0, R_MM6 },
        { "mm7", TOKEN_REG, 0, 0, R_MM7 },
        { "xmm0", TOKEN_REG, 0, 0, R_XMM0 },
        { "xmm1", TOKEN_REG, 0, 0, R_XMM1 },
        { "xmm2", TOKEN_REG, 0, 0, R_XMM2 },
        { "xmm3", TOKEN_REG, 0, 0, R_XMM3 },
        { "xmm4", TOKEN_REG, 0, 0, R_XMM4 },
        { "xmm5", TOKEN_REG, 0, 0, R_XMM5 },
        { "xmm6", TOKEN_REG, 0, 0, R_XMM6 },
        { "xmm7", TOKEN_REG, 0, 0, R_XMM7 },
        { "xmm8", TOKEN_REG, 0, 0, R_XMM8 },
        { "xmm9", TOKEN_REG, 0, 0, R_XMM9 },
        { "xmm10", TOKEN_REG, 0, 0, R_XMM10 },
        { "xmm11", TOKEN_REG, 0, 0, R_XMM11 },
        { "xmm12", TOKEN_REG, 0, 0, R_XMM12 },
        { "xmm13", TOKEN_REG, 0, 0, R_XMM13 },
        { "xmm14", TOKEN_REG, 0, 0, R_XMM14 },
        { "xmm15", TOKEN_REG, 0, 0, R_XMM15 },
        { "xmm16", TOKEN_REG, 0, 0, R_XMM16 },
        { "xmm17", TOKEN_REG, 0, 0, R_XMM17 },
        { "xmm18", TOKEN_REG, 0, 0, R_XMM18 },
        { "xmm19", TOKEN_REG, 0, 0, R_XMM19 },
        { "xmm20", TOKEN_REG, 0, 0, R_XMM20 },
        { "xmm21", TOKEN_REG, 0, 0, R_XMM21 },
        { "xmm22", TOKEN_REG, 0, 0, R_XMM22 },
        { "xmm23", TOKEN_REG, 0, 0, R_XMM23 },
        { "xmm24", TOKEN_REG, 0, 0, R_XMM24 },
        { "xmm25", TOKEN_REG, 0, 0, R_XMM25 },
        { "xmm26", TOKEN_REG, 0, 0, R_XMM26 },
        { "xmm27", TOKEN_REG, 0, 0, R_XMM27 },
        { "xmm28", TOKEN_REG, 0, 0, R_XMM28 },
        { "xmm29", TOKEN_REG, 0, 0, R_XMM29 },
        { "xmm30", TOKEN_REG, 0, 0, R_XMM30 },
        { "xmm31", TOKEN_REG, 0, 0, R_XMM31 },
        { "ymm0", TOKEN_REG, 0, 0, R_YMM0 },
        { "ymm1", TOKEN_REG, 0, 0, R_YMM1 },
        { "ymm2", TOKEN_REG, 0, 0, R_YMM2 },
        { "ymm3", TOKEN_REG, 0, 0, R_YMM3 },
        { "ymm4", TOKEN_REG, 0, 0, R_YMM4 },
        { "ymm5", TOKEN_REG, 0, 0, R_YMM5 },
        { "ymm6", TOKEN_REG, 0, 0, R_YMM6 },
        { "ymm7", TOKEN_REG, 0, 0, R_YMM7 },
        { "ymm8", TOKEN_REG, 0, 0, R_YMM8 },
        { "ymm9", TOKEN_REG, 0, 0, R_YMM9 },
        { "ymm10", TOKEN_REG, 0, 0, R_YMM10 },
        { "ymm11", TOKEN_REG, 0, 0, R_YMM11 },
        { "ymm12", TOKEN_REG, 0, 0, R_YMM12 },
        { "ymm13", TOKEN_REG, 0, 0, R_YMM13 },
        { "ymm14", TOKEN_REG, 0, 0, R_YMM14 },
        { "ymm15", TOKEN_REG, 0, 0, R_YMM15 },
        { "ymm16", TOKEN_REG, 0, 0, R_YMM16 },
        { "ymm17", TOKEN_REG, 0, 0, R_YMM17 },
        { "ymm18", TOKEN_REG, 0, 0, R_YMM18 },
        { "ymm19", TOKEN_REG, 0, 0, R_YMM19 },
        { "ymm20", TOKEN_REG, 0, 0, R_YMM20 },
        { "ymm21", TOKEN_REG, 0, 0, R_YMM21 },
        { "ymm22", TOKEN_REG, 0, 0, R_YMM22 },
        { "ymm23", TOKEN_REG, 0, 0, R_YMM23 },
        { "ymm24", TOKEN_REG, 0, 0, R_YMM24 },
        { "ymm25", TOKEN_REG, 0, 0, R_YMM25 },
        { "ymm26", TOKEN_REG, 0, 0, R_YMM26 },
        { "ymm27", TOKEN_REG, 0, 0, R_YMM27 },
        { "ymm28", TOKEN_REG, 0, 0, R_YMM28 },
        { "ymm29", TOKEN_REG, 0, 0, R_YMM29 },
        { "ymm30", TOKEN_REG, 0, 0, R_YMM30 },
        { "ymm31", TOKEN_REG, 0, 0, R_YMM31 },
        { "zmm0", TOKEN_REG, 0, 0, R_ZMM0 },
        { "zmm1", TOKEN_REG, 0, 0, R_ZMM1 },
        { "zmm2", TOKEN_REG, 0, 0, R_ZMM2 },
        { "zmm3", TOKEN_REG, 0, 0, R_ZMM3 },
        { "zmm4", TOKEN_REG, 0, 0, R_ZMM4 },
        { "zmm5", TOKEN_REG, 0, 0, R_ZMM5 },
        { "zmm6", TOKEN_REG, 0, 0, R_ZMM6 },
        { "zmm7", TOKEN_REG, 0, 0, R_ZMM7 },
        { "zmm8", TOKEN_REG, 0, 0, R_ZMM8 },
        { "zmm9", TOKEN_REG, 0, 0, R_ZMM9 },
        { "zmm10", TOKEN_REG, 0, 0, R_ZMM10 },
        { "zmm11", TOKEN_REG, 0, 0, R_ZMM11 },
        { "zmm12", TOKEN_REG, 0, 0, R_ZMM12 },
        { "zmm13", TOKEN_REG, 0, 0, R_ZMM13 },
        { "zmm14", TOKEN_REG, 0, 0, R_ZMM14 },
        { "zmm15", TOKEN_REG, 0, 0, R_ZMM15 },
        { "zmm16", TOKEN_REG, 0, 0, R_ZMM16 },
        { "zmm17", TOKEN_REG, 0, 0, R_ZMM17 },
        { "zmm18", TOKEN_REG, 0, 0, R_ZMM18 },
        { "zmm19", TOKEN_REG, 0, 0, R_ZMM19 },
        { "zmm20", TOKEN_REG, 0, 0, R_ZMM20 },
        { "zmm21", TOKEN_REG, 0, 0, R_ZMM21 },
        { "zmm22", TOKEN_REG, 0, 0, R_ZMM22 },
        { "zmm23", TOKEN_REG, 0, 0, R_ZMM23 },
        { "zmm24", TOKEN_REG, 0, 0, R_ZMM24 },
        { "zmm25", TOKEN_REG, 0, 0, R_ZMM25 },
        { "zmm26", TOKEN_REG, 0, 0, R_ZMM26 },
        { "zmm27", TOKEN_REG, 0, 0, R_ZMM27 },
        { "zmm28", TOKEN_REG, 0, 0, R_ZMM28 },
        { "zmm29", TOKEN_REG, 0, 0, R_ZMM29 },
        { "zmm30", TOKEN_REG, 0, 0, R_ZMM30 },
        { "zmm31", TOKEN_REG, 0, 0, R_ZMM31 },
        { "k0", TOKEN_REG, 0, 0, R_K0 },
        { "k1", TOKEN_REG, 0, TFLAG_BRC_OPT, R_K1 },
        { "k2", TOKEN_REG, 0, TFLAG_BRC_OPT, R_K2 },
        { "k3", TOKEN_REG, 0, TFLAG_BRC_OPT, R_K3 },
        { "k4", TOKEN_REG, 0, TFLAG_BRC_OPT, R_K4 },
        { "k5", TOKEN_REG, 0, TFLAG_BRC_OPT, R_K5 },
        { "k6", TOKEN_REG, 0, TFLAG_BRC_OPT, R_K6 },
        { "k7", TOKEN_REG, 0, TFLAG_BRC_OPT, R_K7 },
        { "bnd0", TOKEN_REG, 0, 0, R_BND0 },
        { "bnd1", TOKEN_REG, 0, 0, R_BND1 },
        { "bnd2", TOKEN_REG, 0, 0, R_BND2 },
        { "bnd3", TOKEN_REG, 0, 0, R_BND3 },
        { "a16", TOKEN_PREFIX, 0, 0, P_A16 },
        { "a32", TOKEN_PREFIX, 0, 0, P_A32 },
        { "a64", TOKEN_PREFIX, 0, 0, P_A64 },
        { "asp", TOKEN_PREFIX, 0, 0, P_ASP },
        { "lock", TOKEN_PREFIX, 0, 0, P_LOCK },
        { "o16", TOKEN_PREFIX, 0, 0, P_O16 },
        { "o32", TOKEN_PREFIX, 0, 0, P_O32 },
        { "o64", TOKEN_PREFIX, 0, 0, P_O64 },
        { "osp", TOKEN_PREFIX, 0, 0, P_OSP },
        { "rep", TOKEN_PREFIX, 0, 0, P_REP },
        { "repe", TOKEN_PREFIX, 0, 0, P_REPE },
        { "repne", TOKEN_PREFIX, 0, 0, P_REPNE },
        { "repnz", TOKEN_PREFIX, 0, 0, P_REPNZ },
        { "repz", TOKEN_PREFIX, 0, 0, P_REPZ },
        { "times", TOKEN_PREFIX, 0, 0, P_TIMES },
        { "wait", TOKEN_PREFIX, 0, 0, P_WAIT },
        { "xacquire", TOKEN_PREFIX, 0, 0, P_XACQUIRE },
        { "xrelease", TOKEN_PREFIX, 0, 0, P_XRELEASE },
        { "bnd", TOKEN_PREFIX, 0, 0, P_BND },
        { "nobnd", TOKEN_PREFIX, 0, 0, P_NOBND },
        { "abs", TOKEN_SPECIAL, 0, 0, S_ABS },
        { "byte", TOKEN_SPECIAL, 0, 0, S_BYTE },
        { "dword", TOKEN_SPECIAL, 0, 0, S_DWORD },
        { "far", TOKEN_SPECIAL, 0, 0, S_FAR },
        { "long", TOKEN_SPECIAL, 0, 0, S_LONG },
        { "near", TOKEN_SPECIAL, 0, 0, S_NEAR },
        { "nosplit", TOKEN_SPECIAL, 0, 0, S_NOSPLIT },
        { "oword", TOKEN_SPECIAL, 0, 0, S_OWORD },
        { "qword", TOKEN_SPECIAL, 0, 0, S_QWORD },
        { "rel", TOKEN_SPECIAL, 0, 0, S_REL },
        { "short", TOKEN_SPECIAL, 0, 0, S_SHORT },
        { "strict", TOKEN_SPECIAL, 0, 0, S_STRICT },
        { "to", TOKEN_SPECIAL, 0, 0, S_TO },
        { "tword", TOKEN_SPECIAL, 0, 0, S_TWORD },
        { "word", TOKEN_SPECIAL, 0, 0, S_WORD },
        { "yword", TOKEN_SPECIAL, 0, 0, S_YWORD },
        { "zword", TOKEN_SPECIAL, 0, 0, S_ZWORD },
        { "__infinity__", TOKEN_FLOAT, 0, 0, 0 },
        { "__nan__", TOKEN_FLOAT, 0, 0, 0 },
        { "__qnan__", TOKEN_FLOAT, 0, 0, 0 },
        { "__snan__", TOKEN_FLOAT, 0, 0, 0 },
        { "__float8__", TOKEN_FLOATIZE, 0, 0, FLOAT_8 },
        { "__float16__", TOKEN_FLOATIZE, 0, 0, FLOAT_16 },
        { "__float32__", TOKEN_FLOATIZE, 0, 0, FLOAT_32 },
        { "__float64__", TOKEN_FLOATIZE, 0, 0, FLOAT_64 },
        { "__float80m__", TOKEN_FLOATIZE, 0, 0, FLOAT_80M },
        { "__float80e__", TOKEN_FLOATIZE, 0, 0, FLOAT_80E },
        { "__float128l__", TOKEN_FLOATIZE, 0, 0, FLOAT_128L },
        { "__float128h__", TOKEN_FLOATIZE, 0, 0, FLOAT_128H },
        { "__utf16__", TOKEN_STRFUNC, 0, 0, STRFUNC_UTF16 },
        { "__utf16le__", TOKEN_STRFUNC, 0, 0, STRFUNC_UTF16LE },
        { "__utf16be__", TOKEN_STRFUNC, 0, 0, STRFUNC_UTF16BE },
        { "__utf32__", TOKEN_STRFUNC, 0, 0, STRFUNC_UTF32 },
        { "__utf32le__", TOKEN_STRFUNC, 0, 0, STRFUNC_UTF32LE },
        { "__utf32be__", TOKEN_STRFUNC, 0, 0, STRFUNC_UTF32BE },
        { "__ilog2e__", TOKEN_IFUNC, 0, 0, IFUNC_ILOG2E },
        { "__ilog2w__", TOKEN_IFUNC, 0, 0, IFUNC_ILOG2W },
        { "__ilog2f__", TOKEN_IFUNC, 0, 0, IFUNC_ILOG2F },
        { "__ilog2c__", TOKEN_IFUNC, 0, 0, IFUNC_ILOG2C },
        { "seg", TOKEN_SEG, 0, 0, 0 },
        { "wrt", TOKEN_WRT, 0, 0, 0 },
        { "1to2", TOKEN_DECORATOR, 0, TFLAG_BRC | TFLAG_BRDCAST , BRC_1TO2 },
        { "1to4", TOKEN_DECORATOR, 0, TFLAG_BRC | TFLAG_BRDCAST , BRC_1TO4 },
        { "1to8", TOKEN_DECORATOR, 0, TFLAG_BRC | TFLAG_BRDCAST , BRC_1TO8 },
        { "1to16", TOKEN_DECORATOR, 0, TFLAG_BRC | TFLAG_BRDCAST , BRC_1TO16 },
        { "rn-sae", TOKEN_DECORATOR, 0, TFLAG_BRC, BRC_RN },
        { "rd-sae", TOKEN_DECORATOR, 0, TFLAG_BRC, BRC_RD },
        { "ru-sae", TOKEN_DECORATOR, 0, TFLAG_BRC, BRC_RU },
        { "rz-sae", TOKEN_DECORATOR, 0, TFLAG_BRC, BRC_RZ },
        { "sae", TOKEN_DECORATOR, 0, TFLAG_BRC, BRC_SAE },
        { "z", TOKEN_DECORATOR, 0, TFLAG_BRC, BRC_Z },
        { "evex", TOKEN_PREFIX, 0, TFLAG_BRC, P_EVEX },
        { "vex3", TOKEN_PREFIX, 0, TFLAG_BRC, P_VEX3 },
        { "vex2", TOKEN_PREFIX, 0, TFLAG_BRC, P_VEX2 },
    };
    uint32_t k1, k2;
    uint64_t crc;
    uint16_t ix;
    const struct tokendata *data;

    tv->t_flag = 0;
    crc = crc64(UINT64_C(0xace2d0e480575791), token);
    k1 = (uint32_t)crc;
    k2 = (uint32_t)(crc >> 32);

    ix = hash1[k1 & 0x7ff] + hash2[k2 & 0x7ff];
    if (ix >= 2216)
        return tv->t_type = TOKEN_ID;

    data = &tokendata[ix];
    if (strcmp(data->string, token))
        return tv->t_type = TOKEN_ID;

    tv->t_integer = data->num;
    tv->t_inttwo  = data->aux;
    tv->t_flag    = data->tokflag;
    return tv->t_type = data->tokentype;
}
